/*************************************************/
/* PTraffic - Javascript-Library                 */
/*                                               */
/* ptraffic.js                                   */
/* allgemeine Funktionen + Variablen             */
/* fr alle PTraffic- und LineMap-Draw-Versionen */
/*                                               */
/* Version 0.8                                   */
/* ptraffic.js: Version 0.8                      */
/*                                               */
/* Copyright by Jrg Siebrands, Germany, 2018    */
/*************************************************/

/*** Konstanten ***/

const	withTimetable = 1;							// projectType; fr PTraffic-Standard 
const withLinemap = 2;								// projectType; fr LineMapDraw
const withTimetableAndLinemap = 3;		// projectType; fr PTraffic Pro/ProPlus
const withoutTimetableAndLinemap = 4;	// projectType; wenn weder Fahrplan- noch Netzplan-Daten bentigt werden

// alt (?):  var goBack;						// merkt sich bergebene Callback-Funktion; 
var projectDir;				// Verzeichnis fr PTF-Dateien
var projectType;			// withTimetable(std), withLinemap(lmd), withTimetableAndLinemap(pro);  vorher: "Std", "Pro" oder "Draw"
var actLanguage;    	// Aktuelle Sprache - wird in ptInit gesetzt
var actLanguageText; 	// Aktuelles Sprache-Objekt, z.B:: languageText["ger"]; wird in ptInit gesetzt
var ptStandardTable = "ptDefaultTable";		// standard-html-table-id fr Tabellen-Anzeige-Funktionen
var stations = new Array();		// Array mit Stationen; Felder: ID und Station; Sortiert nach Station
var stationsByIdArray = new Array();
var stationsByNameArray = new Object();
var lines = new Array();
var linesByIdArray = new Array();
var linesByNameArray = new Object();
var lineStations = new Array();			// Daten aus line_stations.ptf; Sortierung: LineID, LineStationNumber, StationID
var lineStationsByLineIdArray = new Array();			// [LineID][Position] = Index in stations (nicht Station-ID!)
var stationLinesByStationIdArray	= new Array();	// [StationID][Index] = Index in lines (nicht Line-ID!); nach Line-ID sortiert nach Linien-Namen 
var dayGroups = new Array();			// Array mit allen DayGroups; Felder wie daygroups.ptf; sortiert nach "Days"
var dayGroupsByIdArray = new Array();	 
var intervals = new Array();
var intervalsByIdArray = new Array();
var lineConnections = new Array();			// Sortierung:  LineID, DayGroupID, Direction
var lineConnectionsByIdArray = new Array();
var lineConnectionsByLineIdArray = new Array();		// Aufbau: [LineId][lfd.Nr.] = Index von lineConnections[]
    
/*** Hilfs-Funktionen ***/

/* lscht und initialisert Tabelle fr showStations etc.	*/
/* showTab = Tabelle als id, index, objekt oder undefined */
/* Rckgabe: Tabellenobjekt 															*/
function ptInitTable(showTab)	{
	// alert("ptInitTable()");
	var tp;
	var tid;
	tp = typeof showTab;
	tid = "";
	switch (tp)	{
		case "string"	:
			tb = document.getElementById(showTab);		
			tid = showTab;
			break;
		case "number"	:
			tb = document.getElementsByTagName("table")[showTab];					
			if (tb == null)	{
				tid = ptStandardTable;
			}
			break;
		case "object"	:
			tb = showTab;		
			tid = tb.getAttribute("ID", 0);					
			break;
		default	:		// not exists / nicht vorhanden
			tid = ptStandardTable;
			tb = document.getElementById(tid);						
			break;																									
	}		
	if ((typeof (tb) != "object") || (tb == null))	{
		tb = document.createElement("table");
		tb.setAttribute("Border", 1, 0);
		tb.setAttribute("ID", tid, 0);				
		document.getElementsByTagName("body")[0].appendChild(tb);
	} else {
		publicSQL.htmlTableDelete(tb);								
	}
	return tb;	
}	// ptInitTable()


/*
function emptyFunction()	{	// leere Funktion. Wird verwendet wenn keine Callback-Funktion als Parameter bergeben wurde
	alert("emptyFunction");
}
*/

/*** Anwender-Funktionen ***/

/* Initialisieren; muss vor Aufruf weiterer Funktionen fr das Projekt aufgerufen werden	*/
function ptInit(ptype, lng, optPar1, optPar2)	{		//  PTraffic-Type (Pro, ...), Sprache, Verzeichnis, nachfolgende Funktion	
	// alert("ptInit()");
	var fn = ((arguments.length > 2) && (typeof arguments[arguments.length-1] == "function")) ? arguments[arguments.length-1] : undefined;
	var dir = ((arguments.length > 2) && (typeof arguments[2] == "string")) ? arguments[2] : ".";		
		
	this.ptInitIntervals = function(t)	{		// Datensatz = "ID","Interval"
		// alert("ptInitIntervals");
		var i;
		for (i=1; i<t.length; i++) {
			intervals[i-1] = new Object();
			intervals[i-1].ID = t[i][0];
			intervals[i-1].Interval = t[i][1];			// Minuten-Wert
			intervalsByIdArray[t[i][0]] = i-1;			// ID = Index von intervals
		}		
		if (fn !== "undefined")	{
	 		fn();	// zur Callback-Funktion gehen
	 	}		
	}	
	
	this.ptInitLineConnections = function(t)	{		// Datensatz = "ID","LineID","DayGroupID","Direction"; Sort: "LineID","DayGroupID","Direction"
		// alert("ptInitLineConnections");
		var i;
		var lid = -1;	
		for (i=1; i<t.length; i++) {
			lineConnections[i-1] = new Object();
			lineConnections[i-1].ID = t[i][0];
			lineConnections[i-1].LineID = t[i][1];
			lineConnections[i-1].DayGroupID = t[i][2];
			lineConnections[i-1].Direction = t[i][3];						
			lineConnectionsByIdArray[t[i][0]] = i-1;			// ID = Index von dayGroups[]
			if (lid != t[i][1])	{	// neue LineID
				lineConnectionsByLineIdArray[t[i][1]] = new Array();						// neues LineID-Unter-Array
			}
			lid = t[i][1];
			lineConnectionsByLineIdArray[lid][lineConnectionsByLineIdArray[lid].length] = i-1;
		}		
		publicSQL.query('SELECT ID, Interval FROM intervalsORDER BY Interval','ptInitIntervals');
	}
	
	this.ptInitDayGroups = function(t)	{	// Datensatz = "ID","Group","Days","Text",
		// alert("ptInitDayGroups");
		var i;
		for (i=1; i<t.length; i++) {
			dayGroups[i-1] = new Object();
			dayGroups[i-1].ID = t[i][0];
			dayGroups[i-1].Group = t[i][1];
			dayGroups[i-1].Days = t[i][2];
			dayGroups[i-1].Text = t[i][3];						
			dayGroupsByIdArray[t[i][0]] = i-1;			// ID = Index von daygroups
			//stationsByNameArray[t[i][1]] = i-1;   // name = Index von stations
		}		
		publicSQL.query('SELECT ID, LineID, DayGroupID, Direction FROM line_connections ORDER BY LineID, DayGroupID, Direction','ptInitLineConnections');
	}
	
	this.ptInitStationLines = function(t)	{		// Datensatz = "StationID, "LineID"
    // alert("ptInitStationLines");
		var i;
		var sid = 0;	// unmglicher Wert als Startwert fr aktuelle Linien-ID		
		for (i=1; i<t.length; i++) {			// fr alle Datenstze 
			if (sid != t[i][0])	{			// neue StationID			
				sid = t[i][0];
				stationLinesByStationIdArray[sid] = new Array();
			}	// ab hier kann sid benutzt werden			
			stationLinesByStationIdArray[sid][stationLinesByStationIdArray[sid].length] = linesByIdArray[t[i][1]];	// Index in lines (nicht Station-ID!)							
		}	// for	
		if ((projectType == withTimetable) || (projectType == withTimetableAndLinemap ))	{	// wenn Fahrplandaten bentigt werden 				
			publicSQL.query('SELECT ID, Group, Days, Text FROM daygroups ORDER BY Days DESC', 'ptInitDayGroups');							
		} else if (projectType == withLinemap)	{		// wenn (nur)Netzplandaten bentigt werden
			// folgt noch
			if (fn !== "undefined")	{
		 		fn();	// zur Callback-Funktion gehen
		 	}					
		} else if (projectType == withoutTimetableAndLinemap)	{	// keine Fahrplandaten und Netzplandaten ntig
			if (fn !== "undefined")	{
		 		fn();	// zur Callback-Funktion gehen
		 	}				
		}
	}
	
	this.ptInitLineStations = function(t)	{		// Datensatz = "LineID","LineStationNumber","StationID"
    // alert("ptInitLineStations");
		var i;
		var lid = 0;	// unmglicher Wert als Startwert fr aktuelle Linien-ID
		for (i=1; i<t.length; i++) {			// fr alle Datenstze 
			if (lid != t[i][0])	{			// neue LineID			
				lid = t[i][0];
				lineStationsByLineIdArray[lid] = new Array();
			}	// ab hier kann lid benutzt werden	
			lineStations[i-1] = new Object();
			lineStations[i-1].LineID = lid;			// LineID
			lineStations[i-1].Position = t[i][1];		// Position der Station in der Linienroute; fngt bei 1 an!
			lineStations[i-1].StationID = t[i][2];	// StationID			
			// lineStationsByLineIdArray[lid][lineStationsByLineIdArray[lid].length] = t[i][2]									// Index fr Position fngt hier bei 0 an!
			lineStationsByLineIdArray[lid][lineStationsByLineIdArray[lid].length] = stationsByIdArray[t[i][2]];	// Index in stations (nicht Station-ID!)		
		}
		publicSQL.query('select DISTINCT StationID, LineID from line_stations order by StationID, LineID', 'ptInitStationLines'); 
	}					
	
	this.ptInitLines = function(t)	{
    // alert("ptInitLines");
		var i;
		for (i=1; i<t.length; i++) {
			lines[i-1] = new Object();
			lines[i-1].ID = t[i][0];
			lines[i-1].Line = t[i][1];
			linesByIdArray[t[i][0]] = i-1;			// ID = Index von stations
			linesByNameArray[t[i][1]] = i-1;   	// name = Index von stations
		}
		publicSQL.query('select * from line_stations order by LineID, LineStationNumber, StationID', 'ptInitLineStations'); 
	}			
	this.ptInitStations = function(t)	{
		// alert("initStationsFunc");
		var i;
		for (i=1; i<t.length; i++) {
			stations[i-1] = new Object();
			stations[i-1].ID = t[i][0];
			stations[i-1].Station = t[i][1];
			stationsByIdArray[t[i][0]] = i-1;			// ID = Index von stations
			stationsByNameArray[t[i][1]] = i-1;   // name = Index von stations
		}
		publicSQL.query('select ID, Line from lines order by Line', 'ptInitLines'); // Linien laden, nach Namen sortiert
	};
	projectDir = dir;
	publicSQL.tablePath = dir + "/";
	publicSQL.setTableCache(false);		// Table-Cache ausschalten
	projectType = ptype;
	actLanguage = lng;	// Sprache
	actLanguageText = languageText[lng];	// Sprache-Objekt
	publicSQL.query('select ID, Station from stations order by Station', "ptInitStations"); 	// Stationen laden, nach Namen sortiert.
}

/* setzt die aktuelle Sprache. 																														*/
/* lng = 3-stelliges Krzel der Sprache; Sprache muss in ptraffic_text.js definiert sein! */
function setLanguage(lng)	{
	// alert("setLanguage");
	actLanguage = lng;
	actLanguageText = languageText[lng];
}

/* gibt die aktuelle Sprache als 3-stelliges Krzel zurck; Sprache muss in ptraffic_text.js definiert sein! */
function getLanguage()	{
	return actLanguage;
}

/* Erstellt Formular mit Sprachauswahl-Dialog	*/
function showLanguageSelectDialog(did, update, optPar1, optPar2)	{	// DIV-ID, Aktualisierung, Sprachtext in Landessprache, Sprachwechsel-Funktion
	 // alert("showLanguageSelectDialog()");		
	var selfLang = 	((arguments.length > 2) && (typeof arguments[2] == "boolean")) ? arguments[2] : false;
	var fn = 				((arguments.length > 2) && (typeof arguments[arguments.length-1] == "function")) ? arguments[arguments.length-1] : undefined;		
	var newOpt;
	
	/* Formular fr Sprachauswahl-Dialog erstellen */
	this.showLanguageSelectDialogForm = function()	{ 
		// alert("showLanguageSelectDialogForm()");
		var fm = '<form name="fmSelect" id="fmSelect">';
		fm += '<p>';
		// <p style="white-space:nowrap">
		fm += '<strong>' + actLanguageText.language + ':</strong>';
		fm += '<select name="sbLanguage" id="sbLanguage" onChange="showLanguageSelectDialogChange();">';
		fm += '</select> ';	
	  fm += '</p>';
		fm += '</form>';	
		document.getElementById(did).innerHTML = fm;			
		
		/* Selectbox fllen */	
	  for (s in languageText)		{  // s = "ger", "eng" etc.
	    if (selfLang == false)	{  // Sprachen in aktueller Sprache anzeigen    
		    newOpt = new Option(actLanguageText[s], s, false, false);  // Sprache, Sprachkrzel, ...
		  } else {	// Sprachen in Landessprache anzeige
				newOpt = new Option(languageText[s][s], s, false, false);  // Sprache, Sprachkrzel, ...	  	
			}
	    document.fmSelect.sbLanguage.options[document.fmSelect.sbLanguage.length] = newOpt;
	    if (actLanguage == s)	{  																		// aktuelle Sprache...
	    	document.fmSelect.sbLanguage.options[document.fmSelect.sbLanguage.length-1].selected = true;	//  wird selektiert
	    }
		}				
	}
	
	/* Sprachwechsel */
	this.showLanguageSelectDialogChange = function()	{		// Funktion wird wenn selfLang==true bei Sprach-Wechsel aufgerufen
		// alert("showLanguageSelectDialogChange()");
		actLanguage = document.fmSelect.sbLanguage.options[document.fmSelect.sbLanguage.selectedIndex].value;
		actLanguageText = languageText[actLanguage];
		if (update == true)  {	// Selectbox in neu gewhlte Sprache anzeigen
			showLanguageSelectDialogForm();
		}
		if (fn !== "undefined")	{  // Funktionsparameter vorhanden?
			fn();
		}
	}

	showLanguageSelectDialogForm();		
}	// showLanguageSelectDialog()

/*** Stationen ***/

function getStationName(sid)	{
	var v = stations[stationsByIdArray[sid]];
	if (v != undefined) {
		return stations[stationsByIdArray[sid]].Station;
	} else {
		return v;
	}
}

function getStationId(sn)	{
	// alert("getStationId");
	var v = stations[stationsByNameArray[sn]];
	if (v != undefined) {
		return stations[stationsByNameArray[sn]].ID;
	} else {
		return v;
	}
}

function showStations(optPar1)	{	
	// alert("showStations()");
  var i;
	var s;
	var tr, td, th, tbody, ttext;
	var tb = ptInitTable(optPar1);

	// body...
	tbody = document.createElement("tbody");			
	
	// berschrift...
	tr = document.createElement("tr");
	th = document.createElement("th");						// 1. column = row-number...
	ttext= document.createTextNode(" ");
	th.appendChild(ttext);
	tr.appendChild(th);	
	th = document.createElement("th");				
	s = actLanguageText.station;			// bei neuer Tabelle per Voreinstellung fett + zentriert!
	ttext= document.createTextNode(s);
	th.appendChild(ttext);
	tr.appendChild(th);				
	tbody.appendChild(tr);				
	
	// Stationen...
	for (i=0; i<stations.length; i++)	{
		tr = document.createElement("tr");			
		td = document.createElement("td");					// 1. Spalte
		ttext= document.createTextNode(i+1);  			// Spalten-Nummer
		td.appendChild(ttext);
		td.style.fontWeight = "bold";
		tr.appendChild(td);													
		td = document.createElement("td");					// 2. Spalte
		ttext= document.createTextNode(stations[i].Station);
		td.appendChild(ttext);
		tr.appendChild(td);									
		tbody.appendChild(tr);				
	}	// for i	
	tb.cellPadding = 1;
	tb.cellSpacing = 0;	
	tb.appendChild(tbody);
}

function getLineName(lid)	{
	var v = lines[linesByIdArray[lid]];
	if (v != undefined) {
		return lines[linesByIdArray[lid]].Line;
	} else {
		return v;
	}
}

function getLineId(ln)	{
	// alert("getStationId");
	var v = lines[linesByNameArray[ln]];
	if (v != undefined) {
		return lines[linesByNameArray[ln]].ID;
	} else {
		return v;
	}
}

function showLines(optPar1)	{
	// alert("ShowLines");
  var i;
	var s;
	var tr, td, th, tbody, ttext;
	var tb = ptInitTable(optPar1);

	// body...
	tbody = document.createElement("tbody");			
	
	// berschrift...
	tr = document.createElement("tr");
	th = document.createElement("th");						// 1. column = row-number...
	ttext= document.createTextNode(" ");
	th.appendChild(ttext);
	tr.appendChild(th);	
	th = document.createElement("th");				
	s = actLanguageText.line;			// bei neuer Tabelle per Voreinstellung fett + zentriert!
	ttext= document.createTextNode(s);
	th.appendChild(ttext);
	tr.appendChild(th);				
	tbody.appendChild(tr);		
	

	// Linien...
	for (i=0; i<lines.length; i++)	{
		tr = document.createElement("tr");			
		td = document.createElement("td");					// 1. Spalte
		ttext= document.createTextNode(i+1);  			// Spalten-Nummer
		td.appendChild(ttext);
		td.style.fontWeight = "bold";
		tr.appendChild(td);													
		td = document.createElement("td");					// 2. Spalte
		ttext= document.createTextNode(lines[i].Line);
		td.appendChild(ttext);
		tr.appendChild(td);									
		tbody.appendChild(tr);				
	}	// for i	
	tb.cellPadding = 1;
	tb.cellSpacing = 0;	
	tb.appendChild(tbody);
}

/* Gibt Array mit Linien-ID's der bergebenen Stations-ID zurck; optPar1 = alphabet. Sortierung	*/
function getStationLineIds(sid, optPar1)	{		
	// alert("getStationLineIds");	
	var i;
	var a = new Array();	// Array
	var atemp = new Array();	// Hilfs-Array zum sortieren
	if (stationLinesByStationIdArray[sid] != undefined)	{	// wenn Station-ID existiert
		for (i=0; i<stationLinesByStationIdArray[sid].length; i++)	{	// alle Linien der Station durchgehen
			a[a.length] = lines[stationLinesByStationIdArray[sid][i]].ID;	// Linien-Name aus lines[] holen
		}
	}
	if ((optPar1 == undefined) || (optPar1 == true)) {	// nach Linien-Namen sortieren
		for (i=0; i<a.length; i++)	{
			a[i] = linesByIdArray[a[i]];	// Index von lines[]			
		}
		a.sort();
		for (i=0; i<a.length; i++)	{
			a[i] = lines[a[i]].ID;	// wieder LineID
		}				
	}
	return a;
}	

function getStationLineNames(sid, optPar1)	{		// Station-ID, gibt Array mit Linien in richtiger Reihenfolge zurck
	// alert("getStationLineNames");	
	var i;
	var a = new Array();	// Array
	if (stationLinesByStationIdArray[sid] != undefined)	{	// wenn Station-ID existiert
		for (i=0; i<stationLinesByStationIdArray[sid].length; i++)	{	// alle Liniender Station durchgehen
			a[a.length] = lines[stationLinesByStationIdArray[sid][i]].Line;	// Linienname aus lines[] holen
		}
	}
	return ((optPar1 != undefined) && (optPar1 == false)) ? a : a.sort();
	// return a;
}			

function getLineStationIds(lid)	{		// Linien-ID, gibt Array mit Stationen in richtiger Reihenfolge zurck
	// alert("getLineStationNames");	
	var i;
	var a = new Array();	// Array
	if (lineStationsByLineIdArray[lid] != undefined)	{	// wenn Linien-ID existiert
		for (i=0; i<lineStationsByLineIdArray[lid].length; i++)	{	// alle Stationen der Linie durchgehen
			a[a.length] = stations[lineStationsByLineIdArray[lid][i]].ID;	// Stationsname aus stations[] holen
		}
	}
	return a;
}	

function getLineStationNames(lid)	{		// Linien-ID, gibt Array mit Stationen in richtiger Reihenfolge zurck
	// alert("getLineStationNames");	
	var i;
	var a = new Array();	// Array
	if (lineStationsByLineIdArray[lid] != undefined)	{	// wenn Linien-ID existiert
		for (i=0; i<lineStationsByLineIdArray[lid].length; i++)	{	// alle Stationen der Linie durchgehen
			a[a.length] = stations[lineStationsByLineIdArray[lid][i]].Station;	// Stationsname aus stations[] holen
		}
	}
	return a;
}			

function showLineCourse(lid, optPar1)	{		// Linien-ID, [Tabelle]
	// alert("showLineCourse");		
  var i;
	var s;
	var tr, td, th, tbody, ttext;
	var tb = ptInitTable(optPar1);
	var row, old;

	// body...
	tbody = document.createElement("tbody");			
	// berschrift...
	tr = document.createElement("tr");
	th = document.createElement("th");						// 1. column = row-number...
	ttext= document.createTextNode(" ");
	th.appendChild(ttext);
	tr.appendChild(th);	
	th = document.createElement("th");				
	s = actLanguageText.station;			// bei neuer Tabelle per Voreinstellung fett + zentriert!
	ttext= document.createTextNode(s);
	th.appendChild(ttext);
	tr.appendChild(th);				
	tbody.appendChild(tr);		
	
	// Linien...
	row = 1;  old = '';
	for (i=0; i<lineStationsByLineIdArray[lid].length; i++)	{
		if (old != stations[lineStationsByLineIdArray[lid][i]].Station) {	// nicht gleiche Station
			tr = document.createElement("tr");			
			td = document.createElement("td");					// 1. Spalte
			ttext= document.createTextNode(row);  			// Spalten-Nummer
			td.appendChild(ttext);
			td.style.fontWeight = "bold";
			tr.appendChild(td);													
			td = document.createElement("td");					// 2. Spalte
			// ttext= document.createTextNode(lines[i].Line);
			ttext = document.createTextNode(stations[lineStationsByLineIdArray[lid][i]].Station);
			td.appendChild(ttext);
			tr.appendChild(td);									
			tbody.appendChild(tr);	
			old = stations[lineStationsByLineIdArray[lid][i]].Station;
			row++;
		}
	}	// for i	
	tb.cellPadding = 1;
	tb.cellSpacing = 0;	
	tb.appendChild(tbody);	
}	// showLineCourse()

function showLineCourseForm(did, tid)  { // Dialog-Formular fr Linienverlauf
	// alert('showLineCourseForm()');
	var i;
	var fm;	// Formular
	var newOpt;
		
	this.showLineCourseFormNewLine = function()	{
		// alert('showLineCourseFormNewLine()');		
		var lid = document.fmLines.sbLines.options[document.fmLines.sbLines.selectedIndex].value;
		showLineCourse(lid, tid);
	}	//	showLineCourseFormNewLine()
	
	// Formular erstellen...
	fm = '<form name="fmLines" id="fmLines">';
	fm += '<strong>' + actLanguageText.line + ':</strong>';
	fm += '<select name="sbLines"  id="sbLines" onChange="showLineCourseFormNewLine()">';
	fm += '</select>';
	fm += '</form>';
	document.getElementById(did).innerHTML = fm;

	
	// Formularelemente fllen...
  for (i=0; i<lines.length; i++) {	
    newOpt = new Option(lines[i].Line, lines[i].ID, false, false); 
    document.fmLines.sbLines.options[i] = newOpt;
  }
  if (document.fmLines.sbLines.length > 0) {
  	document.fmLines.sbLines.selectedIndex = 0;
  }
  
  showLineCourseFormNewLine();
	
}	// showLineCourseForm()


