/*************************************************/
/* PTraffic - Javascript-Library                 */
/*                                               */
/* ptraffic_timetable.js                         */
/* Fahrplan-Funktionen                           */
/* fr alle PTraffic-Versionen                   */
/*                                               */
/* Version 0.8                                   */
/* ptraffic_timetable.js: Version 0.8            */
/*                                               */
/* Copyright by Jrg Siebrands, Germany, 2018    */
/*************************************************/

/* Array mit Standardfarben fr den Bildfahrplan	*/
var grapicalScheduleColors = new Object();   // Farben-Array fr Bildfarhplan  
grapicalScheduleColors["bgColor"]							= "white";
grapicalScheduleColors["lineColor1"] 					= "green";
grapicalScheduleColors["lineColor2"] 					= "blue";
grapicalScheduleColors["lineColorStart1"] 		= "red";
grapicalScheduleColors["lineColorStart2"] 		= "red";
grapicalScheduleColors["lineColorHalt1"] 			= "green";
grapicalScheduleColors["lineColorHalt2"] 			= "blue";
grapicalScheduleColors["lineColorEnd1"] 			= "black";
grapicalScheduleColors["lineColorEnd2"] 			= "black";
grapicalScheduleColors["stationLine"] 				= "gray";
grapicalScheduleColors["timeLine"] 						= "gray";
grapicalScheduleColors["timeStepLine"] 				= "gray";
grapicalScheduleColors["timeText"] 						= "black";
grapicalScheduleColors["activeStationText"] 	= "black";
grapicalScheduleColors["inactiveStationText"]	= "red";	

/* Wandelt Minuten-Wert m in Zeitstring im Format "HH:MM" um (Rckgabewert) */
function minutesToTimeString(m)	{
	var stunde, minute;
	var s;
	stunde = Math.floor(m/ 60);
	minute = m - (stunde * 60);
	stunde = ((stunde > 23) ? stunde - 24 : stunde); 
	s = ((stunde < 10) ? "0" + stunde : stunde);
	s = s + ":" + ((minute < 10) ? "0" + minute : minute);
	return s;
}

/* gibt Minutenwert der bergebnene Zeit t zurck */
function getMinutesFromTime(t)	{
	var tp;  // fr typeof
	var m;   // fr Minuten
	tp = typeof t;
	switch (tp)	{
		case "string"	:	// Zeitstring HH:MM oder Minuten						
			if ( (t.length > 2) && (isNaN(t.substr(2,1))) ) {  // lnge als 2 Zeichen und keine Ziffer an 3. Stelle	
				m = parseInt(t.substr(0, 2) * 60) + parseInt(t.substr(3, 2));  // Std. * 60 + Min.			
			} else {  // Ziffer an 3. Stelle
				if (isNaN(t))	{	// wird nicht als Zahl erkannt
					m = 0;  		// 0 als Ersatzwert
				} else {  // Zahl
					m = parseInt(t);
				}
			}	
			break;
		case "number"	: // Zeit in Minuten (Stunden * 60 + Minuten)
			m = t;		
			break;
		case "object"	:	// Datums-Objekt
			m = t.getHours() * 60 + t.getMinutes();	// Std. * 60 + Min.
			break;
		default	:		// anderer Typ -> 0 Uhr bis 23:59 Uhr
			m = 0;
			break;
	}  
	return m; 	
}

/* gibt Interval in Minuten fr bergebene Interval-ID zurck; Rckgabe von -1 wenn nicht vorhanden */
function getInterval(iad)	{
	// alert("getInterval");
	var v = intervals[intervalsByIdArray[iad]];
	if (v != undefined) {
		return intervals[intervalsByIdArray[iad]].Interval;
	} else {
		return -1;
	}	
}	

/* gibt zugehrige LineConnection-ID zurck - wenn nicht gefunden wird -1 zurckgegeben */
function getLineConnectionId(lid, dgid, direction)	{		// gibt passende ID aus lineConnections zurck
	// alert("getLineConnectionId");
	var i;
  var lcid = -1;
	for (i=0; i<lineConnections.length; i++)	{
		if ((lineConnections[i].LineID == lid) && (lineConnections[i].DayGroupID == dgid) && (lineConnections[i].Direction == direction))	{
			lcid = lineConnections[i].ID;
			i = lineConnections.length;	// Schleifenabbruch
		}
	}
	return lcid;
}

/* Zeigt Fahrplan fr eine Linie, Tag-Gruppe und Richtung in Tabelle */
function showTimetable(lid, dgid, direction, tid, optPar1)	{	
	// alert("showTimetable");  
  var lineConnectionID = getLineConnectionId(lid, dgid, direction);
  var tb = document.getElementById(tid);
  var cbFunc = ((arguments.length > 4) && (typeof arguments[arguments.length-1] == "function")) ? arguments[arguments.length-1] : undefined;


	this.showTimetableTTC = function (t)	{
		var i;
		// alert("showTimetableTTC");		
	  tb.tBodies[0].rows[0].cells[0].innerHTML = '<b>' + getLineName(lid) + '</b>'; 
	  for (i=1; i<t.length; i++) {
	    tb.tBodies[0].rows[i].cells[0].innerHTML = '<b>' + t[i][0] + '</b>';
	    tb.tBodies[0].rows[i].cells[0].bgColor = "#CCCCFF";
	  }
	  tb.style.visibility = "visible"; 			
		if (cbFunc !== "undefined")	{	
	 		cbFunc();	// zur Callback-Funktion gehen
	 	}			  	  	  
	}	// this.showTimetableTTC()

	this.showTimetableTT = function (t)	{
  	// alert("showTimeTableTT");	 	 		  	
	  var i,j,k;
	  var a = new Array();
	  var newTR, newTD, newTDText;
	  var stunde, minute, feld;	  
	  publicSQL.htmlTableDelete(tb);
	  document.getElementById(tid).style.visibility = "hidden";
	  for (i=0; i<t[1].length; i++) {
	    newTR = document.getElementById(tid).insertRow(i);
	    newTD = document.createElement("td");
	    newTDtext = document.createTextNode("");
	    newTD.appendChild(newTDtext);
	    newTR.appendChild(newTD); 
	    for (j=1; j<t.length; j++) {
	      newTD = document.createElement("td");
	      if ( (i>0) && ((i % 2) == 0) ) {
	        newTD.bgColor = "#F0F0F0";
	      } else {
	        newTD.bgColor = "#E0E0E0"; 
	      }
	      if (i == 0) {
	        feld = t[j][i]; 
	        newTD.bgColor = "#CCCCFF"; 
	      } else {
	        if (t[j][i] > -1) {
	          stunde = Math.floor(t[j][i] / 60);
	          minute = t[j][i] - (stunde * 60);
	          stunde = ((stunde > 23) ? stunde - 24 : stunde); 
	          feld = ((stunde < 10) ? "0" + stunde : stunde);
	          feld = feld + ":" + ((minute < 10) ? "0" + minute : minute);
	        } else if (t[j][i] == -1) {
	          feld = ""; 
	        } else if (t[j][i] < -1) {
	          if (t[j][i] > -1000) {
	            // feld = "alle " + oInterval[Math.abs(t[j][i])] + " Min.";
	            feld = actLanguageText.interval_minutes_before + " " + getInterval(Math.abs(t[j][i])) + " " + actLanguageText.interval_minutes_after;	// Math.abs weil im Fahrplan Minus-Werte fr Interval-ID benutzt werden
	            k = i+1;
	            newTD.bgColor = "#E8E8E8";
	            newTD.style.textAlign = "center";
	            a[j] = newTD;
	            while ( (k <t[1].length) && (t[j][k] == t[j][i]) ) {
	              t[j][k] = -1000 - i;
	              k++;
	            }
	          } else {
	            a[j].rowSpan++;
	          }
	        } 
	      }
	      if (t[j][i] > -1000) {
	        newTDtext = document.createTextNode(feld);
	        newTD.appendChild(newTDtext);
	        newTR.appendChild(newTD); 
	      }
	    }
	  }
	  publicSQL.query('select s.Station from ttc_' + lid + ' t, stations s where t.StationID = s.ID and t.DayGroupID = ' + dgid + ' and t.Direction = ' + direction + ' order by t.Position', 'showTimetableTTC');  		  	  	
	}	// this.showTimetableTT()
	
  publicSQL.query('select * from tt_' + lineConnectionID, 'showTimetableTT');    	
}	// showTimetable()

// showTimetableChangeLine()

// showTimetableChangeDays()

// showTimetableChangeDirection()

// showTimetableStart()

/* Erstellt Formular mit Auswahlmaske fr anzuzeigenden Fahrplan	*/
function showTimetableForm(did, tid, optPar1)	{	
	// alert("showTimetableForm");			
	var i, old;
	var first = false;
	var fm;	// Formular
  var newOpt;
  var lid;
  // var lineId, lineName, dayGroupId, direction;
  
  // this.showTimetableFormSetLines()	{		// Linien-Auswahlbox fllen
  this.showTimetableFormStart  = function()	{		// Anzeige	
  	 		
  	// alert("showTimetableFormStart");
		showTimetable(	document.fmSelect.sbLines.options[document.fmSelect.sbLines.selectedIndex].value,
										document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value, 
										document.fmSelect.sbDirection.options[document.fmSelect.sbDirection.selectedIndex].value, tid, optPar1);
	}
	
	this.showTimetableFormNewDir = function()	{		
		// alert('showTimetableFormNewDir()');					
		var i;
		var neuer;
	  var alt = 0;		
		var wert;
		var lid = document.fmSelect.sbLines.options[document.fmSelect.sbLines.selectedIndex].value;  // aktuelle Linie			
		document.fmSelect.sbDirection.length = 0;
		for (i=0; i<lineConnectionsByLineIdArray[lid].length; i++) {
			if (document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value == lineConnections[lineConnectionsByLineIdArray[lid][i]].DayGroupID)  {  // richtige DayGroup
				wert = lineConnections[lineConnectionsByLineIdArray[lid][i]].Direction;			
	    	if (wert != alt) {			
					neuer = new Option(wert, wert, false, false);
					document.fmSelect.sbDirection.options[document.fmSelect.sbDirection.length] = neuer;
				}
	    	alt = wert;
	    }
		}
		document.fmSelect.sbDirection.selectedIndex = 0;
	  // direction = document.fmSelect.sbDirection.options[document.fmSelect.sbDirection.selectedIndex].value;					
	}	// showTimetableFormNewDir()	
	
	/* Wochentage-Auswahl */
	this.showTimetableFormNewDirAndDays = function()	{		
		// alert('showTimetableFormNewDirAndDays()');
		var i, j;	  
	  var wert;
	  var alt = 0;
	  var neuer;
		var lid = document.fmSelect.sbLines.options[document.fmSelect.sbLines.selectedIndex].value;  // aktuelle Linie	  
	  document.fmSelect.sbDays.length = 0; 
	  for (i=0; i<lineConnectionsByLineIdArray[lid].length; i++) {
	    wert = lineConnections[lineConnectionsByLineIdArray[lid][i]].DayGroupID;
	    if (wert != alt) {
	    	wert = parseInt(wert);
	      neuer = new Option(dayGroups[dayGroupsByIdArray[wert]].Text, wert, false, false); 
	      document.fmSelect.sbDays.options[document.fmSelect.sbDays.length] = neuer; 
	    }
	    alt = wert;
	  }
	  // daygroupID = document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value; 
	  // publicSQL.query('select lc.Direction from line_connections lc where lc.LineID = ' + lineID + ' and lc.DayGroupID = ' + daygroupID + ' order by lc.Direction', 'newDir'); 		
	  showTimetableFormNewDir();		
	}	// showTimetableFormNewDirAndDays()		
	
	
	// alert(actLanguageText.line + "  " + actLanguageText.operating_days + "  " + actLanguageText.direction);
	// Formular erstellen
	fm = '<form name="fmSelect" id="fmSelect">';
	fm += '<p>';
	// <p style="white-space:nowrap">
	fm += '<strong>' + actLanguageText.line + ':</strong>';
	// fm += '<select name="sbLines" id="sbLines" onChange="showTimetableChangeLine();">';
	fm += '<select name="sbLines" id="sbLines" onChange="showTimetableFormNewDirAndDays();">';
	fm += '</select> ';
	fm += '<strong>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' + actLanguageText.operating_days + ':</strong> '; 
  // fm += '<select name="sbDays" id="sbDays" onChange="showTimetableChangeDays()">';
  fm += '<select name="sbDays" id="sbDays" onChange="showTimetableFormNewDir()">';
  fm += '</select> ';
  fm += '<strong>&nbsp;&nbsp;&nbsp;&nbsp;' + actLanguageText.direction + ':</strong>';
  // fm += '<select name="sbDirection" id="sbDirection" onChange="showTimetableChangeDirection()">';
  fm += '<select name="sbDirection" id="sbDirection">';
  fm += '</select>';
  fm += '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
  fm += '<input name="btStart" id="btStart" onClick="showTimetableFormStart();" value="' + actLanguageText.start_for_button + '" type="button">';
  fm += '</p>';
	fm += '</form>';
	document.getElementById(did).innerHTML = fm;	
	
	/* Formularelemente fllen  */

	
	// Linen-Auswahl...
  for (i=0; i<lines.length; i++) {	
    newOpt = new Option(lines[i].Line, lines[i].ID, false, false); 
    document.fmSelect.sbLines.options[i] = newOpt;
  }
  document.fmSelect.sbLines.selectedIndex = 0;
  lid = document.fmSelect.sbLines.options[document.fmSelect.sbLines.selectedIndex].value;
  // lineName = document.fmSelect.sbLines.options[document.fmSelect.sbLines.selectedIndex].text; 

  // Fahrtage- und Richtungs-Auswahl..
	old = -1;
  for (i=0; i<lineConnectionsByLineIdArray[lid].length; i++)	{
  	if (lineConnections[lineConnectionsByLineIdArray[lid][i]].DayGroupID != old)	{		// neue DayGroup
  		newOpt = new Option(dayGroups[ dayGroupsByIdArray[ lineConnections[ lineConnectionsByLineIdArray[lid][i] ].DayGroupID ]].Text, 
  											  dayGroups[ dayGroupsByIdArray[ lineConnections[ lineConnectionsByLineIdArray[lid][i] ].DayGroupID ]].ID, false, false);   											  
    	document.fmSelect.sbDays.options[i] = newOpt;
    	first = (old == -1);  // ist nur bei erster DayGroup -1
 	    old = lineConnections[lineConnectionsByLineIdArray[lid][i]].DayGroupID; 	    
    }
    if (first == true)	{	// Richtung fr erste DayGroup
  		newOpt = new Option(lineConnections[ lineConnectionsByLineIdArray[lid][i] ].Direction, 
  											  lineConnections[ lineConnectionsByLineIdArray[lid][i] ].Direction, false, false); 
    	document.fmSelect.sbDirection.options[i] = newOpt;    	
    }
  }
  document.fmSelect.sbDays.selectedIndex = 0;
  document.fmSelect.sbDirection.selectedIndex = 0;  
  // dayGroupId = document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value;
  // direction = document.fmSelect.sbDirection.options[document.fmSelect.sbDirection.selectedIndex].value;

	// Tabelle fr Anzeige
	// alt - wird in tid bergeben: document.getElementById(did).innerHTML += "<table id='timeTable' name='timeTable' border=1></table>";
  		  
  /*
  publicSQL.query('select lc.DayGroupID, lc.Direction, dg.Text from line_connections lc, daygroups dg where lc.LineID = ' 
  								+ lineID + ' and lc.DayGroupID = dg.ID order by lc.DayGroupID, lc.Direction', 'newDirAndDays'); 
  								*/		
}	// showTimetableForm()

function showCurrentRides(lid, dgid, direction, tid, optPar1)	{	
	// alert("showCurrentRides");
  var lineConnectionID = getLineConnectionId(lid, dgid, direction);
  var tb = document.getElementById(tid);
  var cbFunc = ((arguments.length > 4) && (typeof arguments[arguments.length-1] == "function")) ? arguments[arguments.length-1] : undefined;	  

	this.showCurrentRidesTT = function(t) {
		// alert("showCurrentRidesTT()");
		var i,j,k,m;
		var alti;
	  var v1, v2, v3;
	  var idx1, idx2;
	  var a;
	  var aktTR, newTD, newTDText;
	  var stunde, minute, feld;
	  var aktMinutes;
		var startZeitInterval, startZeitInterval2, endZeitInterval ;	// Fr Interval-Vorgnger-Zeit bzw. Nachfolger-Zeit die nicht direkt vor Interval-Spalte steht
		var minIntervalPos;		// Index from minInterval
		var minInterval;
		var ivTemp;  // Interval temporr speichern
	  var jetzt = new Date(); 
		var prev, next, prev2, next2;	
	  aktMinutes = jetzt.getHours() * 60 + jetzt.getMinutes();
	  i = 1;
	  while (i < t.length) {
			j = 1; 
		  v1 = -1; 
		  v2 = -1;
		  while (j < t[i].length) {
			  v1 = t[i][j];
			  if (v1 != -1) {
					idx1 = j;
			  j = t[i].length;
				} else {
			 		j++;
				}
			}
			j = t[i].length-1;
			while (j > 0) {
				v2 = t[i][j];
				if (v2 != -1) {
					idx2 = j;
					j = 0;
				} else {
					j--;
				}
		  }
		  if ( (v1 < -1) || (v2 < -1) ) {
				if ( !( (aktMinutes < t[i-1][idx1]) && (aktMinutes > t[i-1][idx2]) && (aktMinutes < t[i+1][idx1]) && (aktMinutes > t[i+1][idx2]) ) ) {
			  	minInterval = 10000;
				  for (k = 1; k < t[0].length; k++) {
						v3 = t[i][k];
						if (v3 < -1) {
							// if (oInterval[Math.abs(v3)] < minInterval) {
							ivTemp = getInterval(Math.abs(v3));
							if (ivTemp < minInterval) {																			
								// minInterval = oInterval[Math.abs(v3)];
								minInterval = ivTemp;
								minIntervalPos = v3;				
								idx1 = k;	// neuer Wert fr idx1 mit niedrigster Interval-Zeit										
							}
						}
					}
				  if (minInterval < 10000) {
						addInterval = 0;
						alti = i-1; 
	
						// Vorgner von Interval suchen
						j = i-1;
						while (j > 0)	{
							if (t[j][idx1] > -1)	{		// Zeit gefunden	
								prev = j;
								j = 0;
							}
							j--;
						}
						
						// Nachfolger von Interval suchen
						j = i+1;
						while (j < t.length)	{
							if (t[j][idx1] > -1)	{		// Zeit gefunden	
								next = j;
								j = t.length;
							}
							j++;
						}						
						
						while ((t[i-1][idx1] + minInterval) < (t[next][idx1])) {	// Zwischenwerte berechnen					
							a = new Array;	// fr Werte fr neu einzufgende Spalte
							a.push(0);
							addInterval += minInterval; 	// Aktueller Addier-Wert fr vorigen Zeitwert
							for (k = 1; k < t[0].length; k++) { 		// fr alle Zeilen
	
								if (t[i][k] > -2)	{ 
									a.push(-1) 
								} else {
	
									// Vorgner von Interval suchen
									j = alti;
									while (j > 0)	{
										if (t[j][k] > -1)	{		// Zeit gefunden	
											prev2 = j;
											j = 0;
											
											// Start-Intervall-Zeit fr vom Vorgnger berechnen
											startZeitInterval2 = 0;
											m = 1;
											while (m < t[0].length) {		// for all stations, bis minInterval gefunden
												if ((t[prev2][m] > -1) && (t[i][m] == minIntervalPos) && (t[i-1][m] > -1))	{		// Zeit fr Vorgnger, fr Interval-Wert und Zeit fr direkten Vorgnger vorhanden
													startZeitInterval2 = t[alti][m] - t[prev2][m];		// Zeit des direkter Vorgnger-Feldes - Zeit des aktuellen Vorgnger-Feldes
													m = t[0].length;
												}
												m++;
											}										
											
										}
										j--;
									}						
	
									// Nachfolger suchen
									j = i+1;
									while (j < t.length)	{
										if (t[j][k] > -1)	{		// Zeit gefunden	
											next2 = j;
											j = t.length;
										}	// if
										j++;
									}	// while j < t.length								
								
									// if ( ( (startZeitInterval2 + addInterval) % oInterval[Math.abs(t[i][k])] ) == 0) {	// erster Teil nicht ntig(?) - wenn Interval-Zeit fr Zeile(bzw. Feld) vorhanden
									if ( ( (startZeitInterval2 + addInterval) % getInterval(Math.abs(t[i][k])) ) == 0) {	// erster Teil nicht ntig(?) - wenn Interval-Zeit fr Zeile(bzw. Feld) vorhanden
		 								if (t[prev][k] != -1)	{  
											a.push(t[prev2][k] + startZeitInterval2 + addInterval)  
										} else  {	
											//	'kommt normalerweise nicht vor!';										
											a.push(-1)										
										}	
									} else {
										a.push(-1);										
									} 	// if
								}							
							}	// for i
							t.splice(i, 0, a); 
							i++;	
							
							// Nachfolger von Interval suchen
							j = i+1;
							while (j < t.length)	{
								if (t[j][idx1] > -1)	{		// Zeit gefunden	
									next = j;
									j = t.length;
								}
								j++;
							}					
																			
						} // while
						t.splice(i, 1);
					}
				} 
			}
			i++;
		}
	  i = 1;
	  while (i < t.length) {
			j = 1; 
			v1 = -1; 
			v2 = -1;
			while (j < t[i].length) {
				v1 = t[i][j];
				if (v1 != -1) {
					idx = j;
					j = t[i].length;
				} else {
					j++;
				}
			}
			j = t[i].length-1;
			while (j > 0) {
				v2 = t[i][j];
				j = (v2 != -1) ? 0 : j-1;
			}
			if ((aktMinutes < v1) || (aktMinutes > v2)) {
				t.splice(i,1);
			} else {
				i++;
			}
		}

		for (i=0; i<t[1].length; i++) {
			aktTR = document.getElementById(tid).tBodies[0].rows[i];
			for (j=1; j<t.length; j++) {
				newTD = document.createElement("td");
				if ( (i>0) && ((i % 2) == 0) ) {
					newTD.bgColor = "#F0F0F0";
				} else {
					newTD.bgColor = "#E0E0E0"; 
				}
				if (i == 0) {
					feld = j;
					newTD.bgColor = "#CCCCFF"; 
				} else {
					if (t[j][i] > -1) {
						stunde = Math.floor(t[j][i] / 60);
						minute = t[j][i] - (stunde * 60);
	   				stunde = ((stunde > 23) ? stunde - 24 : stunde); 
	   				feld = ((stunde < 10) ? "0" + stunde : stunde);
	   				feld = feld + ":" + ((minute < 10) ? "0" + minute : minute);
	   			} else if (t[j][i] == -1) {
	   				feld = ""; 
	   			} else if (t[j][i] < -1) {
	   				if (t[j][i] > -1000) {
	   					// feld = "alle " + oInterval[Math.abs(t[j][i])] + " Min.";
	   					feld = "alle " + getInterval(Math.abs(t[j][i])) + " Min.";
	   					k = i+1;
	   					newTD.bgColor = "#E8E8E8";
	   					newTD.style.textAlign = "center";
	   					a[j] = newTD;
	   					while ( (k <t[1].length) && (t[j][k] == t[j][i]) ) {
	   						t[j][k] = -1000 - i;
	   						k++;
	   					}
	   				} else {
	   					a[j].rowSpan++;
	   				}
	   			} 
	   		}
	   		if (t[j][i] > -1000) {
	   			newTDtext = document.createTextNode(feld);
	   			newTD.appendChild(newTDtext);
	   			aktTR.appendChild(newTD); 
	   		}
	   	}
	  }
	  
	  tb.style.visibility = "visible"; 			
		if (cbFunc !== "undefined")	{	
	 		cbFunc();	// zur Callback-Funktion gehen
	 	}			  	  	  	  
	  
	}	// showCurrentRidesTT()
   
  this.showCurrentRidesTTC = function(t)	{  	
	  // alert("showCurrentRidesTTC()");
		var i;
		var newTR, newTD, newTDText;
	  publicSQL.htmlTableDelete(tb);
	  document.getElementById(tid).style.visibility = "hidden";		
		newTR = tb.insertRow(i); 
		newTD = document.createElement("td"); 
		newTDtext = document.createTextNode(""); 
		newTD.appendChild(newTDtext);
		newTD.innerHTML = '<b>' + getLineName(lid) + '</b>';
		newTR.appendChild(newTD); 
		for (i=1; i<t.length; i++) {
			newTR = tb.insertRow(i); 
			newTD = document.createElement("td"); 
			newTDtext = document.createTextNode(""); 
			newTD.appendChild(newTDtext);
			newTD.innerHTML = '<b>' + t[i][0] + '</b>';
			newTD.bgColor = "#CCCCFF";
			newTR.appendChild(newTD); 
		}
		publicSQL.query('select * from tt_' + lineConnectionID, 'showCurrentRidesTT');
	}	// this.showCurrentRidesTTC()
  
	publicSQL.query('select s.Station from ttc_' + lid + ' t, stations s where t.StationID = s.ID and t.DayGroupID = ' + dgid + ' and t.Direction = ' 
									+ direction + ' order by t.Position'	, 'showCurrentRidesTTC');
  
	
}	// function showTimetable()	

function showCurrentRidesForm(did, tid, optPar1)	{	
	// alert("showCurrentRidesForm()");	
	var i, old;
	var first = false;
	var fm;	// Formular
  var newOpt;
  // var lineId, lineName, dayGroupId, direction;
 
  // this.showTimetableFormSetLines()	{		// Linien-Auswahlbox fllen
  this.showCurrentRidesFormStart  = function()	{		// Anzeige		
  	// alert("showCurrentRidesFormStart");
		showCurrentRides(	document.fmSelect.sbLines.options[document.fmSelect.sbLines.selectedIndex].value,
											document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value, 
											document.fmSelect.sbDirection.options[document.fmSelect.sbDirection.selectedIndex].value, tid, optPar1);
	} 	// this.showCurrentRidesFormStart() 	

	this.showCurrentRidesFormNewDir = function()	{		
		// alert('showCurrentRidesFormNewDir()');					
		var i;
		var neuer;
	  var alt = 0;		
		var wert;
		var lid = document.fmSelect.sbLines.options[document.fmSelect.sbLines.selectedIndex].value;  // aktuelle Linie			
		document.fmSelect.sbDirection.length = 0;
		for (i=0; i<lineConnectionsByLineIdArray[lid].length; i++) {
			if (document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value == lineConnections[lineConnectionsByLineIdArray[lid][i]].DayGroupID)  {  // richtige DayGroup
				wert = lineConnections[lineConnectionsByLineIdArray[lid][i]].Direction;			
	    	if (wert != alt) {			
					neuer = new Option(wert, wert, false, false);
					document.fmSelect.sbDirection.options[document.fmSelect.sbDirection.length] = neuer;
				}
	    	alt = wert;
	    }
		}
		document.fmSelect.sbDirection.selectedIndex = 0;
	  // direction = document.fmSelect.sbDirection.options[document.fmSelect.sbDirection.selectedIndex].value;					
	}	// showCurrentRidesFormNewDir()	
	
	/* Wochentage-Auswahl */
	this.showCurrentRidesFormNewDirAndDays = function()	{		
		// alert('showCurrentRidesFormNewDirAndDays()');
		var i, j;	  
	  var wert;
	  var alt = 0;
	  var neuer;
		var lid = document.fmSelect.sbLines.options[document.fmSelect.sbLines.selectedIndex].value;  // aktuelle Linie	  
	  document.fmSelect.sbDays.length = 0; 
	  for (i=0; i<lineConnectionsByLineIdArray[lid].length; i++) {
	    wert = lineConnections[lineConnectionsByLineIdArray[lid][i]].DayGroupID;
	    if (wert != alt) {
	    	wert = parseInt(wert);
	      neuer = new Option(dayGroups[dayGroupsByIdArray[wert]].Text, wert, false, false); 
	      document.fmSelect.sbDays.options[document.fmSelect.sbDays.length] = neuer; 
	    }
	    alt = wert;
	  }
	  // daygroupID = document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value; 
	  // publicSQL.query('select lc.Direction from line_connections lc where lc.LineID = ' + lineID + ' and lc.DayGroupID = ' + daygroupID + ' order by lc.Direction', 'newDir'); 		
	  showCurrentRidesFormNewDir();		
	}	// showCurrentRidesFormNewDirAndDays()	
	
	/* nicht ntig, da nur ..NewDirAndDays() aufgerufen wird
	this.showCurrentRidesFormChangeLine = function()	{			
		alert('showCurrentRidesFormChangeLine()');
		...
	}	// showCurrentRidesFormChangeLine()		*/
	
	/* nicht ntig, da nur ..NewDir() aufgerufen wird
	this.showCurrentRidesFormChangeDays = function()	{
		alert('showCurrentRidesFormChangeDays');
	}	// showCurrentRidesFormChangeDays()		*/
  
	// Formular erstellen
	fm = '<form name="fmSelect" id="fmSelect">';
	fm += '<p>';
	// <p style="white-space:nowrap">
	fm += '<strong>' + actLanguageText.line + ':</strong>';
	// fm += '<select name="sbLines" id="sbLines" onChange="showTimetableChangeLine();">';
	fm += '<select name="sbLines" id="sbLines" onChange="showCurrentRidesFormNewDirAndDays();">';
	fm += '</select> ';
	fm += '<strong>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' + actLanguageText.operating_days + ':</strong> '; 
  // fm += '<select name="sbDays" id="sbDays" onChange="showTimetableChangeDays()">';
  fm += '<select name="sbDays" id="sbDays" onChange="showCurrentRidesFormNewDir()">';
  fm += '</select> ';
  fm += '<strong>&nbsp;&nbsp;&nbsp;&nbsp;' + actLanguageText.direction + ':</strong>';
  // fm += '<select name="sbDirection" id="sbDirection" onChange="showTimetableChangeDirection()">';
  fm += '<select name="sbDirection" id="sbDirection">';
  fm += '</select>';
  fm += '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
  fm += '<input name="btStart" id="btStart" onClick="showCurrentRidesFormStart();" value="' + actLanguageText.start_for_button + '" type="button">';
  fm += '</p>';
	fm += '</form>';
	document.getElementById(did).innerHTML = fm;	
	
	/* Formularelemente fllen  */
	
	// Linen-Auswahl...
  for (i=0; i<lines.length; i++) {	
    newOpt = new Option(lines[i].Line, lines[i].ID, false, false); 
    document.fmSelect.sbLines.options[i] = newOpt;
  }
  document.fmSelect.sbLines.selectedIndex = 0;
  // lineId = document.fmSelect.sbLines.options[document.fmSelect.sbLines.selectedIndex].value;
  // lineName = document.fmSelect.sbLines.options[document.fmSelect.sbLines.selectedIndex].text; 
  
  showCurrentRidesFormNewDirAndDays();  // Wochentage-Auswahl und davon abhngige Dialogfelder

	// Tabelle fr fr Anzeige
	document.getElementById(did).innerHTML += "<table id='timeTable' name='timeTable' border=1></table>";   
  
}	// showCurrentRidesForm()

/* zeigt Zeitraum-Fahrplan; */
/* stationPos	= Position der Station in Linienfhrung	*/
function showTimetablePeriod(lid, dgid, direction, stationPos, fromTime, toTime, tid, optPar1)	{
	// alert("showTimetablePeriod()");
  var lineConnectionID = getLineConnectionId(lid, dgid, direction);
  var fromMinutes, toMinutes;	// Erste und zweite Zeit in Minuten fr Zeitraum 
  var tb = document.getElementById(tid);
  var cbFunc = ((arguments.length > 7) && (typeof arguments[arguments.length-1] == "function")) ? arguments[arguments.length-1] : undefined; 
	   
	this.showTimetablePeriodTT = function(t) {
		// alert("this.showTimetablePeriodTT()");		
		var i,j,k,m;
		var alti;
	  var v1, v2, v3;
	  var idx1, idx2;
	  var a;
	  var aktTR, newTD, newTDText;
	  var stunde, minute, feld;
	 // var aktMinutes1 = 0, aktMinutes2 = 0;
	  var minInterval, addInterval;
		var startZeitInterval, startZeitInterval2, endZeitInterval ;	// Fr Interval-Vorgnger-Zeit bzw. Nachfolger-Zeit die nicht direkt vor Interval-Spalte steht
		var minIntervalPos;		// Index from minInterval
	  var jetzt = new Date(); 
		var prev, next, prev2, next2;
		var ivTemp;		// temporr fr Interval
	  // ist jetzt fromMinutes: aktMinutes1 = ((document.fmSelect.sbHours1[document.fmSelect.sbHours1.selectedIndex].value * 60) + (document.fmSelect.sbMinutes1[document.fmSelect.sbMinutes1.selectedIndex].value * 1));
	  // ist jetzt toMinutes: aktMinutes2 = ((document.fmSelect.sbHours2[document.fmSelect.sbHours2.selectedIndex].value * 60) + (document.fmSelect.sbMinutes2[document.fmSelect.sbMinutes2.selectedIndex].value * 1));
	  if (stationPos > (t[0].length-1)) {	// stationPos zu gro
	  	stationPos = 0;
	  }
	  i = 1;
	  while (i < t.length) {
			j = 1; 
		  v1 = -1; 
		  v2 = -1;	
			if (stationPos == 0)	{		// alle Stationen
			  while (j < t[i].length) {
				  v1 = t[i][j];
				  if (v1 != -1) {
						idx1 = j;
					  j = t[i].length;
					} else {
				 		j++;
					}
				}
				j = t[i].length-1;
				while (j > 0) {
					v2 = t[i][j];
					if (v2 != -1) {
						idx2 = j;
						j = 0;
					} else {
						j--;
					}
			  }	
			}	else	{
				// alt:
				idx1 = stationPos;
				idx2 = idx1;
				v1 = t[i][idx1];
				v2 = v1;
			}
		  if ( (v1 < -1) || (v2 < -1) ) {
				// if ( !( (aktMinutes1 < t[i-1][idx1]) && (aktMinutes2 > t[i-1][idx2]) && (aktMinutes1 > t[i+1][idx1]) && (aktMinutes2 < t[i+1][idx2]) ) ) {
				if ( !( (fromMinutes < t[i-1][idx1]) && (toMinutes > t[i-1][idx2]) && (fromMinutes > t[i+1][idx1]) && (toMinutes < t[i+1][idx2]) ) ) {
			  	minInterval = 10000;
				  for (k = 1; k < t[0].length; k++) {
						v3 = t[i][k];
						if (v3 < -1) {
							ivTemp = getInterval(Math.abs(v3));
							// if (oInterval[Math.abs(v3)] < minInterval) {
							if (ivTemp < minInterval) {
								// minInterval = oInterval[Math.abs(v3)];
								minInterval = ivTemp;
								minIntervalPos = v3;
								idx1 = k;	// neuer Wert fr idx1 mit niedrigster Interval-Zeit
							}
						}
					}
				  if (minInterval < 10000) {
						addInterval = 0;
						alti = i-1; 
	
						// Vorgnger von Interval suchen
						j = i-1;
						while (j > 0)	{
							if (t[j][idx1] > -1)	{		// Zeit gefunden	
								prev = j;
								j = 0;														
							}
							j--;
						}
	
							// Nachfolger von Interval suchen
						j = i+1;
						while (j < t.length)	{
							if (t[j][idx1] > -1)	{		// Zeit gefunden	
								next = j;
								j = t.length;
							}
							j++;
						}	
	
						while ((t[i-1][idx1] + minInterval) < (t[next][idx1])) {	// Zwischenwerte berechnen				
							a = new Array;
							a.push(0);
							addInterval += minInterval; 
							for (k = 1; k < t[0].length; k++) {		// for all stations 
	
								if (t[i][k] > -2)	{ 
									a.push(t[i][k]);									
								} else {
	
									// Vorgner von Interval suchen
									j = alti;
									while (j > 0)	{
										if (t[j][k] > -1)	{		// Zeit gefunden	
											prev2 = j;
											j = 0;
											
											// Start-Intervall-Zeit fr vom Vorgnger berechnen
											startZeitInterval2 = 0;
											m = 1;
											while (m < t[0].length) {		// for all stations, bis minInterval gefunden
												if ((t[prev2][m] > -1) && (t[i][m] == minIntervalPos) && (t[i-1][m] > -1))	{		// Zeit fr Vorgnger, fr Interval-Wert und Zeit fr direkten Vorgnger vorhanden
													startZeitInterval2 = t[alti][m] - t[prev2][m];		// Zeit des direkter Vorgnger-Feldes - Zeit des aktuellen Vorgnger-Feldes
													m = t[0].length;
												}
												m++;
											}										
											
										}
										j--;
									}						
	
									// Nachfolger suchen
									j = i+1;
									while (j < t.length)	{
										if (t[j][k] > -1)	{		// Zeit gefunden	
											next2 = j;
											j = t.length;
										}	// if
										j++;
									}	// while j < t.length
									
	//								if ( (t[next2][k] > -1) && ( ( (startZeitInterval2 + addInterval) % oInterval[Math.abs(t[i][k])] ) == 0) ) {	// erster Teil nicht ntig(?) - wenn Interval-Zeit fr Zeile(bzw. Feld) vorhanden
									if ( ( (startZeitInterval2 + addInterval) % getInterval(Math.abs(t[i][k])) ) == 0) {	// erster Teil nicht ntig(?) - wenn Interval-Zeit fr Zeile(bzw. Feld) vorhanden
									// war wohl falsch: if ( ( (startZeitInterval2 + addInterval) % oInterval[Math.abs(t[i][k])] ) == 0) {	// erster Teil nicht ntig(?) - wenn Interval-Zeit fr Zeile(bzw. Feld) vorhanden
						 				if (t[prev2][k] != -1)	{  
											a.push(t[prev2][k] + startZeitInterval2 + addInterval)  
										} else  {	
											//	'kommt normalerweise nicht vor!';									
											a.push(-1)	
										}	
									} else {
										a.push(-1);										
									} 	// if
								}			
							}	// for k
							t.splice(i, 0, a); 
							i++;	
							
							// Nachfolger von Interval suchen
							j = i+1;
							while (j < t.length)	{
								if (t[j][idx1] > -1)	{		// Zeit gefunden	
									next = j;
									j = t.length;
								}
								j++;
							}						
							
							
						}	// while
						t.splice(i, 1);
					}
				} 
			}
			i++;				
		}
	  i = 1;
	   
	  while (i < t.length) {
			j = 1; 
			v1 = -1; 
			v2 = -1;
			if (stationPos == 0)	{		
				while (j < t[i].length) {
					v1 = t[i][j];
					if (v1 != -1) {
						idx = j;
						j = t[i].length;
					} else {
						j++;
					}
				}
				j = t[i].length-1;
				while (j > 0) {
					v2 = t[i][j];
					j = (v2 != -1) ? 0 : j-1;
				}	
			}	else	{
				// idx = document.fmSelect.sbStations.options[document.fmSelect.sbStations.selectedIndex].value;
				idx = stationPos;
				v1 = t[i][idx];		
				v2 = v1;
			}
			// if ((aktMinutes2 < v1) || (aktMinutes1 > v2)) {
			if ((toMinutes < v1) || (fromMinutes > v2)) {
				t.splice(i,1);
			} else {
				i++;
			}
		}
		for (i=0; i<t[1].length; i++) {
			// aktTR = document.getElementById("mytable").tBodies[0].rows[i];
			aktTR = document.getElementById(tid).tBodies[0].rows[i];
			for (j=1; j<t.length; j++) {
				newTD = document.createElement("td");
				if ((stationPos > 0) && (i == idx))	{
					newTD.bgColor = "#FEDCBA";			
				} else if ( (i>0) && ((i % 2) == 0) ) {
					newTD.bgColor = "#F0F0F0";
				} else {
					newTD.bgColor = "#E0E0E0"; 
				}
				if (i == 0) {
					feld = j;
					newTD.bgColor = "#CCCCFF"; 
				} else {
					if (t[j][i] > -1) {
						stunde = Math.floor(t[j][i] / 60);
						minute = t[j][i] - (stunde * 60);
	   				stunde = ((stunde > 23) ? stunde - 24 : stunde); 
	   				feld = ((stunde < 10) ? "0" + stunde : stunde);
	   				feld = feld + ":" + ((minute < 10) ? "0" + minute : minute);
	   			} else if (t[j][i] == -1) {
	   				feld = ""; 
	   			} else if (t[j][i] < -1) {
	   				if (t[j][i] > -1000) {
	   					// feld = "alle " + oInterval[Math.abs(t[j][i])] + " Min.";
	   					feld = actLanguage.interval_minutes_before + " " + getInterval(Math.abs(t[j][i])) + interval_minutes_after + " ";
	   					k = i+1;
	   					newTD.bgColor = "#E8E8E8";
	   					newTD.style.textAlign = "center";
	   					a[j] = newTD;
	   					while ( (k <t[1].length) && (t[j][k] == t[j][i]) ) {
	   						t[j][k] = -1000 - i;
	   						k++;
	   					}
	   				} else {
	   					a[j].rowSpan++;
	   				}
	   			} 
	   		}
	   		if (t[j][i] > -1000) {
	   			newTDtext = document.createTextNode(feld);
	   			newTD.appendChild(newTDtext);
	   			aktTR.appendChild(newTD); 
	   		}
	   	}
	  }				
	  tb.style.visibility = "visible"; 			
		if (cbFunc !== "undefined")	{	
	 		cbFunc();	// zur Callback-Funktion gehen
	 	}			  
	}	//	this.showTimetablePeriodTT()
	
	this.showTimetablePeriodTTC = function(t)	{  	
	  // alert("showTimetablePeriodTTC()");
	  document.getElementById(tid).style.visibility = "hidden";			  
		var i;
		var newTR, newTD, newTDText;
		publicSQL.htmlTableDelete(tb);
		newTR = tb.insertRow(i); 
		newTD = document.createElement("td"); 
		newTDtext = document.createTextNode(""); 
		newTD.appendChild(newTDtext);
		newTD.innerHTML = '<b>' + getLineName(lid) + '</b>';
		newTR.appendChild(newTD); 
		for (i=1; i<t.length; i++) {
			newTR = tb.insertRow(i); 
			newTD = document.createElement("td"); 
			newTDtext = document.createTextNode(""); 
			newTD.appendChild(newTDtext);
			newTD.innerHTML = '<b>' + t[i][0] + '</b>';
			newTD.bgColor = "#CCCCFF";
			newTR.appendChild(newTD); 
		}
		publicSQL.query('select * from tt_' + lineConnectionID, 'showTimetablePeriodTT');	
	}	// this.showTimetablePeriodTTC()  
	
	fromMinutes = getMinutesFromTime(fromTime);
	toMinutes 	= getMinutesFromTime(toTime);
	if (fromMinutes > toMinutes)	{  // 1. Zeit darf nicht grer wie 2. Zeit sein
		toMinutes = fromMinutes;
	}		
	
	publicSQL.query('select s.Station from ttc_' + lid + ' t, stations s where t.StationID = s.ID and t.DayGroupID = ' + dgid 
									+ ' and t.Direction = ' + direction + ' order by t.Position', 'showTimetablePeriodTTC');	
	
}	//	showTimetablePeriod()	{

function showTimetablePeriodForm(did, tid, optPar1)	{	
	// alert('showTimetablePeriodForm()');
	var i;
	// var first = false;
	var fm;	// Formular
  var newOpt;
	var neuer;
	var aktHours, aktMinutes;
  var jetzt = new Date(); 	  

  this.showTimetablePeriodFormStart  = function()	{		// Anzeige		
  	// alert("showTimetablePeriodFormStart"); 
 	  var m1, m2;
 	  
  	// korrigieren, wenn Startzeit > Endzeit...
	  m1 = (	(document.fmSelect.sbHours1[document.fmSelect.sbHours1.selectedIndex].value * 60) 
	  							+ (document.fmSelect.sbMinutes1[document.fmSelect.sbMinutes1.selectedIndex].value * 1));
	  m2 = (	(document.fmSelect.sbHours2[document.fmSelect.sbHours2.selectedIndex].value * 60) 
	  							+ (document.fmSelect.sbMinutes2[document.fmSelect.sbMinutes2.selectedIndex].value * 1));
		if (m1 > m2)	{
			document.fmSelect.sbHours2.selectedIndex = document.fmSelect.sbHours1.selectedIndex;
			document.fmSelect.sbMinutes2.selectedIndex = document.fmSelect.sbMinutes1.selectedIndex;
			m2 = m1;
		}	  	
  		
	 	showTimetablePeriod(document.fmSelect.sbLines.options[document.fmSelect.sbLines.selectedIndex].value,
												document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value, 
												document.fmSelect.sbDirection.options[document.fmSelect.sbDirection.selectedIndex].value,
												document.fmSelect.sbStations.options[document.fmSelect.sbStations.selectedIndex].value,   
												//parseInt(document.fmSelect.sbHours1.options[document.fmSelect.sbHours1.selectedIndex].value) * 60
												//+ parseInt(document.fmSelect.sbMinutes1.options[document.fmSelect.sbMinutes1.selectedIndex].value),
												m1,
												// parseInt(document.fmSelect.sbHours2.options[document.fmSelect.sbHours2.selectedIndex].value) * 60
												// + parseInt(document.fmSelect.sbMinutes2.options[document.fmSelect.sbMinutes2.selectedIndex].value),
												m2,
												tid, optPar1);  // Achtung: optPar1 steht fr Callback-Funktion und kann auch undefined sein
	} 	// this.showTimetablePeriodFormStart()       
  
	this.showTimetablePeriodFormNewStations = function(t)	{
		// alert('showTimetablePeriodFormNewStations()');
		var i;
		var neuer;
		var alt = "";
		document.fmSelect.sbStations.length = 0;
		// in PTraffic-Webandwndung global: stationPos = 0;
		// in PTraffic-Webanwendung global: stationName = "";
		neuer = new Option("[ALLE]", 0, false, false);
		document.fmSelect.sbStations.options[0] = neuer;
		for (i=1; i<t.length; i++) {
			if (alt != t[i][1])	{
				neuer = new Option(t[i][1], i, false, false);
 				document.fmSelect.sbStations.options[document.fmSelect.sbStations.length] = neuer;
				alt = t[i][1];
			} else {
				document.fmSelect.sbStations.options[document.fmSelect.sbStations.length-1].value = i;
			}
		}
		document.fmSelect.sbStations.selectedIndex = 0;
	}	// showTimetablePeriodFormNewStations()
	
	this.showTimetablePeriodFormNewDir = function()	{		
		// alert('showTimetablePeriodFormNewDir()');								
		var i;
		var neuer;
	  var alt = 0;		
		var wert;
		var direction;
		var lid  = document.fmSelect.sbLines.options[document.fmSelect.sbLines.selectedIndex].value;  // aktuelle Linie			
		var dgid = document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value;  // aktuelle Tag-Gruppe			
		document.fmSelect.sbDirection.length = 0;
		for (i=0; i<lineConnectionsByLineIdArray[lid].length; i++) {
			if (document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value == lineConnections[lineConnectionsByLineIdArray[lid][i]].DayGroupID)  {  // richtige DayGroup
				wert = lineConnections[lineConnectionsByLineIdArray[lid][i]].Direction;			
	    	if (wert != alt) {			
					neuer = new Option(wert, wert, false, false);
					document.fmSelect.sbDirection.options[document.fmSelect.sbDirection.length] = neuer;
				}
	    	alt = wert;
	    }
		}
		document.fmSelect.sbDirection.selectedIndex = 0;
		direction = document.fmSelect.sbDirection.options[document.fmSelect.sbDirection.selectedIndex].value;
		publicSQL.query('select t.Position, s.Station  from ttc_' + lid + ' t, stations s where t.StationID = s.ID and t.DayGroupID = ' + dgid + ' and t.Direction = ' + direction + ' order by t.Position'
										, 'showTimetablePeriodFormNewStations');	
	}	// showTimetablePeriodFormNewDir()	
	
	/* Wochentage-Auswahl */
	this.showTimetablePeriodFormNewDirAndDays = function()	{		
		// alert('showCurrentRidesFormNewDirAndDays()');
		var i, j;	  
	  var wert;
	  var alt = 0;
	  var neuer;
		var lid = document.fmSelect.sbLines.options[document.fmSelect.sbLines.selectedIndex].value;  // aktuelle Linie	  
	  document.fmSelect.sbDays.length = 0; 
	  for (i=0; i<lineConnectionsByLineIdArray[lid].length; i++) {
	    wert = lineConnections[lineConnectionsByLineIdArray[lid][i]].DayGroupID;
	    if (wert != alt) {
	    	wert = parseInt(wert);
	      neuer = new Option(dayGroups[dayGroupsByIdArray[wert]].Text, wert, false, false); 
	      document.fmSelect.sbDays.options[document.fmSelect.sbDays.length] = neuer; 
	    }
	    alt = wert;
	  }
	  // daygroupID = document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value; 
	  // publicSQL.query('select lc.Direction from line_connections lc where lc.LineID = ' + lineID + ' and lc.DayGroupID = ' + daygroupID + ' order by lc.Direction', 'newDir'); 		
	  showTimetablePeriodFormNewDir();		
	}	// shoTimetablePeriodFormNewDirAndDays()	  
  
	/* Formular erstellen */
	
	fm = '<form name="fmSelect" id="fmSelect">';
	fm += '<p>';
	// <p style="white-space:nowrap">
	fm += '<strong>' + actLanguageText.line + ':</strong> ';
	// fm += '<select name="sbLines" id="sbLines" onChange="showTimetableChangeLine();">';
	fm += '<select name="sbLines" id="sbLines" onChange="showTimetablePeriodFormNewDirAndDays();">';
	fm += '</select> ';
	fm += '<strong>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' + actLanguageText.operating_days + ':</strong> '; 
  // fm += '<select name="sbDays" id="sbDays" onChange="showTimetableChangeDays()">';
  fm += '<select name="sbDays" id="sbDays" onChange="showTimetablePeriodFormNewDir()">';
  fm += '</select> ';
  fm += '<strong>&nbsp;&nbsp;&nbsp;&nbsp;' + actLanguageText.direction + ':</strong> ';
  // fm += '<select name="sbDirection" id="sbDirection" onChange="showTimetableChangeDirection()">';
  fm += '<select name="sbDirection" id="sbDirection" onChange="showTimetablePeriodFormNewStations()">';
  fm += '</select>';
  fm += '</p>';
	// fm += '<p style="white-space:nowrap">';
	fm += '<p>';
	// fm += '<strong>Station: ';
	fm += '<strong>' + actLanguageText.station + ': ';
	fm += '<select name="sbStations" id="sbStations" onChange="changeStation()">';
	fm += '</select>';
	// fm += 'Von';
	fm += ' ' + actLanguageText.from_time + ' ';
  fm += '<select name="sbHours1" id="sbHours1">';
	fm += '</select>';
  fm += '<select name="sbMinutes1" id="sbMinutes1">';
  fm += '</select> ';
  // fm += 'Uhr bis ';
  fm += ' ' + actLanguageText.to_time + ' ';
	fm += '<select name="sbHours2" id="sbHours2">';
  fm += '</select>';
  fm += '<select name="sbMinutes2" id="sbMinutes2">';
  fm += '</select> ';
  // fm += 'Uhr &nbsp;</strong>';
  fm += ' ' + actLanguageText.o_clock + ' &nbsp;&nbsp;</strong>';
  // fm += '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';  
  fm += '<input name="btStart" type="button" id="btStart" onClick="showTimetablePeriodFormStart();" value="' + actLanguageText.start_for_button + '">';
  fm += '</p>';
	fm += '</form>';			
	document.getElementById(did).innerHTML = fm;	
	
	
	/* Formularelemente fllen  */
	
	// Linen-Auswahl...
  for (i=0; i<lines.length; i++) {	
    newOpt = new Option(lines[i].Line, lines[i].ID, false, false); 
    document.fmSelect.sbLines.options[i] = newOpt;
  }
  document.fmSelect.sbLines.selectedIndex = 0;
  // Von- und Bis-Zeit...
	for (i=0; i<24; i++)	{
		neuer = (i>9) ? new Option(i, i, false, false) : new Option(('0' + i), i, false, false);
		document.fmSelect.sbHours1.options[i] = neuer;
		neuer = (i>9) ? new Option(i, i, false, false) : new Option(('0' + i), i, false, false);
		document.fmSelect.sbHours2.options[i] = neuer;		
	}
	for (i=0; i<12; i++)	{
		neuer = (i>1) ? new Option(i*5, i*5, false, false) : new Option(('0' + i*5), (i*5), false, false)
		document.fmSelect.sbMinutes1.options[i] = neuer;
		neuer = (i>1) ? new Option(i*5, i*5, false, false) : new Option(('0' + i*5), (i*5), false, false)
		document.fmSelect.sbMinutes2.options[i] = neuer;		
	}
	
	aktHours = jetzt.getHours();
	aktMinutes = jetzt.getMinutes();
	aktMinutes = Math.floor(aktMinutes - (aktMinutes % 5));
	document.fmSelect.sbHours1.selectedIndex = aktHours;		
	document.fmSelect.sbMinutes1.selectedIndex = (aktMinutes / 5);
	if (aktHours < 22)	{
		document.fmSelect.sbHours2.selectedIndex = aktHours + 2;			
		document.fmSelect.sbMinutes2.selectedIndex = (aktMinutes / 5);				
	} else	{	
		document.fmSelect.sbHours2.selectedIndex = 23;		
		document.fmSelect.sbMinutes2.selectedIndex = 11;		
	}  
  
	showTimetablePeriodFormNewDirAndDays();  // Wochentage-Auswahl und davon abhngige Dialogfelder  
}	// showTimetablePeriodForm()

/* Bildfahrplan anzeigen; cid=Canvas-ID; colors, cid und fn sind optional (in dieser Reihenfolge!)	*/
function showGraphicalTimetable(lid, dgid, direction, fromTime, toTime, width, minHeight, optPar1, optPar2, optPar3)	{	// optionale: Farben, CanvasID, Callbackfunktion
	// alert('showGraphicalTimetable()');
	  var lineConnectionID = 	getLineConnectionId(lid, dgid, direction);   // fr 1. Richtung
  var	lineConnectionID2 = getLineConnectionId(lid, dgid, (direction == 1) ? 2 : 1);	// fr 2. Richtung; -1 = keine 2. Richtung vorhanden
	var direction2 = (lineConnectionID2 != -1) ? lineConnections[lineConnectionsByIdArray[lineConnectionID2]].Direction : -1; // 2. Richtung bzw. -1
  var fromMinutes, toMinutes;	// Erste und zweite Zeit in Minuten fr Zeitraum 
  var cbFunc = ((arguments.length > 7) && (typeof arguments[arguments.length-1] == "function")) ? arguments[arguments.length-1] : undefined; 	
  var cid;		// Canvas-ID
	var colObj;		// verwendetes Array-Objekt mit allen Farben		
	var stationTextArray = new Array();		// all stations
	var stationTextArray2 = new Array();	// all stations, second direction
	var tt = new Array();	// enthlt die Fahrplne fr beide Richtungen, 3-dimensional: [diretion][Kurs][Station]	
	var drawAreaOffsetTop = 25;
	var drawAreaOffsetBottom = 25;
	var drawAreaOffsetLeft = 110;
	var drawAreaOffsetRight = 20;	
	var graphicScheduleHeight; 	 		
	var graphicScheduleCanvas; 
	var graphicScheduleContext;
	var interimArray;	// minimaler Zeitabstand zwischen 2 Stationen		
	var stationPosArray;	// Positionen der Stationen fr Stations-Linien	
	var stationTextPosArray;	// Positionen der Stations-Texte	
	var timeForStationArray;	// true wenn Zeit fr Station vorhanden ist, sonst false;		
 	var timePeriod;			// Zeitbereich Zeit1 bis Zeit2		
	var pixelPerMinute;		// Pixel pro Minute fr Bildfahrplan 	
  // ist jetzt fromMinutes und toMinutes: var aktMinutes1, aktMinutes2;		// Start- und Endzeit in Minuten	

	/* Callback-Funktion aufrufen oder zurck zum Hauptprogramm	*/
	this.showGraphicalTimetableCallBack = function()	{
		// alert('showGraphicalTimetableCallBack()');
		if (cbFunc !== "undefined")	{	
	 		cbFunc();	// zur Callback-Funktion gehen
	 	}		
	 }	// showGraphicalTimetableCallBack()

	/* Kurse zeichnen */
	this.showGraphicalTimetableDrawCourses = function()	{
		// alert('showGraphicalTimetableDrawCourses()');	
		var ti, ki, si;		// Table-Index, Kurs-Index, Station-Index fr tt	
		var i, j;					// i wird aus si generiert, j aus ki; i und j wird fr Zugriff auf stationPosArray benutzt
		var kiStart, kiEnd, siStart, siEnd, dirAdd;		// Hilfsvariablen fr umgedrehten Schleifendurchlauf, dirMult ist Additionswert fr Richtung (1 oder -1)
		var ti, ki, si;		// Table-Index, Kurs-Index, Station-Index fr tt
		var v1;
		var found;
		var ttFoundPos, stationPosArrayFoundPos;		// Hilfsvariable fr 2. Richtung
		var b1, b2;
		var iLastTimeIndex;		// Index (i) von letzter Position mit Zeit, wenn diese noch im Feld ist
		var siLastTimeIndex;	// Index (si) von letzter Positino mit Zeit wenn diese noch im Feld ist; nur fr 2. Richtung
			    
		for (j=1; j<tt[0].length; j++) {	// Kurse - all courses	
			graphicScheduleContext.beginPath();
			found = false;
			foundPos = -1;
			iLastTimeIndex = -1;		// Initialisierung (= nicht gefunden)
			for (i=1; i<tt[0][1].length; i++) {	// alle Stationen	
				if (tt[0][j][i] > -1) {					// Zeit															
					if (found == false) {					// erste Station mit Zeit 
						graphicScheduleContext.moveTo( Math.round((tt[0][j][i]-fromMinutes)*pixelPerMinute)+drawAreaOffsetLeft, Math.abs(stationPosArray[i-1])+drawAreaOffsetTop);			// Start des Kurses	
						if (tt[0][j][i] >= fromMinutes)	{					
							graphicScheduleContext.fillStyle = colObj["lineColorStart1"];
							graphicScheduleContext.fillRect(Math.round((tt[0][j][i]-fromMinutes)*pixelPerMinute)+drawAreaOffsetLeft-2, Math.abs(stationPosArray[i-1])+drawAreaOffsetTop-2, 4, 4);																							
						}
						found = true;
					} else {
						if (tt[0][j][i] >= fromMinutes)	{			// Zeit schon im Anzeigebereich
							if (tt[0][j][foundPos] >= fromMinutes) 	{	// vorige Position war schon im Anzeigebereich
								if ( (Math.round((tt[0][j][i]-fromMinutes)*pixelPerMinute)+drawAreaOffsetLeft) <= (width-drawAreaOffsetRight) )	{		// Position hinten noch im Feld
									graphicScheduleContext.strokeStyle = colObj["lineColor1"];	
									graphicScheduleContext.lineTo( Math.round((tt[0][j][i]-fromMinutes)*pixelPerMinute)+drawAreaOffsetLeft, Math.abs(stationPosArray[i-1])+drawAreaOffsetTop);	
									graphicScheduleContext.fillStyle = colObj["lineColorHalt1"];					
									graphicScheduleContext.fillRect(Math.round((tt[0][j][i]-fromMinutes)*pixelPerMinute)+drawAreaOffsetLeft-2, Math.abs(stationPosArray[i-1])+drawAreaOffsetTop-2, 4, 4);				
									iLastTimeIndex = i;	// merken um letzten Halt andersfarbig zu markieren								
								} else if (tt[0][j][foundPos] < toMinutes) {	// hinten nicht mehr im Feld, aber vorige noch im Feld
									v1 = ( (toMinutes - tt[0][j][foundPos])  / (tt[0][j][i] - tt[0][j][foundPos]) );				// Anteil der sichtbaren zu zeichnenden Strecke errechnen
									v1 = v1 * (Math.abs(stationPosArray[i-1]) - Math.abs(stationPosArray[foundPos-1]));		// Streckenlnge des sichtbaren Teils																										
									graphicScheduleContext.strokeStyle = colObj["lineColor1"];	
									graphicScheduleContext.lineTo(width-drawAreaOffsetRight, Math.abs(stationPosArray[foundPos-1])+drawAreaOffsetTop + v1);	
									iLastTimeIndex = -1;
								} else {
									iLastTimeIndex = -1;	// letzte Zeit nicht im Anzeigebereich
								}
							} else  {		// vorige Position noch nicht im Feld
								v1 = ( (fromMinutes - tt[0][j][foundPos])  / (tt[0][j][i] - tt[0][j][foundPos]) );				// Anteil der sichtbaren zu zeichnenden Strecke errechnen
								v1 = v1 * (Math.abs(stationPosArray[i-1]) - Math.abs(stationPosArray[foundPos-1]));		// Streckenlnge des unsichtbaren Teils								
								if (tt[0][j][i] <= toMinutes)	{		// Zeit noch im Anzeigebereich						
									graphicScheduleContext.moveTo(drawAreaOffsetLeft, Math.abs(stationPosArray[foundPos-1])+drawAreaOffsetTop + v1);														
									graphicScheduleContext.strokeStyle = colObj["lineColor1"];	
									graphicScheduleContext.lineTo( Math.round((tt[0][j][i]-fromMinutes)*pixelPerMinute)+drawAreaOffsetLeft, Math.abs(stationPosArray[i-1])+drawAreaOffsetTop);						
									iLastTimeIndex = i;
									graphicScheduleContext.fillStyle = colObj["lineColorHalt1"];	
									graphicScheduleContext.fillRect(Math.round((tt[0][j][i]-fromMinutes)*pixelPerMinute)+drawAreaOffsetLeft-2, Math.abs(stationPosArray[i-1])+drawAreaOffsetTop-2, 4, 4);			
								} else {	// Zeit nicht mehr im Anzeigebereich
									graphicScheduleContext.moveTo(drawAreaOffsetLeft, Math.abs(stationPosArray[foundPos-1])+drawAreaOffsetTop + v1);														
									v1 = ( (toMinutes - tt[0][j][foundPos])  / (tt[0][j][i] - tt[0][j][foundPos]) );				// Anteil der sichtbaren zu zeichnenden Strecke errechnen
									v1 = v1 * (Math.abs(stationPosArray[i-1]) - Math.abs(stationPosArray[foundPos-1]));		// Streckenlnge des sichtbaren Teils																																		
									graphicScheduleContext.strokeStyle = colObj["lineColor1"];	
									graphicScheduleContext.lineTo( width-drawAreaOffsetRight, Math.abs(stationPosArray[foundPos-1])+drawAreaOffsetTop + v1);						
								}
							}
						} else {	// Zeit noch nicht im Anzeigebereich
							graphicScheduleContext.moveTo( Math.round((tt[0][j][i]-fromMinutes)*pixelPerMinute)+drawAreaOffsetLeft, Math.abs(stationPosArray[i-1])+drawAreaOffsetTop);			// aktueller Start der Kurslinie
						}										
					}
					foundPos = i;						
	 			}	// wenn Zeit
	   	}	// for j
	   	if (iLastTimeIndex != -1)	{		// letzte Station umfrben
				graphicScheduleContext.fillStyle = colObj["lineColorEnd1"];					
				graphicScheduleContext.fillRect(Math.round((tt[0][j][iLastTimeIndex]-fromMinutes)*pixelPerMinute)+drawAreaOffsetLeft-2, Math.abs(stationPosArray[iLastTimeIndex-1])+drawAreaOffsetTop-2, 4, 4);				
			}  		
			graphicScheduleContext.stroke();	// zeichnen
			graphicScheduleContext.closePath();		   	
	  }	// for i		
	
	  // Kurslinien fr Richtung 2
	  if (direction2 != -1)	{
			for (j=1; j<tt[1].length; j++) {	// Kurse - all courses	
				graphicScheduleContext.beginPath();
				found = false;
				foundPos = -1;
				iLastTimeIndex = -1;	siLastTimeIndex = -1;		// Initialisierung (= nicht gefunden)			
				stationPosArrayFoundPos = -1;
				for (si=tt[1][1].length-1; si>0; si--) {	// alle Stationen	
					i = tt[1][1].length-si;		// Index fr stationPosArray
					if (tt[1][j][si] > -1) {		// Zeit															
						if (found == false) {	// erste gefundene Station mit Zeit (= letzte Station, da Richtung 1)
							graphicScheduleContext.moveTo( Math.round((tt[1][j][si]-fromMinutes)*pixelPerMinute)+drawAreaOffsetLeft, Math.abs(stationPosArray[i-1])+drawAreaOffsetTop);			// Start des Kurses	
							if ( tt[1][j][si] <= toMinutes)	{		// Position schon im Anzeigebereich (hinten)							
								graphicScheduleContext.fillStyle = colObj["lineColorEnd2"];					
								graphicScheduleContext.fillRect(Math.round((tt[1][j][si]-fromMinutes)*pixelPerMinute)+drawAreaOffsetLeft-2, Math.abs(stationPosArray[i-1])+drawAreaOffsetTop-2, 4, 4);																							
							}
							found = true;
						} else {												
							if (tt[1][j][si] <= toMinutes)	{			// Zeit schon im Anzeigebereich (hinten)
								if ( tt[1][j][ttFoundPos] <= toMinutes)	{		// vorige Position war schon im Anzeigebereich (hinten)
									if (tt[1][j][si] >= fromMinutes) {		// Position vorne noch im Feld																											
										graphicScheduleContext.strokeStyle = colObj["lineColor2"];	
										graphicScheduleContext.lineTo( Math.round((tt[1][j][si]-fromMinutes)*pixelPerMinute)+drawAreaOffsetLeft, Math.abs(stationPosArray[i-1])+drawAreaOffsetTop);	
										graphicScheduleContext.fillStyle = colObj["lineColorHalt2"];					
										graphicScheduleContext.fillRect(Math.round((tt[1][j][si]-fromMinutes)*pixelPerMinute)+drawAreaOffsetLeft-2, Math.abs(stationPosArray[i-1])+drawAreaOffsetTop-2, 4, 4);													
										iLastTimeIndex = i;			// merken um letzten Halt andersfarbig zu markieren													
										siLastTimeIndex = si;		// merken um letzten Halt andersfarbig zu markieren													
									} else if (tt[1][j][ttFoundPos] >= fromMinutes) {	// vorige vorne nicht mehr im Feld								
										v1 = ( (tt[1][j][ttFoundPos] - fromMinutes)  / (tt[1][j][ttFoundPos] - tt[1][j][si]) );				// Anteil der sichtbaren zu zeichnenden Strecke errechnen						
										v1 = v1 * (Math.abs(stationPosArray[i-1]) - Math.abs(stationPosArray[stationPosArrayFoundPos-1]) );		// Streckenlnge des sichtbaren Teils																																			
										graphicScheduleContext.strokeStyle = colObj["lineColor2"];	
										graphicScheduleContext.lineTo(drawAreaOffsetLeft, Math.abs(stationPosArray[stationPosArrayFoundPos-1])+drawAreaOffsetTop + v1);	
										iLastTimeIndex = -1;
										siLastTimeIndex = -1;
									} else {
										iLastTimeIndex = -1;		// letzte Zeit nicht im Anzeigebereich
										siLastTimeIndex = -1;		// letzte Zeit nicht im Anzeigebereich
									}
								} else  {		// vorige Position war noch nicht im Anzeigebereich (hinten)
									v1 = ( (tt[1][j][ttFoundPos] - toMinutes)  / (tt[1][j][ttFoundPos] - tt[1][j][si]) );				// Anteil der sichtbaren zu zeichnenden Strecke errechnen (hinten)
									v1 = v1 * (Math.abs(stationPosArray[i-1]) - Math.abs(stationPosArray[stationPosArrayFoundPos-1]));		// Streckenlnge des unsichtbaren Teils							
									if (tt[1][j][si] >= fromMinutes) {		// Position vorne noch im Anzeigebereich
										graphicScheduleContext.moveTo(width-drawAreaOffsetRight, Math.abs(stationPosArray[stationPosArrayFoundPos-1])+drawAreaOffsetTop + v1);														
										graphicScheduleContext.strokeStyle = colObj["lineColor2"];	
										graphicScheduleContext.lineTo(width-drawAreaOffsetRight - Math.round((toMinutes - tt[1][j][si])*pixelPerMinute), Math.abs(stationPosArray[i-1])+drawAreaOffsetTop);						
										iLastTimeIndex = i;	
										siLastTimeIndex = i;
										graphicScheduleContext.fillStyle = colObj["lineColorHalt2"];	
										graphicScheduleContext.fillRect(width-drawAreaOffsetRight-2 - Math.round((toMinutes - tt[1][j][si])*pixelPerMinute), Math.abs(stationPosArray[i-1])+drawAreaOffsetTop-2, 4, 4);			
									} else {
										graphicScheduleContext.moveTo(width-drawAreaOffsetRight, Math.abs(stationPosArray[stationPosArrayFoundPos-1])+drawAreaOffsetTop + v1);														
										v1 = ( (tt[1][j][ttFoundPos] - fromMinutes)  / (tt[1][j][ttFoundPos] - tt[1][j][si]) );				// Anteil der sichtbaren zu zeichnenden Strecke errechnen						
										v1 = v1 * (Math.abs(stationPosArray[i-1]) - Math.abs(stationPosArray[stationPosArrayFoundPos-1]) );		// Streckenlnge des sichtbaren Teils																																												
										graphicScheduleContext.strokeStyle = colObj["lineColor2"];	
										graphicScheduleContext.lineTo(drawAreaOffsetLeft, Math.abs(stationPosArray[stationPosArrayFoundPos-1])+drawAreaOffsetTop + v1);	
									}
								}
							} else {	// Zeit nicht im Feld
								graphicScheduleContext.moveTo( Math.round((tt[1][j][si]-fromMinutes)*pixelPerMinute)+drawAreaOffsetLeft, Math.abs(stationPosArray[i-1])+drawAreaOffsetTop);			// aktueller Start der Kurslinie
							}										
						}
						ttFoundPos = si;
						stationPosArrayFoundPos = i;								
	   			} 
		   		
		   	}	// for j
		   	if (iLastTimeIndex != -1)	{		// erste Station umfrben
		   		if (tt[1][j][siLastTimeIndex] <= toMinutes) {		// noch im Anzeigebereich?
						graphicScheduleContext.fillStyle = colObj["lineColorStart2"];	
						graphicScheduleContext.fillRect(Math.round((tt[1][j][siLastTimeIndex]-fromMinutes)*pixelPerMinute)+drawAreaOffsetLeft-2, Math.abs(stationPosArray[iLastTimeIndex-1])+drawAreaOffsetTop-2, 4, 4);													
					}
				}  			   	
				graphicScheduleContext.stroke();	// zeichnen
				graphicScheduleContext.closePath();		   	
		  }	// for i		
		}	// if (direction2 != -1) 
		showGraphicalTimetableCallBack();  // Callback-Funktion aufrufen oder zurck zum Hauptprogramm 					
	}	// showGraphicalTimetableDrawCourses()

	this.showGraphicalTimetableDrawTimeAndTimeLines = function()	{
		// alert('showGraphicalTimetableDrawTimeAndTimeLines()');
	  var v1, v2, v4, v5, v6, v7, v8;
	  var i,j;
	  var s;
	 	var partitionMinutes, partitionMinutes2, minutesBefore, minutesAfter;
	  var firstStation;
		// timePeriod = aktMinutes2 - aktMinutes1;		// anzuzeigender Zeitbereich in Minuten
		timePeriod = toMinutes - fromMinutes;		// anzuzeigender Zeitbereich in Minuten
		pixelPerMinute = (width - (drawAreaOffsetLeft+drawAreaOffsetRight) ) / timePeriod;	// Pixel je Minute     
		if (pixelPerMinute >= 34)	{											// >= 40 Pixel/Minute
			partitionMinutes = 1;													// 1 Minute zwischen Zeitlinien
			partitionMinutes2 = -1;												// keine Zwischenstriche
		} else if (pixelPerMinute >= 17)	{								
			partitionMinutes = 2;													// 2 Minuten zwischen Zeitlinien
			partitionMinutes2 = 1;		
		} else if (pixelPerMinute >= 7.2)	{								
			partitionMinutes = 5;													// 5 Minuten zwischen Zeitlinien
			partitionMinutes2 = 1;
		} else if (pixelPerMinute >= 3.4)	{							
			partitionMinutes = 10;												
			partitionMinutes2 = 2;
		}	else if (pixelPerMinute >= 2.29)	{			
			partitionMinutes = 15;
			partitionMinutes2 = 5;
		}	else if (pixelPerMinute >= 1.13)	{			
			partitionMinutes = 30;
			partitionMinutes2 = 5;
		}	else if (pixelPerMinute >= 0.57)	{			
			partitionMinutes = 60;
			partitionMinutes2 = 10;
		}	else {	
			partitionMinutes = 120;
			partitionMinutes2 = 15;	
		}		
		minutesBefore = partitionMinutes - (fromMinutes % partitionMinutes);		// Minuten vor ersten Trennstrich bei Startzeit	
		minutesAfter = toMinutes % partitionMinutes;													// Minuten nach ersten Trennstrich bei Endzeit	
	
		// Stations-Zeit-Striche zeichnen
		if (partitionMinutes2 != -1)	{		// wenn Zwischenstriche gezeichnet werden sollen
			v7 = partitionMinutes2 - (fromMinutes % partitionMinutes2);				// Minuten vor ersten Trennstrich  bei Startzeit
			v8 = toMinutes % partitionMinutes2;							// Minuten nach ersten Trennstrich bei Endzeit	
			firstStation = true;								// erste Station nur halbe Trennstriche zeichnen
			i = 0;  j = 0;	// Index, Vergleichsindex
			while (i<stationPosArray.length)	{			
				if ( (timeForStationArray[i] == true)	|| (timeForStationArray[j] == true) )	{	// Zeiteintrge fr Station vorhanden				
					graphicScheduleContext.beginPath();
					graphicScheduleContext.strokeStyle = colObj["timeStepLine"]; 	
					for (j=v7; j<timePeriod; j+=partitionMinutes2)	{
						if (firstStation == true)	{			
							graphicScheduleContext.moveTo(Math.round(j*pixelPerMinute)+drawAreaOffsetLeft, stationPosArray[i]+drawAreaOffsetTop-2);		
							graphicScheduleContext.lineTo(Math.round(j*pixelPerMinute)+drawAreaOffsetLeft, stationPosArray[i]+drawAreaOffsetTop+2);											
						} else if (i == (stationPosArray.length-1))	{								// letzte Station							
							graphicScheduleContext.moveTo(Math.round(j*pixelPerMinute)+drawAreaOffsetLeft, stationPosArray[i]+drawAreaOffsetTop-2);		
							graphicScheduleContext.lineTo(Math.round(j*pixelPerMinute)+drawAreaOffsetLeft, stationPosArray[i]+drawAreaOffsetTop+2);											
						} else {
							graphicScheduleContext.moveTo(Math.round(j*pixelPerMinute)+drawAreaOffsetLeft, stationPosArray[i]+drawAreaOffsetTop-2);		
							graphicScheduleContext.lineTo(Math.round(j*pixelPerMinute)+drawAreaOffsetLeft, stationPosArray[i]+drawAreaOffsetTop+2);				
						}
					}
					graphicScheduleContext.stroke();	// zeichnen
					graphicScheduleContext.closePath();	
					firstStation = false;
				}
				i += 2;
				j = i+1;
				if (i == 2) {
					i = 1;		// war vorher 0;
					j = 2;
				}
				if (i == (stationPosArray.length-1))	{
					j = i;	// letzte Station nur einmal da
				}
			}
			graphicScheduleContext.stroke();	// zeichnen
			graphicScheduleContext.closePath();		
		}		
		
		// Senkrechte Zett-Linien zeichnen
		graphicScheduleContext.beginPath();
		graphicScheduleContext.strokeStyle = colObj["timeLine"]; 	
		graphicScheduleContext.moveTo(drawAreaOffsetLeft, drawAreaOffsetTop-5);		
		graphicScheduleContext.lineTo(drawAreaOffsetLeft, graphicScheduleHeight - drawAreaOffsetTop+5);	// link Linie				
		for (i=minutesBefore; i<timePeriod; i+=partitionMinutes)	{
			graphicScheduleContext.moveTo(Math.round(i*pixelPerMinute)+drawAreaOffsetLeft, drawAreaOffsetTop-5);		
			graphicScheduleContext.lineTo(Math.round(i*pixelPerMinute)+drawAreaOffsetLeft, graphicScheduleHeight-drawAreaOffsetBottom+5);	
		}
		graphicScheduleContext.moveTo(width-drawAreaOffsetRight, drawAreaOffsetTop-5);		
		graphicScheduleContext.lineTo(width-drawAreaOffsetRight, graphicScheduleHeight-drawAreaOffsetBottom+5);	// rechte Linie
		graphicScheduleContext.stroke();	// zeichnen
		graphicScheduleContext.closePath();			
			
		// Uhrzeiten schreiben
		graphicScheduleContext.textAlign = "center";
		graphicScheduleContext.fillStyle = colObj["timeText"];
		s = minutesToTimeString(fromMinutes);
		if ( (minutesBefore > 0) && ((minutesBefore*pixelPerMinute) > (graphicScheduleContext.measureText(s).width + 5) ) )	{		// Platz fr Zeit am Anfang vorhanden?
			graphicScheduleContext.fillText(s, drawAreaOffsetLeft, 15);				
			graphicScheduleContext.fillText(s, drawAreaOffsetLeft, graphicScheduleHeight-drawAreaOffsetTop+15);			
		}
		for (i=minutesBefore; i<=timePeriod; i+=partitionMinutes)	{		
			graphicScheduleContext.fillText(minutesToTimeString(fromMinutes+i), Math.round(i*pixelPerMinute)+drawAreaOffsetLeft, 15);
			graphicScheduleContext.fillText(minutesToTimeString(fromMinutes+i), Math.round(i*pixelPerMinute)+drawAreaOffsetLeft, graphicScheduleHeight-drawAreaOffsetTop+15);		
		}	
		s = minutesToTimeString(toMinutes);
		if ( (minutesAfter > 0) && ((minutesAfter*pixelPerMinute) > (graphicScheduleContext.measureText(s).width + 5) ) )	{		// Platz fr Zeit am Anfang vorhanden?	
			graphicScheduleContext.fillText(s, width-drawAreaOffsetRight, 15);	
			graphicScheduleContext.fillText(s, width-drawAreaOffsetRight, graphicScheduleHeight-drawAreaOffsetTop+15);			
		}	
		showGraphicalTimetableDrawCourses();										
	}	// showGraphicalTimetableDrawTimeAndTimeLines()

	this.showGraphicalTimetableDrawStationLines = function()	{
		// alert('showGraphicalTimetableDrawStationLines()');			
		var i;
		var found;
		graphicScheduleContext.beginPath();
		graphicScheduleContext.strokeStyle = colObj["stationLine"]; 
		found = false;
		i=0;
		while (i<stationPosArray.length)	{
			if ( (i != 0) && (i != stationPosArray.length-1) )		{		// nicht erste oder letzte Station (= doppelt vorhanden)
				found = ( (timeForStationArray[i] == true) || (timeForStationArray[i+1] == true) );
			} else {																									// erste oder letzte Station
				found = (timeForStationArray[i] == true);													
			}		
			if (found == true)	{	
				graphicScheduleContext.moveTo(drawAreaOffsetLeft, stationPosArray[i]+drawAreaOffsetTop);		// von rechts ...
				graphicScheduleContext.lineTo(width-drawAreaOffsetRight, stationPosArray[i]+drawAreaOffsetTop);	// ... nach links											
			}
			if ( (i != 0) && (i != stationPosArray.length-1) )		{		// erste und letzte Station nur einmal vorhanden
				i+=2;
			} else {																									// erste oder letzte Station
				i++;
			}		
		}
		graphicScheduleContext.stroke();	// zeichnen
		graphicScheduleContext.closePath();		
		showGraphicalTimetableDrawTimeAndTimeLines();		
		
	}	// showGraphicalTimetableDrawStationLines()


	/* Stationstext an richtige Position schreiben */
	this.showGraphicalTimetableWriteStationText = function()	{
		// alert('showGraphicalTimetableWriteStationText()');		
		var i;
		var found;

		graphicScheduleContext.textAlign = "left";
		found = false;	
		i=0;
		while (i<stationTextArray.length)	{		
			if ( (i != 0) && (i != stationTextArray.length-1) )		{		// nicht erste oder letzte Station (= doppelt vorhanden)
				found = ( (timeForStationArray[i] == true) || (timeForStationArray[i+1] == true) );
			} else {																									// erste oder letzte Station
				found = (timeForStationArray[i] == true);													
			}
			if (found == true)	{
				if (Math.abs(stationTextPosArray[i] - stationPosArray[i]) < 10)	{	// Text liegt nahe der Stations-Linie
					graphicScheduleContext.fillStyle = colObj["activeStationText"];					
					graphicScheduleContext.fillText(stationTextArray[i], 5, stationTextPosArray[i]+28, drawAreaOffsetLeft-10);
				} else {	// Stationstext mit Linie zur Stationslinie zeichnen
					graphicScheduleContext.fillStyle = colObj["activeStationText"];
					graphicScheduleContext.fillText(stationTextArray[i], 5, stationTextPosArray[i]+28, drawAreaOffsetLeft-25);					
					graphicScheduleContext.beginPath();
					graphicScheduleContext.strokeStyle = colObj["stationLine"];				
					graphicScheduleContext.moveTo(drawAreaOffsetLeft-20, stationTextPosArray[i]+drawAreaOffsetTop);		
					graphicScheduleContext.lineTo(drawAreaOffsetLeft-15, stationTextPosArray[i]+drawAreaOffsetTop);	// nach links						
					graphicScheduleContext.moveTo(drawAreaOffsetLeft-15, stationTextPosArray[i]+drawAreaOffsetTop);		
					graphicScheduleContext.lineTo(drawAreaOffsetLeft-5, stationPosArray[i]+drawAreaOffsetTop);		// schrg nach oben/unten
					graphicScheduleContext.moveTo(drawAreaOffsetLeft-5, stationPosArray[i]+drawAreaOffsetTop);		
					graphicScheduleContext.lineTo(drawAreaOffsetLeft, stationPosArray[i]+drawAreaOffsetTop);			// nach links								
					graphicScheduleContext.stroke();	// zeichnen										
				}
			} else {
				graphicScheduleContext.fillStyle = colObj["inactiveStationText"];
				if (Math.abs(stationTextPosArray[i] - stationPosArray[i]) < 10)	{	// Text liegt nahe der Stations-Linie
					graphicScheduleContext.fillText('(' + stationTextArray[i] + ')', 5, stationTextPosArray[i]+drawAreaOffsetTop+3, drawAreaOffsetLeft-10);				
				} else {
					graphicScheduleContext.fillText('(' + stationTextArray[i] + ')', 5, stationTextPosArray[i]+drawAreaOffsetTop+3, drawAreaOffsetLeft-25);				
				}
			}
			if ( (i != 0) && (i != stationTextArray.length-1) )		{		// erste und letzte Station nur einmal vorhanden
				i+=2;
			} else {																									// erste oder letzte Station
				i++;
			}
		}	
		// nicht mehr: drawBorder();				
		showGraphicalTimetableDrawStationLines();
	}	// showGraphicalTimetableWriteStationText()

	this.showGraphicalTimetableSetStationTextPos = function()	{
		// alert('showGraphicalTimetableSetStationTextPos()');		
		var i, j;
		var b1;
		
		timeForStationArray = new Array(stationPosArray.length);	
		
		// timeForStationArray fllen
		for (i=0; i<timeForStationArray.length; i++)	{
			timeForStationArray[i] = false;
		}	
		// Richtung 1
		for (j=1; j<tt[0].length; j++) {	// alle Kurse			
			for (i=1; i<tt[0][1].length; i++) {	// alle Zeiten - all courses	
				if (tt[0][j][i] > -1)	{
					timeForStationArray[i-1] = true;
				}
			}
		}
		// Richtung 2
		if (direction2 != -1)	{
			for (j=1; j<tt[1].length; j++) {	// alle Kurse			
				for (i=1; i<tt[1][1].length; i++) {	// alle Zeiten - all courses	
					if (tt[1][j][i] > -1)	{
						timeForStationArray[timeForStationArray.length-i] = true;
					}
				}
			}		
		}
	
		// Positionen der Stations-Texte ermitteln
		stationTextPosArray = new Array(stationPosArray.length);		
		for (i=0; i<stationPosArray.length; i++) {
			stationTextPosArray[i] = stationPosArray[i]; 
		}		
	
		b1 = true;	// init
		while (b1 == true)	{		// solange berschneidungen gefunden wurden	
			b1 = false;
			for (i=0; i<stationTextPosArray.length-1; i++)	{	
				if ( (stationTextArray[i] != stationTextArray[i+1]) && (Math.abs(stationTextPosArray[i]) > (Math.abs(stationTextPosArray[i+1])-10)) )	{	// berschneidung mit Element darunter
	
					j = (graphicScheduleHeight - (drawAreaOffsetTop+drawAreaOffsetBottom) ) / stationTextPosArray.length-1;
					b1 = (Math.abs(stationTextPosArray[i] - (i*j))) < (Math.abs(stationTextPosArray[i+1] - ((i+1)*j))); // rechnerisch abweichendere Station ermitteln				
					if (b1) {
						if (stationTextPosArray[i+1] == stationTextPosArray[i+2])	{		// folgende ist gleiche Station
							stationTextPosArray[i+1] = stationTextPosArray[i]+10;		
							stationTextPosArray[i+2] = stationTextPosArray[i]+10;
						} else {
							stationTextPosArray[i+1] = stationTextPosArray[i]+10;		
						}
						b1 = true; i++;
					} else {
						if (stationTextPosArray[i-1] == stationTextPosArray[i])	{		// vorherige ist gleiche Station						
							stationTextPosArray[i] = stationTextPosArray[i+1]-10;							
							stationTextPosArray[i-1] = stationTextPosArray[i+1]-10;								
						} else {
							stationTextPosArray[i] = stationTextPosArray[i+1]-10;	
						}
						b1 = true;
					}
				}						
			}	// for
		}	// while		
		// document.write(stationTextPosArray);
		showGraphicalTimetableWriteStationText();		
		
	}	// showGraphicalTimetableSetStationTextPos()

	this.showGraphicalTimetableSetStationPos = function()	{
		// alert('showGraphicalTimetableSetStationPos()');			
		var i;
		var v1, v2, v3, v4;	
	  var timeFound;
	  // Gesamt-Mindestlnge der Strecke ermitteln
	  v1 = 0;
	  for (i=0; i<interimArray.length; i++)	{
	  	if (interimArray[i] != 9999)	{	// Wert vorhanden
	  		if (stationTextArray[i] != stationTextArray[i+1])	{	// Abstand erhht sich nur bei ungleichen Stationen 
	  			v1 += interimArray[i];
	  		}
	  	}
	  }	
		
		// Y-Positionen fr Stationen ermitteln
		v2 = 0;	// aktuelle vergangene Zeit
		v3 = ((graphicScheduleHeight - (drawAreaOffsetTop + drawAreaOffsetBottom) )/v1);  	// Pixel pro Minute; 20 Pixel fr obere Zeile + 10 Pixel fr Abstand oben und unten (je 5)
		v4 = 0;	// Anzahl Stationen ohne Zeit
		stationPosArray = new Array(stationTextArray.length);
		stationPosArray[0] = 0;	// erste Station ganz oben
	
		// timeForStationArray und stationPosArray fllen
		timeFound = false;
		for (i=1; i<stationTextArray.length; i++)	{
			if ( stationTextArray[i] != stationTextArray[i-1] )	{	// nur wenn nicht gleiche Station				
				if (interimArray[i-1] != 9999)	{		// wennStation im Plan vorkommt
					v2 += interimArray[i-1];
					stationPosArray[i] = Math.round(v2*v3);
					v4 = 0;
					timeFound = true;
				} else {			
					if (timeFound== true) v4++;			
					stationPosArray[i] = (Math.round(v2*v3) + (v4 * 10));
					if (stationPosArray[i] > (graphicScheduleHeight-30))	{
						stationPosArray[i] = (graphicScheduleHeight-30);
					}
				}
			} else { 
				stationPosArray[i] = stationPosArray[i-1];
			}
		}
		stationPosArray[stationTextArray.length-1] = graphicScheduleCanvas.height -(drawAreaOffsetTop + drawAreaOffsetBottom);	
		showGraphicalTimetableSetStationTextPos();		
		
	}	// showGraphicalTimetableSetStationPos()

	/* Zeiten zwischen Stationen ermitteln, fllt interimArray */
	this.showGraphicalTimetableSetInterim =	function()	{
		// alert('showGraphicalTimetableSetInterim()');			
		var i, ki, si;
		var v1, v2, v3, v4;
		var b1;
		var lg1, lg2, lg3;
		var interimDoubleArray;		// zum ermitteln der Werte fr interimArray	
		
		// Arrays initialisieren...
		interimArray = new Array(stationTextArray.length-1);
		for (i=0; i<interimArray.length; i++) {
			interimArray[i] = -1;		// initialisieren, -1 steht fr noch kein Wert ermittelt
		}			
		interimDoubleArray = new Array(tt[0].length-1);
		for (ki=0; ki<interimDoubleArray.length; ki++)	{
			interimDoubleArray[ki] = new Array(tt[0][1].length-2);	// ein weniger fr Feldname (Kursnummer) + ein weniger da Zwischenrume zwischen 2 Zeiten ermittelt werden
			for (si=0; si<interimDoubleArray[ki].length; si++)	{
				interimDoubleArray[ki][si] = 9999;	// init
			}
		}
		
		// interimDoubleArray fllen: errechnete Zwischenrume (wegen nicht bedienter Stationen dazwischen) erhalten negative Werte
		// 1) 1. Richtung
		for (ki=1; ki<tt[0].length; ki++)	{		// fr alle Kurse
			v1 = -1;	// speichert Index vorheriger Station mit Zeiteintrag fr t[ki]
			if (tt[0][ki][1] > -1)	{		// Zeit		
				v1 = 1;
			}
			for (si=2; si<tt[0][ki].length; si++)	{		// fr alle Stationen
				if (tt[0][ki][si] > -1)	{						// Zeit
					if (v1 != -1)	{								// vorher schon Zeit gefunden
						if (v1 == (si-1))	{						// letzte Station mit Zeit
							interimDoubleArray[ki-1][si-2] = (tt[0][ki][si] - tt[0][ki][v1]) * 3;		// Differenz in Minuten * 3 (wiel 0 zu 1 wird)
							// if (interimDoubleArray[ki-1][si-2] == 0) interimDoubleArray[ki-1][si-2] = 1;	// 0 nicht erlaubt da Linienzeichnung nicht eindeutig
						} else {										// mehrere Felder dazwischen						
							v4 = (tt[0][ki][si] - tt[0][ki][v1]) / (si-v1); 		// Minuten pro Feld (nicht gerundet!)
							v2 = v4;
							v3 = 0;	// bereits eingetragene Minuten
							for (i=v1; i<si; i++)	{		// alle Zwischenrume fllen mit errechneten Minuten als negative Zahlen
								interimDoubleArray[ki-1][i-1] = -Math.round(v2) - v3;	// aktuelle Gesamtzeit - schon eingetragener Minuten -1 (wegen 0)
								// if (interimDoubleArray[ki-1][i-1] == 0) interimDoubleArray[ki-1][i-1] = -1;		// 0 kann nicht negativ dargestellt werden, 1 ist ohnehin Mindestabstand
								v3 += interimDoubleArray[ki-1][i-1];
								if (interimDoubleArray[ki-1][i-1] == 0) {
									interimDoubleArray[ki-1][i-1]--;	// -1 wegen 0 (kann nicht negativ dargestellt werden	
								} else {
									interimDoubleArray[ki-1][i-1] *= 3;
								}
								v2 += v4;	// Geamtzeit erhhen und geschriebene abziehen
							}
						}	// mehrere felder dazwischen
					}	else {	// vorher noch kein Zeiteintrag gefunden (evtl. ergnzen)
					}
					v1 = si;	// index von t[ki] merken
				}	
			}	// fr alle Stationen
		}	// fr alle Kurse
		
		// Tabelle interimDoubleArray ausgeben (fr Debug):
		/*	document.write('<table border="1">');
		for (i=0; i<interimDoubleArray[0].length; i++) {	// Stationen 
			document.write('<tr>');
			for (j=0; j<interimDoubleArray.length; j++)	{				// Kurse
				document.write('<td color="#FF0000">' + interimDoubleArray[j][i] + '</td>'); 
			}
			document.write('<td color="#FF0000"> [' + interimArray[i] + '] </td>'); 		
			document.write('</tr>');
		}
		document.write('</table><br>');				*/
		
		// 2) 2. Richtung
		if (direction2 != -1)	{		// nur wenn 2. Richtung vorhanden		
			// interimDoubleArray = new Array(tt[0].length-1);		
			lg1 = interimDoubleArray.length;
			lg2 = tt[1].length-1;
			lg3 = tt[1][0].length-1;
			for (ki=lg1; ki<(lg1+lg2); ki++)	{
				interimDoubleArray[ki] = new Array(tt[1][1].length-2);	// ein weniger fr Feldname (Kursnummer) + ein weniger da Zwischenrume zwischen 2 Zeiten ermittelt werden
				for (si=0; si<interimDoubleArray[ki].length; si++)	{
					interimDoubleArray[ki][si] = 9999;	// init
				}
			}	
							
			for (ki=1; ki<tt[1].length; ki++)	{		// fr alle Kurse
				v1 = -1;	// speichert Index vorheriger Station mit Zeiteintrag fr t[ki]
				if (tt[1][ki][1] > -1)	{		// Zeit		
					v1 = 1;
				}
				for (si=2; si<tt[1][ki].length; si++)	{		// fr alle Stationen
					if (tt[1][ki][si] > -1)	{						// Zeit
						if (v1 != -1)	{								// vorher schon Zeit gefunden
							if (v1 == (si-1))	{						// letzte Station mit Zeit
								interimDoubleArray[ki-1+lg1][lg3-si] = (tt[1][ki][si] - tt[1][ki][v1]) * 3;		// Differenz in Minuten * 3 (weil 0 zu 1 wird)
							} else {										// mehrere Felder dazwischen						
								v4 = (tt[1][ki][si] - tt[1][ki][v1]) / (si-v1); 		// Minuten pro Feld (nicht gerundet!)
								v2 = v4;
								v3 = 0;	// bereits eingetragene Minuten
								for (i=v1; i<si; i++)	{		// alle Zwischenrume fllen mit errechneten Minuten als negative Zahlen
									interimDoubleArray[ki-1+lg1][lg3-i+1] = -Math.round(v2) - v3;	// aktuelle Gesamtzeit - schon eingetragener Minuten -1 (wegen 0)
									v3 += interimDoubleArray[ki-1+lg1][lg3-i+1];
									if (interimDoubleArray[ki-1+lg1][lg3-i+1] == 0) {
										interimDoubleArray[ki-1+lg1][lg3-i+1]--;	// -1 wegen 0 (kann nicht negativ dargestellt werden	
									} else {
										interimDoubleArray[ki-1+lg1][lg3-i+1] *= 3;
									}
									v2 += v4;	// Geamtzeit erhhen und geschriebene abziehen
								}
							}	// mehrere felder dazwischen
						}	else {	// vorher noch kein Zeiteintrag gefunden (evtl. ergnzen)
						}
						v1 = si;	// index von t[ki] merken
					}	
				}	// fr alle Stationen
			}	// fr alle Kurse	
		}	// wenn 2. Richtung vorhanden	
	
		// Tabelle interimDoubleArray ausgeben (fr Debug):
		/* document.write('<table border="1">');
		for (i=0; i<interimDoubleArray[0].length; i++) {	// Stationen 
			document.write('<tr>');
			for (j=0; j<interimDoubleArray.length; j++)	{				// Kurse
				document.write('<td color="#FF0000">' + interimDoubleArray[j][i] + '</td>'); 
			}
			document.write('<td color="#FF0000"> [' + interimArray[i] + '] </td>'); 		
			document.write('</tr>');
		}
		document.write('</table><br>');		*/
	
		// Tabelle bearbeiten - interimArray aus interimDoubleArray erstellen
		for (si=0; si<interimDoubleArray[0].length; si++)	{			// alle Stationen
			// Stationen mit nur positiven (eindeutigen) Zahlen eintragen
			b1 = false;	// init, positiven Wert gefunden
			for (ki=0; ki<interimDoubleArray.length; ki++)	{				// alle kurse
				if ( (interimDoubleArray[ki][si] > 0) && (interimDoubleArray[ki][si] != 9999) )	{		// negativer Wert - kann nicht in interimArray bernommen werden
					b1 = true;						
					ki = interimDoubleArray.length;	// fr Schleifenende
				}
			}
			if (b1 == true)	{	// positiver wert (ausser 9999) gefunden
				v1 = 9999;	// init 
				for (ki=0; ki<interimDoubleArray.length; ki++)	{							// alle kurse					
					if (interimDoubleArray[ki][si] > 0)	{	// positiver Wert
						if (v1 > interimDoubleArray[ki][si])	{	
							v1 = interimDoubleArray[ki][si];
						}
					}
				}
				interimArray[si] = v1;
			} else {	// kein positiver Wert vorhanden
				v1 = 0;	// init
				v2 = 0;	// init, Zhler
				for (ki=0; ki<interimDoubleArray.length; ki++)	{							// alle kurse					
					if (interimDoubleArray[ki][si] < 0)	{	// negativer Wert
						v1+=interimDoubleArray[ki][si];
						v2++;
					}
				}
				if (v2 > 0)	{	// Werte gefunden
					interimArray[si] = Math.abs(Math.round(v1 / v2));
				} else {
					interimArray[si] = 9999;
				}
			}
		}
		
		// Tabelle interimDoubleArray ausgeben (fr Debug):
		/* document.write('<table border="1">');
		for (i=0; i<interimDoubleArray[0].length; i++) {	// Stationen 
			document.write('<tr>');
			for (j=0; j<interimDoubleArray.length; j++)	{				// Kurse
				document.write('<td color="#FF0000">' + interimDoubleArray[j][i] + '</td>'); 
			}
			document.write('<td color="#FF0000"> [' + interimArray[i] + '] </td>'); 		
			document.write('</tr>');
		}
		document.write('</table>');			*/		
		 
		showGraphicalTimetableSetStationPos();						
	}	// showGraphicalTimetableSetInterim()		

	/* Canvas initialisieren */
	this.showGraphicalTimetableCanvasInit = function()	{
		// alert('showGraphicalTimetableCanvasInit()');		
		var v1 = (stationTextArray.length / 2) - 1;	// tatschliche Stationen ohne doppelte
		if  ( ((v1 * 28) + (drawAreaOffsetTop + drawAreaOffsetBottom) ) < minHeight)	{  	
  		graphicScheduleHeight = minHeight;
  	} else {
    	graphicScheduleHeight = (v1 * 28) + (drawAreaOffsetTop + drawAreaOffsetBottom);
  	}
		graphicScheduleCanvas = document.getElementById(cid);
		graphicScheduleCanvas.height = graphicScheduleHeight;
		graphicScheduleCanvas.width = width;			
		graphicScheduleContext = graphicScheduleCanvas.getContext('2d');		  
		graphicScheduleContext.fillStyle = colObj["bgColor"];			// Hintergrundfarbe fr Canvas		
	 	graphicScheduleContext.clearRect(0, 0, graphicScheduleCanvas.width, graphicScheduleCanvas.height);   	
		// graphicScheduleContext.fillStyle = colObj["bgColor"];		
		graphicScheduleContext.fillRect(0, 0, graphicScheduleCanvas.width, graphicScheduleCanvas.height);   	
		document.getElementById(cid).style.visibility = "visible";	
		showGraphicalTimetableSetInterim();				
	}	// showGraphicalTimetableCanvasInit()

	/* setzt fr alle Stationen Abfahrts- und Ankunfts-Bahnhof	*/
	this.showGraphicalTimetableDoubleStations = function()	{	
		// alert('showGraphicalTimetableDoubleStations()');				
		var i;
		var dirIdx, courseIdx, stationIdx;
		var lastStation;
		var tempArray1, tempArray2;
	
		// 1. Richtung
		dirIdx = 0;		
		lastStation = '';
		for (stationIdx=1; stationIdx<stationTextArray.length-1; stationIdx++)		{		// fr alle Stationen ausser erste und letzte 	(3. Index von tt),
			// Achtung: durch Einfgen der zustzlichen Stations-Arrays in tt stimmt die Station-Position nicht mehr, diese wird aber auch nicht mehr bentigt
			if (stationTextArray[stationIdx] != lastStation)	{		// nicht gleiche Station wie vorher
				lastStation = stationTextArray[stationIdx];				
				if (stationTextArray[stationIdx] != stationTextArray[stationIdx+1])		{		// nur wenn Staion nicht vorher schon doppelt vorhanden ist
					// Stationstext einfgen
					for (i=stationTextArray.length; i>stationIdx; i--)	{		
						stationTextArray[i] = stationTextArray[i-1];
					} 
					// Stations-Array in tt einfgen
					for (courseIdx=0; courseIdx<tt[dirIdx].length; courseIdx++)	{		// fr alle Kurse
						for (i=tt[dirIdx][courseIdx].length; i>stationIdx+1; i--)	{		// fr alle Stationen						
							tt[dirIdx][courseIdx][i] = tt[dirIdx][courseIdx][i-1];
						}
					}						
					stationIdx++;
				}
			}
		}	// for stationIdx
		
			
		// fr 2. Richtung
		if (direction2 != -1)	{		// nur wenn 2. Richtung vorhanden ist 
			dirIdx = 1;
			lastStation = '';		
			for (stationIdx=1; stationIdx<stationTextArray2.length-1; stationIdx++)		{		// fr alle Stationen ausser erste und letzte 	(3. Index von tt),
				// Achtung: durch Einfgen der zustzlichen Stations-Arrays in tt stimmt die Station-Position nicht mehr, diese wird aber auch nicht mehr bentigt
				if (stationTextArray2[stationIdx] != lastStation)	{		// nicht gleiche Station wie vorher
					lastStation = stationTextArray2[stationIdx];				
					if (stationTextArray2[stationIdx] != stationTextArray2[stationIdx+1])		{		// nur wenn Staion nicht vorher schon doppelt vorhanden ist
						for (i=stationTextArray2.length; i>stationIdx; i--)	{		
							stationTextArray2[i] = stationTextArray2[i-1];
						} 
						// Stations-Array in tt einfgen
						for (courseIdx=0; courseIdx<tt[dirIdx].length; courseIdx++)	{		// fr alle Kurse
							for (i=tt[dirIdx][courseIdx].length; i>stationIdx+1; i--)	{		// fr alle Stationen
								tt[dirIdx][courseIdx][i] = tt[dirIdx][courseIdx][i-1];
							}
						}		
						stationIdx++;																	
					}
				}
			}	// for stationIdx
		}
	
	
		// falls ntig Ankunftszeit am Anfang und Abfahrtszeit am Ende wieder lschen
		for (dirIdx = 0; dirIdx<tt.length; dirIdx++)	{										// fr beide Richtungen
			for (courseIdx=1; courseIdx<tt[dirIdx].length; courseIdx++)	{			// fr alle Kurse
				if (tt[dirIdx][courseIdx][1] == -1)	{														// nur ntig wenn keine Zeit am Anfang
					for (i=2; i<tt[dirIdx][courseIdx].length; i++)	{								// fr alle Stationen
						if (tt[dirIdx][courseIdx][i] != -1)	{		// Zeit oder Interval gefunden
							if ((i % 2) == 0)	{		// Ankunfts-Station
								tt[dirIdx][courseIdx][i] = -1;		// Ankunftsbahnhof, daher "kein Halt"
							}
							i = tt[dirIdx][courseIdx].length;	// Schleifenende
						}
					}
				}	// if
					
				if (tt[dirIdx][courseIdx][tt[dirIdx][courseIdx].length-1] == -1)	{										// nur ntig wenn keine Zeit am Ende
					for (i=tt[dirIdx][courseIdx].length-2; i>1; i--)	{				// fr alle Stationen
						if (tt[dirIdx][courseIdx][i] != -1)	{		// Zeit oder Interval gefunden
							if ((i % 2) != 0)	{	// Abfahrts-Station
								tt[dirIdx][courseIdx][i] = -1;		// Ankunftsbahnhof, daher "kein Halt"
							}
							i = 1;					// Schleifenende
						}
					}			
				}																		
			}	// for courseIdx...
		}	// for dirIdx...					
		showGraphicalTimetableCanvasInit();						
	}	// showGraphicalTimetableDoubleStations()

	this.showGraphicalTimetableExpandTT = function()	{
		// alert('showGraphicalTimetableExpandTT()');			
		var t;
		var ttIndex, dirIdx;
		var i,j,k,m;
		var alti;
	  var v1, v2, v3;
	  var idx1, idx2;
	  var a;
	  var stunde, minute, feld;	  
	  var minInterval, addInterval;
		var ivTemp;  // Interval temporr speichern	  
		var startZeitInterval, startZeitInterval2, endZeitInterval ;	// Fr Interval-Vorgnger-Zeit bzw. Nachfolger-Zeit die nicht direkt vor Interval-Spalte steht
		var minIntervalPos;		// Index from minInterval
		var prev, next, prev2, next2;
		
		// Fahrplantabelle(n) expandieren
		
	  for (dirIdx=0; dirIdx<tt.length; dirIdx++)	{		// fr beide Richtungen 
		  i = 1;
		  while (i < tt[dirIdx].length) {
				j = 1; 
			  v1 = -1; 
			  v2 = -1;
				// if (stationPos == 0)	{  // hier keine Stationsauwahl mglich, daher immer 0
			  while (j < tt[dirIdx][i].length) {
				  v1 = tt[dirIdx][i][j];
				  if (v1 != -1) {
						idx1 = j;
					  j = tt[dirIdx][i].length;
					} else {
				 		j++;
					}
				}					
				j = tt[dirIdx][i].length-1;
				while (j > 0) {
					v2 = tt[dirIdx][i][j];
					if (v2 != -1) {
						idx2 = j;
						j = 0;
					} else {
						j--;
					}
			  }				
				// auskommentiert - Stationsauswahl hier nicht mglich
				/*	}	else	{
					idx1 = document.fmSelect.sbStations.options[document.fmSelect.sbStations.selectedIndex].value;
					idx2 = idx1;
					v1 = tt[dirIdx][i][idx1];
					v2 = v1;	*/					
				// }
			  if ( (v1 < -1) || (v2 < -1) ) {		  	
					if ( !( (fromMinutes < tt[dirIdx][i-1][idx1]) && (toMinutes > tt[dirIdx][i-1][idx2]) && (fromMinutes > tt[dirIdx][i+1][idx1]) && (toMinutes < tt[dirIdx][i+1][idx2]) ) ) {
				  	minInterval = 10000;
					  for (k = 1; k < tt[dirIdx][0].length; k++) {
							v3 = tt[dirIdx][i][k];
							if (v3 < -1) {
								// if (oInterval[Math.abs(v3)] < minInterval) {
								ivTemp = getInterval(Math.abs(v3));
								if (ivTemp < minInterval) {								
									// minInterval = oInterval[Math.abs(v3)];
									minInterval = ivTemp;
									minIntervalPos = v3;
									idx1 = k;	// neuer Wert fr idx1 mit niedrigster Interval-Zeit
								}
							}
						}
					  if (minInterval < 10000) {
							addInterval = 0;
							alti = i-1; 
		
							// Vorgnger von Interval suchen
							j = i-1;
							while (j > 0)	{
								if (tt[dirIdx][j][idx1] > -1)	{		// Zeit gefunden	
									prev = j;
									j = 0;														
								}
								j--;
							}
		
							// Nachfolger von Interval suchen
							j = i+1;
							while (j < tt[dirIdx].length)	{
								if (tt[dirIdx][j][idx1] > -1)	{		// Zeit gefunden	
									next = j;
									j = tt[dirIdx].length;
								}
								j++;
							}	
		
							while ((tt[dirIdx][i-1][idx1] + minInterval) < (tt[dirIdx][next][idx1])) {	// Zwischenwerte berechnen					
								a = new Array;
								a.push(0);
								addInterval += minInterval; 
								for (k = 1; k < tt[dirIdx][0].length; k++) {		// for all stations 
		
									if (tt[dirIdx][i][k] > -2)	{ 
										a.push(tt[dirIdx][i][k]);									
									} else {
		
										// Vorgner von Interval suchen
										j = alti;
										while (j > 0)	{
											if (tt[dirIdx][j][k] > -1)	{		// Zeit gefunden	
												prev2 = j;
												j = 0;
												
												// Start-Intervall-Zeit fr vom Vorgnger berechnen
												startZeitInterval2 = 0;
												m = 1;
												while (m < tt[dirIdx][0].length) {		// for all stations, bis minInterval gefunden
													if ((tt[dirIdx][prev2][m] > -1) && (tt[dirIdx][i][m] == minIntervalPos) && (tt[dirIdx][i-1][m] > -1))	{		// Zeit fr Vorgnger, fr Interval-Wert und Zeit fr direkten Vorgnger vorhanden
														startZeitInterval2 = tt[dirIdx][alti][m] - tt[dirIdx][prev2][m];		// Zeit des direkter Vorgnger-Feldes - Zeit des aktuellen Vorgnger-Feldes
														m = tt[dirIdx][0].length;
													}
													m++;
												}										
												
											}
											j--;
										}						
		
										// Nachfolger suchen
										j = i+1;
										while (j < tt[dirIdx].length)	{
											if (tt[dirIdx][j][k] > -1)	{		// Zeit gefunden	
												next2 = j;
												j = tt[dirIdx].length;
											}	// if
											j++;
										}	// while j < tt[dirIdx].length
										
										//	if ( (t[next2][k] > -1) && ( ( (startZeitInterval2 + addInterval) % oInterval[Math.abs(t[i][k])] ) == 0) ) {	// erster Teil nicht ntig(?) - wenn Interval-Zeit fr Zeile(bzw. Feld) vorhanden								
										// if ( ( (startZeitInterval2 + addInterval) % oInterval[Math.abs(tt[dirIdx][i][k])] ) == 0) {	// erster Teil nicht ntig(?) - wenn Interval-Zeit fr Zeile(bzw. Feld) vorhanden
										ivTemp = getInterval(Math.abs(tt[dirIdx][i][k]));										
										if ( ( (startZeitInterval2 + addInterval) % ivTemp ) == 0) {	// erster Teil nicht ntig(?) - wenn Interval-Zeit fr Zeile(bzw. Feld) vorhanden
							 				if (tt[dirIdx][prev2][k] != -1)	{  
												a.push(tt[dirIdx][prev2][k] + startZeitInterval2 + addInterval)  
											} else  {	
												//	'kommt normalerweise nicht vor!';									
												a.push(-1)	
											}	
										} else {
											a.push(-1);										
										} 	// if
									}							
								}	// for k
								tt[dirIdx].splice(i, 0, a); 
								i++;	
								
								// Nachfolger von Interval suchen
								j = i+1;
								while (j < tt[dirIdx].length)	{
									if (tt[dirIdx][j][idx1] > -1)	{		// Zeit gefunden	
										next = j;
										j = tt[dirIdx].length;
									}
									j++;
								}						
								
								
							}	// while
							tt[dirIdx].splice(i, 1);
						}
					} 
				}
				i++;				
			}
		  i = 1;
		  	  
		  while (i < tt[dirIdx].length) {
				j = 1; 
				v1 = -1; 
				v2 = -1;
				// if (stationPos == 0)	{		// hier keine Stationsauswahl mglich, daher immer 0
				while (j < tt[dirIdx][i].length) {
					v1 = tt[dirIdx][i][j];
					if (v1 != -1) {
						idx = j;
						j = tt[dirIdx][i].length;
					} else {
						j++;
					}
				}
				j = tt[dirIdx][i].length-1;
				while (j > 0) {
					v2 = tt[dirIdx][i][j];
					j = (v2 != -1) ? 0 : j-1;
				}	
				// auskommentiert - Stationsauswahl hier nicht mglich (07.1.13)
				/* }	else	{
					idx = document.fmSelect.sbStations.options[document.fmSelect.sbStations.selectedIndex].value;
					v1 = tt[dirIdx][i][idx];		
					v2 = v1;	*/
				// }
				if ((toMinutes < v1) || (fromMinutes > v2)) {
					tt[dirIdx].splice(i,1);
				} else {
					i++;
				}
			}
		}	// for dirIdx...				
	 	showGraphicalTimetableDoubleStations();						
	}	// showGraphicalTimetableExpandTT()
	
	this.showGraphicalTimetableFillTT2 = function(t)	{
		// alert('showGraphicalTimetableFillTT2()');
		var i,j;
		tt[1] = new Array();
		for (i=0; i<t.length; i++)	{	
			tt[1][i] = new Array();
			for (j=0; j<t[i].length; j++)	{
				tt[1][i][j] = t[i][j];
			}
		}
		showGraphicalTimetableExpandTT();
	}	// showGraphicalTimetableFillTT2()	

	this.showGraphicalTimetableFillTT = function(t)	{
		// alert('showGraphicalTimetableFillTT()');
		var i,j;
		tt[0] = new Array();
		for (i=0; i<t.length; i++)	{	
			tt[0][i] = new Array();
			for (j=0; j<t[i].length; j++)	{
				tt[0][i][j] = t[i][j];
			}
		}	
		if (direction2 != -1)	{
			publicSQL.query('select * from tt_' + lineConnectionID2, 'showGraphicalTimetableFillTT2');				
		} else {
			showGraphicalTimetableExpandTT();
		}		
	}	// showGraphicalTimetableFillTT()

	this.showGraphicalTimetableStationsToTable2 = function(t)	{
		// alert('showGraphicalTimetableStationsToTable2()');
		var i;	
		stationTextArray2 = [];
		for (i=1; i<t.length; i++) {	
			stationTextArray2[stationTextArray2.length] = t[i][0];
		}
		publicSQL.query('select * from tt_' + lineConnectionID, 'showGraphicalTimetableFillTT');			
	}	// showGraphicalTimetableStationsToTable2()	
	
	this.showGraphicalTimetableStationsToTable = function(t)	{
		// alert('showGraphicalTimetableStationsToTable()');
		var i;
		stationTextArray = [];
		for (i=1; i<t.length; i++) {	
			stationTextArray[stationTextArray.length] = t[i][0];
		}
		if (direction2 != -1)	{
				publicSQL.query('select s.Station from ttc_' + lid + ' t, stations s where t.StationID = s.ID and t.DayGroupID = ' + dgid 
												+ ' and t.Direction = ' + direction2 + ' order by t.Position', 'showGraphicalTimetableStationsToTable2');	
		} else {		
			publicSQL.query('select * from tt_' + lineConnectionID, 'showGraphicalTimetableFillTT');	
			
		}		
	}	// showGraphicalTimetableStationsToTable()	
		

	
	fromMinutes = getMinutesFromTime(fromTime);
	toMinutes 	= getMinutesFromTime(toTime);
	if (fromMinutes > toMinutes)	{  // 1. Zeit darf nicht grer wie 2. Zeit sein
		toMinutes = fromMinutes;
	}	
	
	
	// Canvas-ID zuweisen...
  if (cbFunc != undefined)	{	// Funktionsparameter vorhanden
  	cid = ((arguments.length > 8) && (typeof arguments[arguments.length-2] === "string")) ? arguments[arguments.length-2] : undefined;
  } else {	// kein Funktionsparameter vorhanden
  	cid = ((arguments.length > 7) && (typeof arguments[arguments.length-1] == "string")) ? arguments[arguments.length-1] : undefined; 		  	
  }
  
  // Farbobjekt zuweisen...
  if (cbFunc == undefined)	{  	// muss letztes oder vorletztes Argument sein, falls vorhanden
  	if (cid == undefined)	{			// muss letztes Argument sein, falls vorhanden
  		colObj = ((arguments.length > 7) && (typeof arguments[arguments.length-1] == "object")) ? arguments[arguments.length-1] : grapicalScheduleColors; 
  	} else {		
			colObj = (typeof arguments[arguments.length-2] == "object") ? arguments[arguments.length-2] : grapicalScheduleColors;   		  		
		}
  } else {											// muss vorletztes oder vor-vorletztes Argument sein, falls vorhanden
  	if (cid == undefined)	{			// muss vorletztes Argument sein, falls vorhanden
  		colObj = (typeof arguments[arguments.length-2] == "object") ? arguments[arguments.length-2] : grapicalScheduleColors; 
  	} else {		
			colObj = (typeof arguments[arguments.length-3] == "object") ? arguments[arguments.length-3] : grapicalScheduleColors;   		  		
		}  	  	
  	// colObj = ((arguments.length > 9) && (typeof arguments[arguments.length-2] == "object")) ? arguments[arguments.length-2] : grapicalScheduleColors; 
  }		
 
  // falls ntig Canvas erstellen...
  if (cid == undefined)	{   	
		var cv = document.createElement("canvas");
		// document.createElement("canvas").setAttribute("id", cid, 0);
		cv.setAttribute("id", "showGraphicalTimetableCanvas");				
		cid = cv.getAttribute("id");
		document.getElementsByTagName("body")[0].appendChild(cv);   	   	
  }
	document.getElementById(cid).style.visibility = "hidden";				// Canvas unsichtbar

	publicSQL.query('select s.Station from ttc_' + lid + ' t, stations s where t.StationID = s.ID and t.DayGroupID = ' + dgid 
									+ ' and t.Direction = ' + direction + ' order by t.Position', 'showGraphicalTimetableStationsToTable');	
	
}	// function showGraphicalTimetable()	{

/* Bildfahrplan-Dialog anzeigen; cid = Canvas-ID, optPar1 = Callback-Funktion	*/
function showGraphicalTimetableForm(did, cid, optPar1)	{	
	// alert('showGraphicalTimetableForm()');
	
	var i;
	// var first = false;
	var fm;	// Formular
  var newOpt;
	var neuer;
	var aktHours, aktMinutes;
  var jetzt = new Date(); 	
  var colObj = new Object();  
  
  // this.showGraphicalTimetableFormStart()	{		
  this.showGraphicalTimetableFormStart  = function()	{		// Anzeige		
  	// alert("showGraphicalTimetableFormStart"); 
 	  var m1, m2;

  	// korrigieren, wenn Startzeit > Endzeit...
	  m1 = (	(document.fmSelect.sbHours1[document.fmSelect.sbHours1.selectedIndex].value * 60) 
	  							+ (document.fmSelect.sbMinutes1[document.fmSelect.sbMinutes1.selectedIndex].value * 1));
	  m2 = (	(document.fmSelect.sbHours2[document.fmSelect.sbHours2.selectedIndex].value * 60) 
	  							+ (document.fmSelect.sbMinutes2[document.fmSelect.sbMinutes2.selectedIndex].value * 1));
		if (m1 > m2)	{
			document.fmSelect.sbHours2.selectedIndex = document.fmSelect.sbHours1.selectedIndex;
			document.fmSelect.sbMinutes2.selectedIndex = document.fmSelect.sbMinutes1.selectedIndex;
		}	  	
		
		// Farbobject initialisieren
		for (i=0; i<document.fmSelect.sbColorOptions.length; i++)	{
	 		// in value steht die Farbe, id ist identisch mit Array-Element-Name
			colObj[document.fmSelect.sbColorOptions[i].id] = document.fmSelect.sbColorOptions[i].value;
		}
		
		if (optPar1 != undefined)	{		// Funktionsparameter bergeben
			showGraphicalTimetable(	document.fmSelect.sbLines.options[document.fmSelect.sbLines.selectedIndex].value,
															document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value, 
															document.fmSelect.sbDirection.options[document.fmSelect.sbDirection.selectedIndex].value,
															parseInt(document.fmSelect.sbHours1.options[document.fmSelect.sbHours1.selectedIndex].value) * 60
															+ parseInt(document.fmSelect.sbMinutes1.options[document.fmSelect.sbMinutes1.selectedIndex].value),
															parseInt(document.fmSelect.sbHours2.options[document.fmSelect.sbHours2.selectedIndex].value) * 60
															+ parseInt(document.fmSelect.sbMinutes2.options[document.fmSelect.sbMinutes2.selectedIndex].value),	
															parseInt(document.fmSelect.sbCanvasWidth.options[document.fmSelect.sbCanvasWidth.selectedIndex].value),
															parseInt(document.fmSelect.sbCanvasHeight.options[document.fmSelect.sbCanvasHeight.selectedIndex].value),
															colObj, cid, optPar1);													
		} else {											// kein Funktionsparameter bergeben															
			showGraphicalTimetable(	document.fmSelect.sbLines.options[document.fmSelect.sbLines.selectedIndex].value,
															document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value, 
															document.fmSelect.sbDirection.options[document.fmSelect.sbDirection.selectedIndex].value,
															parseInt(document.fmSelect.sbHours1.options[document.fmSelect.sbHours1.selectedIndex].value) * 60
															+ parseInt(document.fmSelect.sbMinutes1.options[document.fmSelect.sbMinutes1.selectedIndex].value),
															parseInt(document.fmSelect.sbHours2.options[document.fmSelect.sbHours2.selectedIndex].value) * 60
															+ parseInt(document.fmSelect.sbMinutes2.options[document.fmSelect.sbMinutes2.selectedIndex].value),	
															parseInt(document.fmSelect.sbCanvasWidth.options[document.fmSelect.sbCanvasWidth.selectedIndex].value),
															parseInt(document.fmSelect.sbCanvasHeight.options[document.fmSelect.sbCanvasHeight.selectedIndex].value),
															colObj, cid);													
		}
	} 	// this.showGraphicalTimetableFormStart()      
  
	this.showGraphicalTimetableFormChangeColorOptions = function()	{ 
		// alert('showGraphicalTimetableFormChangeColorOptions()');
		var i;
		var sel;	
	  // Farbe in Selectbox anzeigen...
	  for (i=0;i<this.length;i++)	{
	  	this.options[i].style.backgroundColor='white';
	  	this.options[this.selectedIndex].style.backgroundColor='red';
	  }		
	  // zugehrige Farbe in Farbbox einstellen..
		sel = document.fmSelect.sbColorOptions.options[document.fmSelect.sbColorOptions.selectedIndex].value;
		for (i=0; i<document.fmSelect.sbColors.length; i++)		{	// Farbe suchen
			if (document.fmSelect.sbColors.options[i].value == sel)		{	// ausgewhlte Farbe gefunden
				document.fmSelect.sbColors.selectedIndex = i;
				document.fmSelect.sbColors.style.backgroundColor = sel;
				document.fmSelect.sbColors.style.color = document.fmSelect.sbColors.options[document.fmSelect.sbColors.selectedIndex].style.color;				
				i =  document.fmSelect.sbColors.length;					// Schleifenabbruch
			}
		}	
	}	// showGraphicalTimetableFormChangeColorOptions()
 
	this.showGraphicalTimetableFormChangeColors = function()	{
		// alert('showGraphicalTimetableFormChangeColors()');
		var i;
		var sel;
		var s;
		sel = document.fmSelect.sbColors.options[document.fmSelect.sbColors.selectedIndex].value;					// gewhlte Farbe
		document.fmSelect.sbColorOptions.options[document.fmSelect.sbColorOptions.selectedIndex].value = sel;		// Farbe der aktiven Option zuweisen
		document.fmSelect.sbColors.style.backgroundColor = document.fmSelect.sbColorOptions.options[document.fmSelect.sbColorOptions.selectedIndex].value;
		document.fmSelect.sbColors.style.color = document.fmSelect.sbColors.options[document.fmSelect.sbColors.selectedIndex].style.color;	
	}	// showGraphicalTimetableFormChangeColors()
    
	this.showGraphicalTimetableFormNewDir = function()	{		
		// alert('showGraphicalTimetableFormNewDir()');								
		var i;
		var neuer;
	  var alt = 0;		
		var wert;
		// var direction;
		var lid  = document.fmSelect.sbLines.options[document.fmSelect.sbLines.selectedIndex].value;  // aktuelle Linie			
		var dgid = document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value;  // aktuelle Tag-Gruppe			
		document.fmSelect.sbDirection.length = 0;
		for (i=0; i<lineConnectionsByLineIdArray[lid].length; i++) {
			if (document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value == lineConnections[lineConnectionsByLineIdArray[lid][i]].DayGroupID)  {  // richtige DayGroup
				wert = lineConnections[lineConnectionsByLineIdArray[lid][i]].Direction;			
	    	if (wert != alt) {			
					neuer = new Option(wert, wert, false, false);
					document.fmSelect.sbDirection.options[document.fmSelect.sbDirection.length] = neuer;
				}
	    	alt = wert;
	    }
		}
		document.fmSelect.sbDirection.selectedIndex = 0;
		// direction = document.fmSelect.sbDirection.options[document.fmSelect.sbDirection.selectedIndex].value;
		// publicSQL.query('select t.Position, s.Station  from ttc_' + lid + ' t, stations s where t.StationID = s.ID and t.DayGroupID = ' + dgid + ' and t.Direction = ' + direction + ' order by t.Position'
		// 								, 'showGraphicalTimetableFormNewStations');	
	}	// showGraphicalTimetableFormNewDir()	
	
	/* Wochentage-Auswahl */
	this.showGraphicalTimetableFormNewDirAndDays = function()	{		
		// alert('showGraphicalTimetableFormNewDirAndDays()');
		var i, j;	  
	  var wert;
	  var alt = 0;
	  var neuer;
		var lid = document.fmSelect.sbLines.options[document.fmSelect.sbLines.selectedIndex].value;  // aktuelle Linie	  
	  document.fmSelect.sbDays.length = 0; 
	  for (i=0; i<lineConnectionsByLineIdArray[lid].length; i++) {
	    wert = lineConnections[lineConnectionsByLineIdArray[lid][i]].DayGroupID;
	    if (wert != alt) {
	    	wert = parseInt(wert);
	      neuer = new Option(dayGroups[dayGroupsByIdArray[wert]].Text, wert, false, false); 
	      document.fmSelect.sbDays.options[document.fmSelect.sbDays.length] = neuer; 
	    }
	    alt = wert;
	  }
	  // daygroupID = document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value; 
	  // publicSQL.query('select lc.Direction from line_connections lc where lc.LineID = ' + lineID + ' and lc.DayGroupID = ' + daygroupID + ' order by lc.Direction', 'newDir'); 		
	  showGraphicalTimetableFormNewDir();		
	}	// showGraphicalTimetableFormNewDirAndDays()	    
  
	/* Formular erstellen */
	
	fm = '<form name="fmSelect" id="fmSelect">';	
		fm += '<p>';
			// Linie...
			// <p style="white-space:nowrap">
			fm += '<strong>' + actLanguageText.line + ':</strong> ';
			// fm += '<select name="sbLines" id="sbLines" onChange="showTimetableChangeLine();">';
			fm += '<select name="sbLines" id="sbLines" onChange="showGraphicalTimetableFormNewDirAndDays();">';
			fm += '</select> ';
			// Wochentag(e)...
			fm += '<strong>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' + actLanguageText.operating_days + ':</strong> '; 
		  // fm += '<select name="sbDays" id="sbDays" onChange="showTimetableChangeDays()">';
		  fm += '<select name="sbDays" id="sbDays" onChange="showGraphicalTimetableFormNewDir()">';
		  fm += '</select> ';
		  // Richtung...
		  fm += '<strong>&nbsp;&nbsp;&nbsp;&nbsp;' + actLanguageText.direction + ':</strong> ';
		  // fm += '<select name="sbDirection" id="sbDirection" onChange="showTimetableChangeDirection()">';
		  fm += '<select name="sbDirection" id="sbDirection" onChange="showGraphicalTimetableFormNewStations()">';
		  fm += '</select>';
	  fm += '</p>';
		// fm += '<p style="white-space:nowrap">';
		
		fm += '<p>';
			// Startzeit (von)...
			// fm += 'Von';
			fm += '<strong>' +   actLanguageText.from_time + '</strong> ';
		  fm += '<select name="sbHours1" id="sbHours1">';
			fm += '</select>';
		  fm += '<select name="sbMinutes1" id="sbMinutes1">';
		  fm += '</select> ';
		  // Endzeit (bis)...
		  // fm += 'Uhr bis ';
		  fm += '<strong>' + actLanguageText.to_time + '</strong> ';
			fm += '<select name="sbHours2" id="sbHours2">';
		  fm += '</select>';
		  fm += '<select name="sbMinutes2" id="sbMinutes2">';
		  fm += '</select> ';
		  // fm += 'Uhr &nbsp;</strong>';
		  fm += '<strong>' + actLanguageText.o_clock + ' &nbsp;&nbsp;</strong>';
		  // fm += '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';  
	  fm += '</p>';
	  
		fm += '<p style="white-space:nowrap">';
			// Farben...';
			fm += '<strong>Farben:</strong> ';
		  fm += '<select name="sbColorOptions" onChange="showGraphicalTimetableFormChangeColorOptions();">';
				fm += '<option id="bgColor"							value="white" >Hintergrund</option>';
		    fm +=	'<option id="lineColor1"						value="green" >Richtung 1</option>';
		    fm += '<option id="lineColor2"						value="blue">Richtung 2</option>';
		    fm += '<option id="lineColorStart1"			value="red">Richtung 1 Start</option>';
		    fm += '<option id="lineColorStart2"			value="red">Richtung 2 Start</option>';
		    fm += '<option id="lineColorHalt1"				value="green">Richtung 1 Halt</option>';
		    fm += '<option id="lineColorHalt2"				value="blue">Richtung 2 Halt</option>';
		    fm += '<option id="lineColorEnd1"				value="black">Richtung 1 Ende</option>';
		    fm += '<option id="lineColorEnd2"				value="black">Richtung 2 Ende</option>';
		    fm += '<option id="stationLine"					value="gray">Stations-Linie</option>';
		    fm += '<option id="timeLine"							value="gray">Zeit-Linie</option>';
		    fm += '<option id="timeStepLine" 				value="gray">Zeit-Zwischenschritt</option>';
		    fm += '<option id="timeText"							value="black">Zeit-Text</option>';
		    fm += '<option id="activeStationText"		value="black">Stations-Name</option>';
		    fm += '<option id="inactiveStationText"	value="red">Stations-Name (ohne Halt)</option>		                                          ';
		  fm += '</select>  ';
		  fm += '<select name="sbColors" onChange="showGraphicalTimetableFormChangeColors();" style="width:100px"> 	       	';
				fm += '<option value="white" 	style="background-color: white; color:#000000"> Weiss</option>';
				fm += '<option value="yellow" 	style="background-color: yellow; color:#000000"> Gelb</option>';
				fm += '<option value="fuchsia" style="background-color: fuchsia; color:#000000"> Fuchsia</option>';
				fm += '<option value="red" 	style="background-color: red; color:#000000"  >Rot</option>';
				fm += '<option value="purple" 	style="background-color: purple; color:#FFFFFF"> Violett</option>';
				fm += '<option value="lime" 	style="background-color: lime; color:#000000"> Hellgrn</option> 	';
				fm += '<option value="olive" 	style="background-color: olive; color:#FFFFFF"> Olivgrn</option>	';
				fm += '<option value="green" 	style="background-color: green; color:#FFFFFF"> Grn</option> 	';
				fm += '<option value="teal" 	style="background-color: teal; color:#FFFFFF"> Blaugrn</option> 	';
				fm += '<option value="aqua" 	style="background-color: aqua; color:#000000"> Hellblau</option> 	';
				fm += '<option value="blue" 	style="background-color: blue; color:#FFFFFF"> Blau</option> 	';
				fm += '<option value="navy" 	style="background-color: navy; color:#FFFFFF"> Marinenblau</option> 	';
				fm += '<option value="maroon" 	style="background-color: maroon; color:#FFFFFF"> Kastanie</option>';
				fm += '<option value="silver" 	style="background-color: silver; color:#000000"> Silber</option> 	';
				fm += '<option value="gray" 	style="background-color: gray; color:#000000"> Grau</option>';
				fm += '<option value="black" 	style="background-color: black; color:#FFFFFF"> Schwarz</option>';
		  fm += '</select> ';
		  // Breite...';
		  fm += '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<strong>' + actLanguageText.width + ':</strong> ';
		  fm += '<select name="sbCanvasWidth" id="sbCanvasWidth" onChange="changeCanvasWidth()">';
				fm += '<option value="200">200</option>';
				fm += '<option value="400">400</option>';
				fm += '<option value="600">600</option>';
				fm += '<option  selected value="800">800</option>';
				fm += '<option value="1000">1000</option>';
				fm += '<option value="1200">1200</option>';
				fm += '<option value="1400">1400</option>';
				fm += '<option value="1600">1600</option>';
				fm += '<option value="1800">1800</option>';
				fm += '<option value="2000">2000</option>';
		  fm += '</select> ';
		  // Mindest-Hhe...';
		  fm += '<strong>&nbsp;&nbsp;&nbsp;&nbsp;Mindest-H&ouml;he:</strong> ';
		  fm += '<select name="sbCanvasHeight" id="sbCanvasHeight" onChange="changeCanvasMinHeight()">';
				fm += '<option value="200">200</option>';
				fm += '<option value="400">400</option>';
				fm += '<option  selected value="600">600</option>';
				fm += '<option value="800">800</option>';
				fm += '<option value="1000">1000</option>';
				fm += '<option value="1200">1200</option>';
				fm += '<option value="1400">1400</option>';
				fm += '<option value="1600">1600</option>';
				fm += '<option value="1800">1800</option>';
				fm += '<option value="2000">2000</option>';
		  fm += '</select>';
		  fm += '&nbsp;&nbsp;&nbsp;';
	  fm += '<p>';  	 
	  fm += '</p>';  	 
	  	fm += '<input name="btStart" type="button" id="btStart" onClick="showGraphicalTimetableFormStart();" value="' + actLanguageText.start_for_button + '">';	  
	  fm += '</p>';  	 
	fm += '</form>';			
	document.getElementById(did).innerHTML = fm;	
		
	/* Formularelemente fllen  */
	
	// Linen-Auswahl...
  for (i=0; i<lines.length; i++) {	
    newOpt = new Option(lines[i].Line, lines[i].ID, false, false); 
    document.fmSelect.sbLines.options[i] = newOpt;
  }
  document.fmSelect.sbLines.selectedIndex = 0;
  // Von- und Bis-Zeit...
	for (i=0; i<24; i++)	{
		neuer = (i>9) ? new Option(i, i, false, false) : new Option(('0' + i), i, false, false);
		document.fmSelect.sbHours1.options[i] = neuer;
		neuer = (i>9) ? new Option(i, i, false, false) : new Option(('0' + i), i, false, false);
		document.fmSelect.sbHours2.options[i] = neuer;		
	}
	for (i=0; i<12; i++)	{
		neuer = (i>1) ? new Option(i*5, i*5, false, false) : new Option(('0' + i*5), (i*5), false, false)
		document.fmSelect.sbMinutes1.options[i] = neuer;
		neuer = (i>1) ? new Option(i*5, i*5, false, false) : new Option(('0' + i*5), (i*5), false, false)
		document.fmSelect.sbMinutes2.options[i] = neuer;		
	}
	
	aktHours = jetzt.getHours();
	aktMinutes = jetzt.getMinutes();
	aktMinutes = Math.floor(aktMinutes - (aktMinutes % 5));
	document.fmSelect.sbHours1.selectedIndex = aktHours;		
	document.fmSelect.sbMinutes1.selectedIndex = (aktMinutes / 5);
	if (aktHours < 22)	{
		document.fmSelect.sbHours2.selectedIndex = aktHours + 2;			
		document.fmSelect.sbMinutes2.selectedIndex = (aktMinutes / 5);				
	} else	{	
		document.fmSelect.sbHours2.selectedIndex = 23;		
		document.fmSelect.sbMinutes2.selectedIndex = 11;		
	}  
 
 	showGraphicalTimetableFormChangeColorOptions();	// richtige Farbe in Farbauswahlbox anzeigen
 
	showGraphicalTimetableFormNewDirAndDays();  // Wochentage-Auswahl und davon abhngige Dialogfelder    
  
}	//	showGraphicalTimetableForm()


/* Stations-Farhplan anzeigen; optPar1 = Callback-Funktion	*/
function showStationTimetable(sid, lid, dgid, direction, tid, optPar1)	{
	// alert('showStationTimetable()');
  var lineConnectionID = getLineConnectionId(lid, dgid, direction);
  var tb = document.getElementById(tid);
  var cbFunc = ((arguments.length > 5) && (typeof arguments[arguments.length-1] == "function")) ? arguments[arguments.length-1] : undefined; 
	var lineName = getLineName(lid);
	var stationName = getStationName(sid);
	var stationPos;     // Position der Station im Fahrplan
	
	/* Callback-Funktion aufrufen oder zurck zum Hauptprogramm	*/
	this.showStationTimetableCallBack = function()	{
		// alert('showStationTimetableCallBack()');
		if (cbFunc !== "undefined")	{	
	 		cbFunc();	// zur Callback-Funktion gehen
	 	}		
	 }	// showStationTimetableCallBack()	
	
	this.showStationTimetableTTC = function(t)	{
		// alert('showStationTimetableTTC()');		
		var foundIndex = -1;
	  var a = document.getElementById(tid);
	  a.tBodies[0].rows[0].cells[0].innerHTML = '<b>' + lineName + '</b>'; 
	  for (i=1; i<t.length; i++) {
	    a.tBodies[0].rows[i].cells[0].innerHTML = '<b>' + t[i][0] + '</b>';
	    a.tBodies[0].rows[i].cells[0].bgColor = "#CCCCFF";
	    if (t[i][0] == stationName) 	{			// is selected station?
	   		for (var j=1; j<a.tBodies[0].rows[i].cells.length; j++)	{				// all courses
		   		if (a.tBodies[0].rows[i].cells[j].rowSpan == 1) 	{						// single cell
						if ( (i == t.length-1) || (t[i+1][0] != stationName) )	{		// not next one with self station?
		   				a.tBodies[0].rows[i].cells[j].bgColor = "#EDCBA";
		   				foundIndex = i;
		   			}
		   		}
	    	}    	
	    }
	  }
	  document.getElementById(tid).style.visibility = "visible"; 		
		showStationTimetableCallBack();  // Callback-Funktion aufrufen oder zurck zum Hauptprogramm 						  				
	}	// showStationTimetableTTC()
	
	this.showStationTimetableTT = function(t)	{
		// alert('showStationTimetableTT()');		
		var q;
	  var i,j,k;
	  var a = new Array();
	  var newTR, newTD, newTDText;
	  var stunde, minute, feld;
		var isEmpty;
		
		// delete empty courses
	  for (i=t.length-1; i>0; i--) {	
			isEmpty = true;
		  for (j=1; j<t[1].length; j++) {
				if (isEmpty == true) {
					isEmpty = (t[i][j] == -1) 
				}
			}
			if (isEmpty	== true) {
				t.splice(i,1);
			}
		}
		
	  // publicSQL.htmlTableDelete("mytable")
	  // document.getElementById("mytable").style.visibility = "hidden";
	  publicSQL.htmlTableDelete(tb);	  
	  document.getElementById(tid).style.visibility = "hidden";
	  for (i=0; i<t[1].length; i++) {		// all stations
	    newTR = document.getElementById(tid).insertRow(i);
	    newTD = document.createElement("td");
	    newTDtext = document.createTextNode("");
	    newTD.appendChild(newTDtext);
	    newTR.appendChild(newTD); 
	    for (j=1; j<t.length; j++) {		// all courses
	      newTD = document.createElement("td");
	      if ( (i>0) && ((i % 2) == 0) ) {		// cycle colors
	        newTD.bgColor = "#F0F0F0";
	      } else {
	        newTD.bgColor = "#E0E0E0"; 
	      }
	      if (i == 0) {
					feld = j;
	        newTD.bgColor = "#CCCCFF"; 
	      } else {
	        if (t[j][i] > -1) {
	          stunde = Math.floor(t[j][i] / 60);
	          minute = t[j][i] - (stunde * 60);
	          stunde = ((stunde > 23) ? stunde - 24 : stunde); 
	          feld = ((stunde < 10) ? "0" + stunde : stunde);
	          feld = feld + ":" + ((minute < 10) ? "0" + minute : minute);
	        } else if (t[j][i] == -1) {
	          feld = ""; 
	        } else if (t[j][i] < -1) {
	          if (t[j][i] > -1000) {
	            // feld = "alle " + oInterval[Math.abs(t[j][i])] + " Min.";
	            feld = actLanguageText.interval_minutes_before + " " + getInterval(Math.abs(t[j][i])) + " " + actLanguageText.interval_minutes_after;	            
	            k = i+1;
	            newTD.bgColor = "#E8E8E8";
	            newTD.style.textAlign = "center";
	            a[j] = newTD;
	            while ( (k <t[1].length) && (t[j][k] == t[j][i]) ) {
	              t[j][k] = -1000 - i;
	              k++;
	            }
	          } else {
	            a[j].rowSpan++;
	          }
	        } 
	      }
	      if (t[j][i] > -1000) {
	        newTDtext = document.createTextNode(feld);
	        newTD.appendChild(newTDtext);
	        newTR.appendChild(newTD); 
	      }
	    }
	  }
		q = 'select s.Station, s.Position from ttc_' + lid + ' t, stations s WHERE t.Position >= ' + stationPos +
				' AND t.StationID = s.ID and t.DayGroupID = ' + dgid + ' and t.Direction = ' + direction + ' order by t.Position';
	  publicSQL.query(q, 'showStationTimetableTTC');		
		
	}	// showStationTimetableTT()
	
	/* erstellt Abfrage fr Fahrplan fr Station stationPos und alle nachfolgenden Stationen	*/
	this.showStationTimetableGetNextStations = function(t)	{		// select following stations
		// alert('showStationTimetableGetNextStations()');		
		var q;
		var positions = 'ID';	
	  for (i=1; i<t.length; i++) {
			positions = positions + ',';
			positions = positions + t[i][1];
		}
		q = 'select ' + positions + ' from tt_' + lineConnectionID;
	  publicSQL.query(q, 'showStationTimetableTT');				
	}	// showStationTimetableGetNextStations()
		     
	/* setzt stationPos (Position der Station im Fahrplan)	*/
	this.showStationTimetableGetStationPos = function(t)	{
		// alert('showStationTimetableGetStationPos()');	
		stationPos = t[1][0];		
		if ( (t.length > 2) && (t[1][0] == (t[2][0]-1)) )	{		// if 2 self stations -> second one
			stationPos = t[2][0];
		}							
		publicSQL.query('SELECT StationID, Position from ttc_' + lid + ' WHERE DayGroupID = ' + dgid + ' and Direction = ' 
										+ direction + ' AND Position >= ' + stationPos + ' ORDER BY Position', 'showStationTimetableGetNextStations');	// select following stations		
		
	}	// showStationTimetableGetStationPos()
	
	publicSQL.query('SELECT Position from ttc_' + lid + ' WHERE DayGroupID = ' + dgid + ' and Direction = ' + direction + ' and StationID = ' 
									+ sid + ' ORDER BY Position', 'showStationTimetableGetStationPos');
	
}	// showStationTimetable()

function showStationTimetableForm(did, tid, optPar1)	{	
	// alert('showStationTimetableForm()');
	var i;
	// var first = false;
	var fm;	// Formular
  var newOpt;
	var neuer;
	var sid;
	var lid;
	var dgid;
	var direction;
	
	var firstStationId;
	var firstStationName;
	var lastStationId;
	var lastStationName;
	var firstStationMultiple;
	var lastStationMultiple;

	this.showStationTimetableFormStart = function()	{
		// alert('showStationTimetableFormStart()');
		showStationTimetable(sid, lid, dgid, direction, tid, optPar1);
	}	// showStationTimetableFormStart()

	this.showStationTimetableFormNewDir = function()	{
		// alert('showStationTimetableFormNewDir');		
		var i;
		var neuer;
	  var alt = 0;		
		var wert;
		// var direction;
		// var lid  = document.fmSelect.sbLines.options[document.fmSelect.sbLines.selectedIndex].value;  // aktuelle Linie			
		// var dgid = document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value;  // aktuelle Tag-Gruppe			
		document.fmSelect.sbDirection.length = 0;
		for (i=0; i<lineConnectionsByLineIdArray[lid].length; i++) {
			if (dgid == lineConnections[lineConnectionsByLineIdArray[lid][i]].DayGroupID)  {  // richtige DayGroup
				wert = lineConnections[lineConnectionsByLineIdArray[lid][i]].Direction;			
	    	if (wert != alt) {		
	    		if (wert == 1)	{	// Richtung 1
		    		if ( (sid != lastStationId)	|| (lastStationMultiple == true) )	{	
							neuer = new Option(getStationName(lastStationId), wert, false, false);
							document.fmSelect.sbDirection.options[document.fmSelect.sbDirection.length] = neuer;
						}
					} else if (wert == 2)	{	// Richtung 2
						if ( (sid != firstStationId) || (firstStationMultiple == true) )	{
							neuer = new Option(getStationName(firstStationId), wert, false, false);
							document.fmSelect.sbDirection.options[document.fmSelect.sbDirection.length] = neuer;
						}
					}
				}
	    	alt = wert;
	    }
		}
		if (document.fmSelect.sbDirection.length > 1)		{
			if (document.fmSelect.sbDirection.options[0].text == document.fmSelect.sbDirection.options[1].text)	{		// self stations?
				 document.fmSelect.sbDirection.options[0].text = document.fmSelect.sbDirection.options[0].text + ' (1)';
				 document.fmSelect.sbDirection.options[1].text = document.fmSelect.sbDirection.options[1].text + ' (2)';
			}
		}					
		document.fmSelect.sbDirection.selectedIndex = 0;		
		direction = document.fmSelect.sbDirection.options[0].value; 			
	}	// showStationTimetableFormNewDir()

	/* Wochentage-Auswahl */
	this.showStationTimetableFormNewDayGroups = function()	{		
		// alert('showStationTimetableFormNewDayGroups()');		
		var i;	  
	  var wert;
	  var alt = 0;
	  var neuer;
	  document.fmSelect.sbDays.length = 0; 
	  for (i=0; i<lineConnectionsByLineIdArray[lid].length; i++) {
	    wert = lineConnections[lineConnectionsByLineIdArray[lid][i]].DayGroupID;
	    if (wert != alt) {
	    	wert = parseInt(wert);
	      neuer = new Option(dayGroups[dayGroupsByIdArray[wert]].Text, wert, false, false); 
	      document.fmSelect.sbDays.options[document.fmSelect.sbDays.length] = neuer; 
	    }
	    alt = wert;
	  }
	  dgid = document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value; 	  
	  showStationTimetableFormNewDir();			  
	}	// showStationTimetableFormNewDayGroups()	    

	this.showStationTimetableFormNewFirstLastStations = function()	{
		// alert('showStationTimetableFormNewFirstLastStations()');
		// var foundfirst = -1;
		// var foundnext = -1;
		firstStationId = stations[lineStationsByLineIdArray[lid][0]].ID;
		// firstStationName = t[1][1];
		lastStationId = stations[lineStationsByLineIdArray[lid][lineStationsByLineIdArray[lid].length-1]].ID;
		// lastStationName = t[t.length-1][1];	
		firstStationMultiple = false;
		lastStationMultiple = false;
		// stationIDMultiple	= false;				
		
		// for (var i=1; i<t.length; i++) {						// test for multiple first- or last-station
		for (var i=1; i<lineStationsByLineIdArray[lid].length; i++) {						// test for multiple first- or last-station
			// if ( (i > 1) && (t[i][0] == firstStationId) )	{
			if ( (i > 1) && (lineStationsByLineIdArray[lid][0] == firstStationId) )	{  // Erste Station nochmal da
				firstStationMultiple = true;
			}
			// if ( (i < t.length-1) && (t[i][0] == lastStationId) )	{
			if ( (i < lineStationsByLineIdArray[lid].length-1) && (lineStationsByLineIdArray[lid][0] == lastStationId) )	{  // letzte Station nochmal da
				lastStationMultiple = true;
			}		
			/* wohl nicht ntig:...
			if (t[i][0] == stationID )	{		// self station
				if ((foundfirst == -1) || (foundfirst == (i-1)) )		{		// debug 
					foundfirst = i;
				} else {
					foundnext = i;
					stationIDMultiple = true;
				}
			}	*/
		}	
		showStationTimetableFormNewDayGroups();
		/*
		q = 'SELECT DISTINCT daygroups.ID, daygroups.Days, daygroups.Text FROM daygroups, line_connections'
			+ 'WHERE daygroups.ID = line_connections.DayGroupID AND line_connections.LineID = ' + lineID +	' ORDER by daygroups.Days DESC';
		publicSQL.query(q, 'newDaygroups'); 		*/
	}	// showStationTimetableFormNewFirstLastStations()

	this.showStationTimetableFormNewLines = function()	{
		// alert('showStationTimetableFormNewLines()');
		var i;
		var neuer;
		// var q;		
		var v;
		document.fmSelect.sbLines.length = 0;		
		for (i=0; i<stationLinesByStationIdArray[sid].length; i++)	{
			v = lines[stationLinesByStationIdArray[sid][i]].ID;
	  	neuer = new Option(getLineName(v), v, false, false);
			document.fmSelect.sbLines.options[document.fmSelect.sbLines.length] = neuer;
		}
		document.fmSelect.sbLines.selectedIndex = 0;
		lid = document.fmSelect.sbLines.options[document.fmSelect.sbLines.selectedIndex].value;
		// q = 'SELECT stations.ID, stations.Station FROM stations, line_stations WHERE line_stations.LineID = ' + lid + ' AND stations.ID = line_stations.StationID ORDER BY line_stations.LineStationNumber';
		// publicSQL.query(q, 'newFirstLastStations');		
		showStationTimetableFormNewFirstLastStations();		
	}	// showStationTimetableFormNewLines()

	this.showStationTimetableFormChangeDirection = function()	{
		// alert('showStationTimetableFormChangeDirection()');
		direction = document.fmSelect.sbDirection.options[document.fmSelect.sbDirection.selectedIndex].value;
	}	// showStationTimetableFormChangeDirection()

	this.showStationTimetableFormChangeDays = function()	{
		// alert('showStationTimetableFormChangeDays()');
		dgid = document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value;
		showStationTimetableFormNewDir();
	}	// showStationTimetableFormChangeDays()

	this.showStationTimetableFormChangeLines = function()	{
		// alert('showStationTimetableFormChangeLines()');
		lid = document.fmSelect.sbLines.options[document.fmSelect.sbLines.selectedIndex].value;
		showStationTimetableFormNewFirstLastStations();
	}	// showStationTimetableFormChangeLines()

	this.showStationTimetableFormChangeStation = function()	{
		// alert('showStationTimetableFormChangeStation()');
		sid = document.fmSelect.sbStations.options[document.fmSelect.sbStations.selectedIndex].value;
		showStationTimetableFormNewLines();
	}	// showStationTimetableFormChangeStation()

	/* Formular erstellen */
	
	fm = '<form name="fmSelect" id="fmSelect">';
	fm += '<p>';
	// <p style="white-space:nowrap">
	
	fm += '<strong>' + actLanguageText.station + ':</strong> ';
	fm += '<select name="sbStations" id="sbStations" onChange="showStationTimetableFormChangeStation()">';
	fm += '</select></strong> ';	
	fm += '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<strong>' + actLanguageText.line + ':</strong> ';
	// fm += '<select name="sbLines" id="sbLines" onChange="showTimetableChangeLine();">';
	fm += '<select name="sbLines" id="sbLines" onChange="showStationTimetableFormChangeLines();">';
	fm += '</select> ';
	fm += '</p>';
	fm += '<p>';
	fm += '<strong>' + actLanguageText.operating_days + ':</strong> '; 
  // fm += '<select name="sbDays" id="sbDays" onChange="showTimetableChangeDays()">';
  fm += '<select name="sbDays" id="sbDays" onChange="showStationTimetableFormChangeDays()">';
  fm += '</select> ';
  fm += '<strong>&nbsp;&nbsp;&nbsp;&nbsp;' + actLanguageText.direction + ':</strong> ';
  // fm += '<select name="sbDirection" id="sbDirection" onChange="showTimetableChangeDirection()">';
  fm += '<select name="sbDirection" id="sbDirection" onChange="showStationTimetableFormChangeDirection()">';
  fm += '</select>';
  fm += '</p>';
	// fm += '<p style="white-space:nowrap">';
	fm += '<p>';
  fm += '<input name="btStart" type="button" id="btStart" onClick="showStationTimetableFormStart();" value="' 
  			+ actLanguageText.start_for_button + '">';
  fm += '</p>';
	fm += '</form>';			
	document.getElementById(did).innerHTML = fm;	
	
	
	/* Formularelemente fllen  */
	
	// Stations-Auswahl...
  for (i=0; i<stations.length; i++) {	
    newOpt = new Option(stations[i].Station, stations[i].ID, false, false); 
    document.fmSelect.sbStations.options[i] = newOpt;
  }
  document.fmSelect.sbStations.selectedIndex = 0;
  sid = document.fmSelect.sbStations.options[document.fmSelect.sbStations.selectedIndex].value;
      
	showStationTimetableFormNewLines();   

}	// showStationTimetableForm()

/* Abfahrts-Tabelle fr eine bestimmte Station und best. Zeitraum anzeigen	*/
function showDepartures(sid, dgid, fromTime, toTime, tid, optPar1)	{
	// alert('showDepartures(()');	
  var lineConnectionID = getLineConnectionId(lid, dgid, direction);
  var fromMinutes, toMinutes;	// Erste und zweite Zeit in Minuten fr Zeitraum 
  var tb = document.getElementById(tid);
  var cbFunc = ((arguments.length > 5) && (typeof arguments[arguments.length-1] == "function")) ? arguments[arguments.length-1] : undefined; 
  var foundConnections = new Array();  // fr gefundenen Verbindungen
  var lid;
  var lcid;
  var direction;
  var lineName;
	var	departureTable = new Array();		// Array mit relevanten Abfahrten
	var actStations = new Array();
	var stationPos;
	var stationPosArray = new Array();
	var stationPosArrayIndex;		
	
	/* Callback-Funktion aufrufen oder zurck zum Hauptprogramm	*/
	this.showDeparturesCallBack = function()	{
		// alert('showDeparturesCallBack()');
		if (cbFunc !== "undefined")	{	
	 		cbFunc();	// zur Callback-Funktion gehen
	 	}		
	 }	// showDeparturesCallBack()		
	
	// Hilfsfunktion zum Sortieren
	this.showDeparturesTableSort = function(a, b)	{
		return a[0] - b[0];
	}
	
	this.showDeparturesFillTable = function()	{
		// alert('showDeparturesFillTable()');		
		var i;
		var newTR, newTD, newTDText;
		var stunde, minute, feld;
		var newCap;
		
		publicSQL.htmlTableDelete(tid);
			
		var tb = document.getElementById(tid);
		tb.cellPadding = '2px';
		newTR = tb.insertRow(0); 
	
		newTD = document.createElement("td"); 
		newTD.innerHTML = '<b>' +actLanguageText.time + '</b>';	
	  newTD.bgColor = "#CCCCFF";
		newTR.appendChild(newTD); 	
	
		newTD = document.createElement("td"); 
		newTD.innerHTML = '<b>' + actLanguageText.line + '</b>';		
	  newTD.bgColor = "#CCCCFF";
		newTR.appendChild(newTD); 	
		
		newTD = document.createElement("td"); 
		newTD.innerHTML = '<b>' + actLanguageText.to + '</b>';		
	  newTD.bgColor = "#CCCCFF";
		newTR.appendChild(newTD); 	
		
	  newCap = document.getElementById(tid).createCaption();
		// newCap.innerHTML = '<b>' + document.fmSelect.sbStations.options[document.fmSelect.sbStations.selectedIndex].text + '</b>';		
		newCap.innerHTML = '<b>' + getStationName(sid) + '</b>';		
	
		for (i=0; i<departureTable.length; i++) {		
			newTR = tb.insertRow(i+1); 	
	
			newTD = document.createElement("td"); 		
	    stunde = Math.floor(departureTable[i][0] / 60);
	    minute = departureTable[i][0] - (stunde * 60);
	    stunde = ((stunde > 23) ? stunde - 24 : stunde); 
	    feld = ((stunde < 10) ? "0" + stunde : stunde);
	    feld = feld + ":" + ((minute < 10) ? "0" + minute : minute);
	
			newTDtext = document.createTextNode(feld); 
			newTD.appendChild(newTDtext);
	    if ( (i % 2) == 0)  {
	      newTD.bgColor = "#F0F0F0";
	    } else {
	      newTD.bgColor = "#E0E0E0"; 
	    }
	  	newTR.appendChild(newTD);	// 
			
			newTD = document.createElement("td"); 
			newTDtext = document.createTextNode(departureTable[i][1]); 
			newTD.appendChild(newTDtext);
	    if ( (i % 2) == 0)  {
	      newTD.bgColor = "#F0F0F0";
	    } else {
	      newTD.bgColor = "#E0E0E0"; 
	    }
	  	newTR.appendChild(newTD); 	
			
			newTD = document.createElement("td");		
			newTDtext = document.createTextNode(departureTable[i][2]); 
			newTD.appendChild(newTDtext);
	    if ( (i % 2) == 0)  {
	      newTD.bgColor = "#F0F0F0";
	    } else {
	      newTD.bgColor = "#E0E0E0"; 
	    }
	  	newTR.appendChild(newTD); 
		}			
		showDeparturesCallBack();  // Callback-Funktion aufrufen oder zurck zum Hauptprogramm 						  						
	}	// showDeparturesFillTable(=
	
	this.showDeparturesTT = function(t)	{  
		// alert('showDeparturesTT()');		
		var q;		// query
		var i,j,k, alti;
	  var v1, v2, v3;
	  var idx1, idx2;
	  var a;
	  var aktTR, newTD, newTDText;
	  var stunde, minute, feld;
	  var minInterval, addInterval;
		var startZeitInterval, startZeitInterval2, endZeitInterval ;	// Fr Interval-Vorgnger-Zeit bzw. Nachfolger-Zeit die nicht direkt vor Interval-Spalte steht
		var minIntervalPos;		// Index from minInterval
	  var jetzt = new Date(); 
		var lastPos;
		var prev, next, prev2, next2;

	  i = 1;	  	  	  
	  while (i < t.length) {
			idx1 = stationPos;
			idx2 = idx1;
			v1 = t[i][idx1];
			v2 = v1;
		  if ( (v1 < -1) || (v2 < -1) ) {	// = Interval
				if ( !( (fromMinutes < t[i-1][idx1]) && (toMinutes > t[i-1][idx2]) && (fromMinutes > t[i+1][idx1]) && (toMinutes < t[i+1][idx2]) ) ) {
			  	minInterval = 10000;
				  for (k = 1; k < t[0].length; k++) {
						v3 = t[i][k];
						if (v3 < -1) {
							// if (oInterval[Math.abs(v3)] < minInterval) {
							if (getInterval(Math.abs(v3)) < minInterval) {
								// minInterval = oInterval[Math.abs(v3)];
								minInterval = getInterval(Math.abs(v3));
								minIntervalPos = v3;
								idx1 = k;	// neuer Wert fr idx1 mit niedrigster Interval-Zeit							
							}
						}
					}
				  if (minInterval < 10000) {
						addInterval = 0;
						alti = i-1; 
	
						// Vorgnger von Interval suchen
						j = i-1;
						while (j > 0)	{
							if (t[j][idx1] > -1)	{		// Zeit gefunden	
								prev = j;
								j = 0;														
							}
							j--;
						}
	
						// Nachfolger von Interval suchen
						j = i+1;
						while (j < t.length)	{
							if (t[j][idx1] > -1)	{		// Zeit gefunden	
								next = j;
								j = t.length;
							}
							j++;
						}	
						
						while ((t[i-1][idx1] + minInterval) < (t[next][idx1])) {	// Zwischenwerte berechnen					
							a = new Array;
							a.push(0);
							addInterval += minInterval; 
							for (k = 1; k < t[0].length; k++) {		// for all stations 
							
								if (t[i][k] > -2)	{ 
									a.push(t[i][k]);									
								} else {						
	
									// Vorgner von Interval suchen
									j = alti;
									while (j > 0)	{
										if (t[j][k] > -1)	{		// Zeit gefunden	
											prev2 = j;
											j = 0;
											
											// Start-Intervall-Zeit fr vom Vorgnger berechnen
											startZeitInterval2 = 0;
											m = 1;
											while (m < t[0].length) {		// for all stations, bis minInterval gefunden
												if ((t[prev2][m] > -1) && (t[i][m] == minIntervalPos) && (t[i-1][m] > -1))	{		// Zeit fr Vorgnger, fr Interval-Wert und Zeit fr direkten Vorgnger vorhanden
													startZeitInterval2 = t[alti][m] - t[prev2][m];		// Zeit des direkter Vorgnger-Feldes - Zeit des aktuellen Vorgnger-Feldes
													m = t[0].length;
												}
												m++;
											}																				
										}
										j--;
									}						
	
									// Nachfolger suchen
									j = i+1;
									while (j < t.length)	{
										if (t[j][k] > -1)	{		// Zeit gefunden	
											next2 = j;
											j = t.length;
										}	// if
										j++;
									}	// while j < t.length
								
									// if ( ( (startZeitInterval2 + addInterval) % oInterval[Math.abs(t[i][k])] ) == 0) {	// erster Teil nicht ntig(?) - wenn Interval-Zeit fr Zeile(bzw. Feld) vorhanden
									if ( ( (startZeitInterval2 + addInterval) % getInterval(Math.abs(t[i][k])) ) == 0) {	// erster Teil nicht ntig(?) - wenn Interval-Zeit fr Zeile(bzw. Feld) vorhanden
						 				if (t[prev2][k] != -1)	{  
											a.push(t[prev2][k] + startZeitInterval2 + addInterval)  
										} else  {	
											//	'kommt normalerweise nicht vor!';									
											a.push(-1)						
										}	
									} else {
										a.push(-1);										
									} 	// if
								} 	
							}	// for k
							t.splice(i, 0, a); 
							i++;
							
							// Nachfolger von Interval suchen
							j = i+1;
							while (j < t.length)	{
								if (t[j][idx1] > -1)	{		// Zeit gefunden	
									next = j;
									j = t.length;
								}
								j++;
							}																				
						}	// while
						t.splice(i, 1);
					}
				} 
			}
			i++;		
		}	
	  i = 1;
	  while (i < t.length) {
			j = 1; 
			v1 = -1; 
			v2 = -1;
			idx = stationPos;
			v1 = t[i][idx];		
			v2 = v1;
			if ((toMinutes < v1) || (fromMinutes > v2)) {
				t.splice(i,1);
			} else {
				i++;
			}
		}
	
	
	
		// Now timetable is expanded and has only fields with relevant time!
	
		// build departure-table
		var s = '';
		for (i=1; i<t.length; i++) {
			if (t[i][stationPos] == -1)	{		// hlt nicht
				//	
			} else {		// hlt
				lastPos = stationPos;
	
				for (j=stationPos+1; j<t[i].length; j++)	{ // letzten Wert suchen
					if (t[i][j] != -1)	{		
						lastPos = j;
					}
				}
	
				if (stationPos != lastPos)	{		// spterer Halt gefunden
					departureTable[departureTable.length] = new Array();			
					departureTable[departureTable.length-1][0] = t[i][stationPos];	// zeit
					departureTable[departureTable.length-1][1] = lineName;		
					// departureTable[departureTable.length-1][2] = stations[lastPos][1];				
					departureTable[departureTable.length-1][2] = actStations[lastPos][1];				
				}
			}
		}
		departureTable.sort(showDeparturesTableSort);
					
		if (stationPos != stationPosArray[stationPosArray.length-1])	{
			stationPosArrayIndex++;		
			// showTimeTable3a();
			showDeparturesSetStationPos();
		} else if (foundConnections.length > 0)	{	
			lcid = foundConnections[0][0];
			lid = foundConnections[0][1];
			direction = foundConnections[0][2];
			lineName = foundConnections[0][3];			
			foundConnections.splice(0, 1);
			// q = 'SELECT t.Position, s.ID, s.Station  FROM ttc_' + lineID + ' t, stations s where t.StationID = s.ID and t.DayGroupID = ' + daygroupID + ' and t.Direction = ' + direction + ' order by t.Position';
			q = 'SELECT t.Position, s.ID, s.Station  FROM ttc_' + lid + ' t, stations s where t.StationID = s.ID and t.DayGroupID = ' + dgid + ' and t.Direction = ' + direction + ' order by t.Position';
			publicSQL.query(q, 'showDeparturesTTC');		
		}		else	{
			showDeparturesFillTable();		// fill table			
		}		
		
	}	// showDeparturesTT()		
	
	this.showDeparturesSetStationPos = function()	{
		// alert('showDeparturesSetStationPos()');		
		stationPos = stationPosArray[stationPosArrayIndex];
		publicSQL.query('select * from tt_' + lcid, 'showDeparturesTT');					
	}	// showDeparturesSetStationPos()
	
	this.showDeparturesTTC = function(t) {		// showDeparturesTT()
		// alert('showDeparturesTTC()');	
		var i;
		actStations.splice(0, stations.length);
		stationPos = -1;
		stationPosArray = new Array();	
		for (i=1; i<t.length; i++) {	
			actStations[i] = new Array();	// t.Position, s.ID, s.Station
			actStations[i][0] = t[i][1];	// Stations-ID
			actStations[i][1] = t[i][2];	// Staations-Name		
			if (t[i][1] == sid)	{					
				if ( (i == t.length-1) || (t[i+1][1] != sid) )	{			// not next one with self station?
					stationPosArray[stationPosArray.length] = t[i][0];
				}			
			}		
		}
		stationPosArrayIndex = 0;		// init
		showDeparturesSetStationPos();						
	}	// showDeparturesTTC()
		
	/* erstellt Tabelle "foundConnections" mit allen fr sid relevanten Verbindungen	*/
	this.showDeparturesSetConnections = function()	{	
		// alert('showDeparturesSetConnections()');
		var q;
		var i, j;
		var idx = 0;
		var id;
		departureTable.splice(0,departureTable.length);		// leeren	
		for (i=0; i<stationLinesByStationIdArray[sid].length; i++)	{			// alle Linien zur Station durchgehen
			id = lines[stationLinesByStationIdArray[sid][i]].ID;						// zugehrige Linien-ID
			for (j=0; j<lineConnectionsByLineIdArray[id].length; j++)	{		// alle Verbindungen der Linie durchgehen
				if (lineConnections[lineConnectionsByLineIdArray[id][j]].DayGroupID == dgid)	{		// richtige Daygroup?
					foundConnections[idx] = new Array();
					foundConnections[idx][0] = lineConnections[lineConnectionsByLineIdArray[id][j]].ID;										// ID
					foundConnections[idx][1] = lineConnections[lineConnectionsByLineIdArray[id][j]].LineID;								// LineID
					foundConnections[idx][2] = lineConnections[lineConnectionsByLineIdArray[id][j]].Direction;						// Direction
					foundConnections[idx][3] = getLineName(lineConnections[lineConnectionsByLineIdArray[id][j]].LineID);	// Linien-Name
					idx++;	// Index fr nchsten Eintrag
				}
			}
		}
		if (foundConnections.length > 0)	{		// wenn Eintrge vorhanden ersten Eintrag holen...
			lcid =			foundConnections[0][0];		// ID	
			lid = 			foundConnections[0][1];		// ID
			direction =	foundConnections[0][2];		// ID 
			lineName =	foundConnections[0][3];		// ID
			foundConnections.splice(0, 1);    // ... und aus foundConnections lschen
		}
		q = 'SELECT t.Position, s.ID, s.Station  FROM ttc_' + lid + ' t, stations s where t.StationID = s.ID and t.DayGroupID = ' + dgid 
				+ ' and t.Direction = ' + direction + ' order by t.Position';
		publicSQL.query(q, 'showDeparturesTTC');					
	}	// showDeparturesSetConnections()
	
	fromMinutes = getMinutesFromTime(fromTime);
	toMinutes 	= getMinutesFromTime(toTime);
	if (fromMinutes > toMinutes)	{  // 1. Zeit darf nicht grer wie 2. Zeit sein
		toMinutes = fromMinutes;
	}		
	
	showDeparturesSetConnections();
	
	// publicSQL.query('select s.Station from ttc_' + lid + ' t, stations s where t.StationID = s.ID and t.DayGroupID = ' + dgid 	+ ' and t.Direction = ' + direction + ' order by t.Position', 'showTimetablePeriodTTC');			
}	// showDepartures

function showDeparturesForm(did, tid, optPar1)	{
	// alert('showDeparturesForm()');	
	var i;
	// var first = false;
	var fm;	// Formular
  var newOpt;
	var neuer;
	var aktHours, aktMinutes;
  var jetzt = new Date(); 			
	var sid;
	var dgid;
	var q;
	
	this.showDeparturesFormStart = function()	{		
		// alert('showDeparturesFormStart()');		
 	  var m1, m2; 	  
  	// korrigieren, wenn Startzeit > Endzeit...
	  m1 = (	(document.fmSelect.sbHours1[document.fmSelect.sbHours1.selectedIndex].value * 60) 
	  							+ (document.fmSelect.sbMinutes1[document.fmSelect.sbMinutes1.selectedIndex].value * 1));
	  m2 = (	(document.fmSelect.sbHours2[document.fmSelect.sbHours2.selectedIndex].value * 60) 
	  							+ (document.fmSelect.sbMinutes2[document.fmSelect.sbMinutes2.selectedIndex].value * 1));
		if (m1 > m2)	{
			document.fmSelect.sbHours2.selectedIndex = document.fmSelect.sbHours1.selectedIndex;
			document.fmSelect.sbMinutes2.selectedIndex = document.fmSelect.sbMinutes1.selectedIndex;
			m2 = m1;
		}									
		showDepartures(sid, dgid, m1, m2, tid, optPar1)		
	}	// showDeparturesFormStart()
	
	this.showDeparturesFormInitDaygroups = function(t)	{	
		// alert('showDeparturesFormInitDaygroups()');
		var neuer;
		document.fmSelect.sbDays.length = 0; 
		for (var i=1; i<t.length; i++) {
	  	neuer = new Option(t[i][1], t[i][0], false, false); 
			document.fmSelect.sbDays.options[document.fmSelect.sbDays.length] = neuer; 
		}
		document.fmSelect.sbDays.selectedIndex = 0;	
		dgid = document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value; 
		// daygroupText = document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].text; 	
	}	// showDeparturesFormInitDaygroups()

	this.showDeparturesFormChangeDays = function() {
		// alert('showDeparturesFormChangeDays()');
		dgid = document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].value; 
		// daygroupText = document.fmSelect.sbDays.options[document.fmSelect.sbDays.selectedIndex].text; 
	}	// showDeparturesFormChangeDays()

	this.showDeparturesFormChangeStation = function()	{
		// alert('showDeparturesFormChangeStation()');
		// stationName = document.fmSelect.sbStations.options[document.fmSelect.sbStations.selectedIndex].text;
		sid = document.fmSelect.sbStations.options[document.fmSelect.sbStations.selectedIndex].value; 
		q = 'SELECT DISTINCT daygroups.ID, daygroups.Text, daygroups.Days FROM line_stations, line_connections, daygroups'
				+ ' WHERE line_stations.StationID = ' + sid + ' AND line_connections.LineID = line_stations.LineID AND line_connections.DayGroupID = daygroups.ID'
				+ ' ORDER BY daygroups.Days DESC';
	  publicSQL.query(q, 'showDeparturesFormInitDaygroups');
	}	// showDeparturesFormChangeStation()
	
		
	/* Formular erstellen */
	
	
	fm = '<form name="fmSelect" id="fmSelect">';
	fm += '<p>';
	// <p style="white-space:nowrap">
	fm += '<strong>' + actLanguageText.station + ': ';
	fm += '<select name="sbStations" id="sbStations" onChange="showDeparturesFormChangeStation()">';
	fm += '</select>';
	fm += '<strong>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' + actLanguageText.operating_days + ':</strong> '; 
  fm += '<select name="sbDays" id="sbDays" onChange="showDeparturesFormChangeDays()">';
  fm += '</select> ';
	fm += ' ' + actLanguageText.from_time + ' ';
  fm += '<select name="sbHours1" id="sbHours1">';
	fm += '</select>';
  fm += '<select name="sbMinutes1" id="sbMinutes1">';
  fm += '</select> ';
  fm += ' ' + actLanguageText.to_time + ' ';
	fm += '<select name="sbHours2" id="sbHours2">';
  fm += '</select>';
  fm += '<select name="sbMinutes2" id="sbMinutes2">';
  fm += '</select> ';
  fm += ' ' + actLanguageText.o_clock + ' &nbsp;&nbsp;</strong>';
  fm += '<input name="btStart" type="button" id="btStart" onClick="showDeparturesFormStart();" value="' + actLanguageText.start_for_button + '">';
  fm += '</p>';
	fm += '</form>';			
	document.getElementById(did).innerHTML = fm;	
	
	/* Formularelemente fllen  */
	
	// Zeitraum-Auswahl...
	for (i=0; i<24; i++)	{
		neuer = (i>9) ? new Option(i, i, false, false) : new Option(('0' + i), i, false, false);
		document.fmSelect.sbHours1.options[i] = neuer;
		neuer = (i>9) ? new Option(i, i, false, false) : new Option(('0' + i), i, false, false);
		document.fmSelect.sbHours2.options[i] = neuer;		
	}
	for (i=0; i<12; i++)	{
		neuer = (i>1) ? new Option(i*5, i*5, false, false) : new Option(('0' + i*5), (i*5), false, false)
		document.fmSelect.sbMinutes1.options[i] = neuer;
		neuer = (i>1) ? new Option(i*5, i*5, false, false) : new Option(('0' + i*5), (i*5), false, false)
		document.fmSelect.sbMinutes2.options[i] = neuer;		
	}
			
	aktHours = jetzt.getHours();
	aktMinutes = jetzt.getMinutes();
	aktMinutes = Math.floor(aktMinutes - (aktMinutes % 5));
	document.fmSelect.sbHours1.selectedIndex = aktHours;		
	document.fmSelect.sbMinutes1.selectedIndex = (aktMinutes / 5);
	if (aktHours < 22)	{
		document.fmSelect.sbHours2.selectedIndex = aktHours + 2;			
		document.fmSelect.sbMinutes2.selectedIndex = (aktMinutes / 5);				
	} else	{	
		document.fmSelect.sbHours2.selectedIndex = 23;		
		document.fmSelect.sbMinutes2.selectedIndex = 11;		
	}  
	
	// Stations-Auswahl...
	document.fmSelect.sbStations.length = 0;
	for (i=0; i<stations.length; i++) {
		neuer = new Option(stations[i].Station, stations[i].ID, false, false);
		document.fmSelect.sbStations.options[document.fmSelect.sbStations.length] = neuer;
	}
	document.fmSelect.sbStations.selectedIndex = 0;
	sid = stations[0].ID;  
 	
	q = 'SELECT DISTINCT daygroups.ID, daygroups.Text, daygroups.Days FROM line_stations, line_connections, daygroups'
			+ ' WHERE line_stations.StationID = ' + sid + ' AND line_connections.LineID = line_stations.LineID AND line_connections.DayGroupID = daygroups.ID'
			+ ' ORDER BY daygroups.Days DESC';
  publicSQL.query(q, 'showDeparturesFormInitDaygroups');
  
}	// showDeparturesForm()

// Abfahrtstafel anzeigen; optPar1=Fenster, optPar2=Callback-Funktion
function showDepartureBoard(sid, dgid, toTime, rowAnz, tid, optPar1, optPar2)	{
	// alert('showDepartureBoard()');
	/* 	anders als in showDeparures(Form):
	- showTimeTable4: From- und To-Zeitberechnung am Anfang von showTimeTable4 (bis i=1;), hier kein To-Zeit
	- showTimeTable5: hier MeinFenster-Aufruf am Ende der Funktion 
	- sowie Formular und Formular-Initialisierung (hier keine 2. Zeit, dafr Anzahl Zeilen	*/
	
  var lineConnectionID = getLineConnectionId(lid, dgid, direction);
  var fromMinutes, toMinutes;	// Erste und zweite Zeit in Minuten fr Zeitraum 
  var cbFunc = ((arguments.length > 5) && (typeof arguments[arguments.length-1] == "function")) ? arguments[arguments.length-1] : undefined; 
  var extHTML = ((arguments.length > 5) && (typeof arguments[5] == "string")) ? arguments[5] : ''; 	// Fenstername oder Leerstring
  // var tb = document.getElementById(tid);  
  var tb;
  var foundConnections = new Array();  // fr gefundenen Verbindungen
  var lid;
  var lcid;
  var direction;
  var lineName;
	var	departureTable = new Array();		// Array mit relevanten Abfahrten
	var actStations = new Array();
	var stationPos;
	var stationPosArray = new Array();
	var stationPosArrayIndex;		
	var aktMinutes;
	var aktIndex;
	var outputWindow;	// Ausgabefenster
	
	/* Callback-Funktion aufrufen oder zurck zum Hauptprogramm	*/
	this.showDepartureBoardCallBack = function()	{
		// alert('showDepartureBoardCallBack()');
		if (cbFunc !== "undefined")	{	
	 		cbFunc();	// zur Callback-Funktion gehen
	 	}		
	}	// showDepartureBoardCallBack()		
	
	// Hilfsfunktion zum Sortieren
	this.showDepartureBoardTableSort = function(a, b)	{
		return a[0] - b[0];
	}
	
	this.showDepartureBoardFillTable = function()	{
		// alert('showDepartureBoardFillTable()');		
		// *** fr externes File: wenn hier alert-Aufruf funktioniert das Schreiben in externes Fenster ***
		// *** fr externes File: tb = outputWindow.document.getElementById(tid);
		tb = document.getElementById(tid);
		var i;
		var idx, tableRow;
		var newTR, newTD, newTDText;
		var stunde, minute, feld;
		publicSQL.htmlTableDelete(tb);	
			
		tb.style.color = '#CCCCCC';
		tb.style.backgroundColor = '#CCCCCC';
		tb.style.fontFamily = 'Verdana';	
		tb.cellPadding = '2px';
		
		
		newTR = tb.insertRow(0); 
		newTD = document.createElement("td"); 
		newTD.colSpan = 3;
		newTD.innerHTML = '<b>' + getStationName(sid) + '</b>';	
		newTD.bgColor = "#000000";
		newTR.appendChild(newTD);
		newTR.style.color = '#CCCCCC';
	
		newTR = tb.insertRow(1); 
		
		newTD = document.createElement("td"); 
		newTD.innerHTML = '<b>' + actLanguageText.time + '</b>';	
	  newTD.bgColor = "#000000";
		newTR.appendChild(newTD); 	
		newTR.style.color = '#CCCCCC';
	
		newTD = document.createElement("td"); 
		newTD.innerHTML = '<b>' + actLanguageText.line + '</b>';		
	  newTD.bgColor = "#000000";
		newTR.appendChild(newTD); 	
		
		newTD = document.createElement("td"); 
		newTD.innerHTML = '<b>' + actLanguageText.to + '</b>';		
	  newTD.bgColor = "#000000";
		newTR.appendChild(newTD); 	
		
	//	newTD.innerHTML = '<b>' + lineName + '</b>';
		tableRow = 1;
		idx = aktIndex;
		
		/*** hier noch anpassen: ***/
				
		// while (tableRow < opener.document.fmSelect.sbColumns.options[opener.document.fmSelect.sbColumns.selectedIndex].value)		{
		while (tableRow <= rowAnz)		{
			// if (idx<opener.departureTable.length)		{ 
			if (idx < departureTable.length)		{ 
				
				newTR = tb.insertRow(tableRow+1); 	
				
				newTD = document.createElement("td"); 		
		    
		    stunde = Math.floor(departureTable[idx][0] / 60);    
		    minute = departureTable[idx][0] - (stunde * 60);
		    
		    stunde = ((stunde > 23) ? stunde - 24 : stunde); 
		    feld = ((stunde < 10) ? "0" + stunde : stunde);
		    feld = feld + ":" + ((minute < 10) ? "0" + minute : minute);
	
				newTDtext = document.createTextNode(feld); 
				newTD.appendChild(newTDtext);
		    newTD.bgColor = "#000000";
		  	newTR.appendChild(newTD);	// 
			
				newTD = document.createElement("td"); 
				
				newTDtext = document.createTextNode(departureTable[idx][1]); 
				
				newTD.appendChild(newTDtext);
		    newTD.bgColor = "#000000";
		  	newTR.appendChild(newTD); 	
			
				newTD = document.createElement("td");		
				
				newTDtext = document.createTextNode(departureTable[idx][2]); 
				
				newTD.appendChild(newTDtext);
	//		newTD.innerHTML = '<b>' + t[i][0] + '</b>';
		    newTD.bgColor = "#000000";
		  	newTR.appendChild(newTD); 
				idx++;
			}	else	{
				newTR = tb.insertRow(tableRow+1); 	
	
				newTD = document.createElement("td"); 		
				newTDtext = document.createTextNode(''); 			
		    newTD.bgColor = "#000000";						
				newTD.appendChild(newTDtext);			
				newTD.innerHTML = '&nbsp;';		
		  	newTR.appendChild(newTD);	// 
				
				newTD = document.createElement("td"); 		
				newTDtext = document.createTextNode(''); 			
		    newTD.bgColor = "#000000";						
				newTD.appendChild(newTDtext);			
				newTD.innerHTML = '&nbsp;';		
		  	newTR.appendChild(newTD);	// 
			
				newTD = document.createElement("td"); 		
				newTDtext = document.createTextNode(''); 			
		    newTD.bgColor = "#000000";						
				newTD.appendChild(newTDtext);			
				newTD.innerHTML = '&nbsp;';		
		  	newTR.appendChild(newTD);	// 
			}
			tableRow++;
		}		// while		
	}	// showDepartureBoardFillTable()

	this.showDepartureBoardSetView = function()	{
		// alert('showDepartureBoardSetView()');
		var altIndex = aktIndex;
		var jetzt = new Date();
		var minutes = jetzt.getMinutes() + jetzt.getHours()*60;
		if (minutes > aktMinutes)	{	
			aktMinutes = minutes;				
			if (departureTable[aktIndex][0] < aktMinutes)	{					
			  while ((aktIndex < departureTable.length) && (departureTable[aktIndex][0] < aktMinutes))	{		// Index vorhanden und Zug abgefahren			  	
					aktIndex++;			
				}
				if (aktIndex != altIndex)	{	
					showDepartureBoardFillTable();	
				}
			}
		}		
	}	// showDepartureBoardSetView()
	
	this.showDepartureBoardGo = function()	{
		// alert('showDepartureBoardGo()');
		/*** noch anpassen: ***/
		/*
		// document.getElementById('station').innerHTML = '' + opener.document.fmSelect.sbStations.options[opener.document.fmSelect.sbStations.selectedIndex].text;
		// nach filltable verschoben: document.getElementById('station').innerHTML = '' + document.fmSelect.sbStations.options[opener.document.fmSelect.sbStations.selectedIndex].text;		
		*/	
		var jetzt = new Date();
		aktIndex = 0;
		aktMinutes = jetzt.getMinutes() + jetzt.getHours()*60;
		// outputWindow.focus();
		showDepartureBoardFillTable();
		runView = window.setInterval("showDepartureBoardSetView()", 500);		
		showDepartureBoardCallBack();
	}	// showDepartureBoardGo()

	// externes Fenster ffnen wenn als Parameter bergeben
	this.showDepartureBoardSetWindow = function()	{
		// alert('showDepartureBoardSetWindow()');
		if (extHTML != '')	{			// externes Fenster angegeben
	  	outputWindow = window.open(extHTML, "Zweitfenster", "dependent=yes,width=800,height=600,left=200,top=200,toolbar=no,location=no,resizable=yes,scrollbars=yes");
  		// outputWindow.focus();
  		tb = outputWindow.document.getElementById(tid);
  		// outputWindow.document.getElementById("content").innerHTML="hallo";
  	} else {									// kein  externes Fenster angegeben
  		var tb = document.getElementById(tid);
		}
		showDepartureBoardGo();
	}	// showDepartureBoardSetWindow()

	this.showDepartureBoardTT = function(t)	{  
		// alert('showDepartureBoardTT()');		
		var q;		// query
		var i,j,k, alti;
	  var v1, v2, v3;
	  var idx1, idx2;
	  var a;
	  var aktTR, newTD, newTDText;
	  var stunde, /* minute, */ feld;
	  var minInterval, addInterval;
		var startZeitInterval, startZeitInterval2, endZeitInterval ;	// Fr Interval-Vorgnger-Zeit bzw. Nachfolger-Zeit die nicht direkt vor Interval-Spalte steht
		var minIntervalPos;		// Index from minInterval
	  var jetzt = new Date(); 
		var lastPos;
		var prev, next, prev2, next2;
		
		fromMinutes = jetzt.getHours() * 60 + jetzt.getMinutes();
		if (fromMinutes > toMinutes)	{		// Bis-Zeit vor aktueller Zeit
			stunde = jetzt.getHours() + 2;
			if (stunde > 23)	{	
				// stunde = 23;		
				toMinutes = 1435;
			} else {
			  toMinutes = fromMinutes + 120
			}
		}			
		
	  i = 1;	  	  	  
	  while (i < t.length) {
			idx1 = stationPos;
			idx2 = idx1;
			v1 = t[i][idx1];
			v2 = v1;
		  if ( (v1 < -1) || (v2 < -1) ) {	// = Interval
				if ( !( (fromMinutes < t[i-1][idx1]) && (toMinutes > t[i-1][idx2]) && (fromMinutes > t[i+1][idx1]) && (toMinutes < t[i+1][idx2]) ) ) {
			  	minInterval = 10000;
				  for (k = 1; k < t[0].length; k++) {
						v3 = t[i][k];
						if (v3 < -1) {
							// if (oInterval[Math.abs(v3)] < minInterval) {
							if (getInterval(Math.abs(v3)) < minInterval) {
								// minInterval = oInterval[Math.abs(v3)];
								minInterval = getInterval(Math.abs(v3));
								minIntervalPos = v3;
								idx1 = k;	// neuer Wert fr idx1 mit niedrigster Interval-Zeit							
							}
						}
					}
				  if (minInterval < 10000) {
						addInterval = 0;
						alti = i-1; 
	
						// Vorgnger von Interval suchen
						j = i-1;
						while (j > 0)	{
							if (t[j][idx1] > -1)	{		// Zeit gefunden	
								prev = j;
								j = 0;														
							}
							j--;
						}
	
						// Nachfolger von Interval suchen
						j = i+1;
						while (j < t.length)	{
							if (t[j][idx1] > -1)	{		// Zeit gefunden	
								next = j;
								j = t.length;
							}
							j++;
						}	
						
						while ((t[i-1][idx1] + minInterval) < (t[next][idx1])) {	// Zwischenwerte berechnen					
							a = new Array;
							a.push(0);
							addInterval += minInterval; 
							for (k = 1; k < t[0].length; k++) {		// for all stations 
							
								if (t[i][k] > -2)	{ 
									a.push(t[i][k]);									
								} else {						
	
									// Vorgner von Interval suchen
									j = alti;
									while (j > 0)	{
										if (t[j][k] > -1)	{		// Zeit gefunden	
											prev2 = j;
											j = 0;
											
											// Start-Intervall-Zeit fr vom Vorgnger berechnen
											startZeitInterval2 = 0;
											m = 1;
											while (m < t[0].length) {		// for all stations, bis minInterval gefunden
												if ((t[prev2][m] > -1) && (t[i][m] == minIntervalPos) && (t[i-1][m] > -1))	{		// Zeit fr Vorgnger, fr Interval-Wert und Zeit fr direkten Vorgnger vorhanden
													startZeitInterval2 = t[alti][m] - t[prev2][m];		// Zeit des direkter Vorgnger-Feldes - Zeit des aktuellen Vorgnger-Feldes
													m = t[0].length;
												}
												m++;
											}																				
										}
										j--;
									}						
	
									// Nachfolger suchen
									j = i+1;
									while (j < t.length)	{
										if (t[j][k] > -1)	{		// Zeit gefunden	
											next2 = j;
											j = t.length;
										}	// if
										j++;
									}	// while j < t.length
								
									// if ( ( (startZeitInterval2 + addInterval) % oInterval[Math.abs(t[i][k])] ) == 0) {	// erster Teil nicht ntig(?) - wenn Interval-Zeit fr Zeile(bzw. Feld) vorhanden
									if ( ( (startZeitInterval2 + addInterval) % getInterval(Math.abs(t[i][k])) ) == 0) {	// erster Teil nicht ntig(?) - wenn Interval-Zeit fr Zeile(bzw. Feld) vorhanden
						 				if (t[prev2][k] != -1)	{  
											a.push(t[prev2][k] + startZeitInterval2 + addInterval)  
										} else  {	
											//	'kommt normalerweise nicht vor!';									
											a.push(-1)						
										}	
									} else {
										a.push(-1);										
									} 	// if
								} 	
							}	// for k
							t.splice(i, 0, a); 
							i++;
							
							// Nachfolger von Interval suchen
							j = i+1;
							while (j < t.length)	{
								if (t[j][idx1] > -1)	{		// Zeit gefunden	
									next = j;
									j = t.length;
								}
								j++;
							}																				
						}	// while
						t.splice(i, 1);
					}
				} 
			}
			i++;		
		}	
	  i = 1;
	  while (i < t.length) {
			j = 1; 
			v1 = -1; 
			v2 = -1;
			idx = stationPos;
			v1 = t[i][idx];		
			v2 = v1;
			if ((toMinutes < v1) || (fromMinutes > v2)) {
				t.splice(i,1);
			} else {
				i++;
			}
		}
	
	
	
		// Now timetable is expanded and has only fields with relevant time!
	
		// build departure-table
		var s = '';
		for (i=1; i<t.length; i++) {
			if (t[i][stationPos] == -1)	{		// hlt nicht
				//	
			} else {		// hlt
				lastPos = stationPos;
	
				for (j=stationPos+1; j<t[i].length; j++)	{ // letzten Wert suchen
					if (t[i][j] != -1)	{		
						lastPos = j;
					}
				}
	
				if (stationPos != lastPos)	{		// spterer Halt gefunden
					departureTable[departureTable.length] = new Array();			
					departureTable[departureTable.length-1][0] = t[i][stationPos];	// zeit
					departureTable[departureTable.length-1][1] = lineName;		
					// departureTable[departureTable.length-1][2] = stations[lastPos][1];				
					departureTable[departureTable.length-1][2] = actStations[lastPos][1];				
				}
			}
		}
		departureTable.sort(showDepartureBoardTableSort);
					
		if (stationPos != stationPosArray[stationPosArray.length-1])	{
			stationPosArrayIndex++;		
			// showTimeTable3a();
			showDepartureBoardSetStationPos();
		} else if (foundConnections.length > 0)	{	
			lcid = foundConnections[0][0];
			lid = foundConnections[0][1];
			direction = foundConnections[0][2];
			lineName = foundConnections[0][3];			
			foundConnections.splice(0, 1);
			// q = 'SELECT t.Position, s.ID, s.Station  FROM ttc_' + lineID + ' t, stations s where t.StationID = s.ID and t.DayGroupID = ' + daygroupID + ' and t.Direction = ' + direction + ' order by t.Position';
			q = 'SELECT t.Position, s.ID, s.Station  FROM ttc_' + lid + ' t, stations s where t.StationID = s.ID and t.DayGroupID = ' + dgid + ' and t.Direction = ' + direction + ' order by t.Position';
			publicSQL.query(q, 'showDepartureBoardTTC');		
		}		else	{
			// showDepartureBoardFillTable();		// fill table			
			showDepartureBoardSetWindow();
		}		
		
	}	// showDepartureBoardTT()		
	
	this.showDepartureBoardSetStationPos = function()	{
		// alert('showDepartureBoardSetStationPos()');		
		stationPos = stationPosArray[stationPosArrayIndex];
		publicSQL.query('select * from tt_' + lcid, 'showDepartureBoardTT');					
	}	// showDepartureBoardSetStationPos()
	
	this.showDepartureBoardTTC = function(t) {		// showDepartureBoardTT()
		// alert('showDepartureBoardTTC()');	
		var i;
		actStations.splice(0, stations.length);
		stationPos = -1;
		stationPosArray = new Array();	
		for (i=1; i<t.length; i++) {	
			actStations[i] = new Array();	// t.Position, s.ID, s.Station
			actStations[i][0] = t[i][1];	// Stations-ID
			actStations[i][1] = t[i][2];	// Staations-Name		
			if (t[i][1] == sid)	{					
				if ( (i == t.length-1) || (t[i+1][1] != sid) )	{			// not next one with self station?
					stationPosArray[stationPosArray.length] = t[i][0];
				}			
			}		
		}
		stationPosArrayIndex = 0;		// init
		showDepartureBoardSetStationPos();						
	}	// showDepartureBoardTTC()
		
	/* erstellt Tabelle "foundConnections" mit allen fr sid relevanten Verbindungen	*/
	this.showDepartureBoardSetConnections = function()	{	
		// alert('showDepartureBoardSetConnections()');
		var q;
		var i, j;
		var idx = 0;
		var id;
		departureTable.splice(0,departureTable.length);		// leeren	
		for (i=0; i<stationLinesByStationIdArray[sid].length; i++)	{			// alle Linien zur Station durchgehen
			id = lines[stationLinesByStationIdArray[sid][i]].ID;						// zugehrige Linien-ID
			for (j=0; j<lineConnectionsByLineIdArray[id].length; j++)	{		// alle Verbindungen der Linie durchgehen
				if (lineConnections[lineConnectionsByLineIdArray[id][j]].DayGroupID == dgid)	{		// richtige Daygroup?
					foundConnections[idx] = new Array();
					foundConnections[idx][0] = lineConnections[lineConnectionsByLineIdArray[id][j]].ID;										// ID
					foundConnections[idx][1] = lineConnections[lineConnectionsByLineIdArray[id][j]].LineID;								// LineID
					foundConnections[idx][2] = lineConnections[lineConnectionsByLineIdArray[id][j]].Direction;						// Direction
					foundConnections[idx][3] = getLineName(lineConnections[lineConnectionsByLineIdArray[id][j]].LineID);	// Linien-Name
					idx++;	// Index fr nchsten Eintrag
				}
			}
		}
		if (foundConnections.length > 0)	{		// wenn Eintrge vorhanden ersten Eintrag holen...
			lcid =			foundConnections[0][0];		// ID	
			lid = 			foundConnections[0][1];		// ID
			direction =	foundConnections[0][2];		// ID 
			lineName =	foundConnections[0][3];		// ID
			foundConnections.splice(0, 1);    // ... und aus foundConnections lschen
		}
		q = 'SELECT t.Position, s.ID, s.Station  FROM ttc_' + lid + ' t, stations s where t.StationID = s.ID and t.DayGroupID = ' + dgid 
				+ ' and t.Direction = ' + direction + ' order by t.Position';
		publicSQL.query(q, 'showDepartureBoardTTC');					
	}	// showDepartureBoardSetConnections()
	
	// hier aktuelle Zeit: fromMinutes = getMinutesFromTime(fromTime);
	toMinutes 	= getMinutesFromTime(toTime);
	/*
	if (fromMinutes > toMinutes)	{  // 1. Zeit darf nicht grer wie 2. Zeit sein
		toMinutes = fromMinutes;
	}	
	*/		
	
	showDepartureBoardSetConnections();	
	
	
}	// showDepartureBoard()


